@@ -25,15 +25,16 @@ from __future__ import absolute_import
 from __future__ import print_function
 
 from functools import wraps
-import os
 import cryptography.x509
+import logging
+import os
 import random
 import re
 import string
+import subprocess
 import sys
 
 import requests
-from six.moves import input   # pylint: disable=W0622,F0401
 import six
 
 
@@ -82,6 +83,14 @@ ATTR_NAME_BY_OID = {
     cryptography.x509.ObjectIdentifier('0.9.2342.19200300.100.1.1'): 'UID',
 }
 
+# Retry-able connection errors, see https://pagure.io/dogtagpki/issue/2973
+RETRYABLE_EXCEPTIONS = (
+    requests.exceptions.ConnectionError,  # connection failed
+    requests.exceptions.Timeout,  # connection or read time out
+)
+
+logger = logging.getLogger(__name__)
+
 
 def convert_x509_name_to_dn(name):
     """
@@ -111,59 +120,6 @@ def convert_x509_name_to_dn(name):
     return dn
 
 
-def read_text(message,
-              options=None, default=None, delimiter=':',
-              allow_empty=True, case_sensitive=True):
-    """
-    Get an input from the user. This is used, for example, in
-    pkispawn and pkidestroy to obtain user input.
-
-    :param message: prompt to display to the user
-    :type message: str
-    :param options: list of possible inputs by the user.
-    :type options: list
-    :param default: default value of parameter being prompted.
-    :type default: str
-    :param delimiter: delimiter to be used at the end of the prompt.
-    :type delimiter: str
-    :param allow_empty: Allow input to be empty.
-    :type allow_empty: boolean -- True/False
-    :param case_sensitive: Allow input to be case sensitive.
-    :type case_sensitive: boolean -- True/False
-    :returns: str -- value obtained from user input.
-    """
-    if default:
-        message = message + ' [' + default + ']'
-    message = message + delimiter + ' '
-
-    done = False
-    value = None
-    while not done:
-        value = input(message)
-        value = value.strip()
-
-        if len(value) == 0:  # empty value
-            if allow_empty:
-                value = default
-                break
-
-        else:  # non-empty value
-            if options is not None:
-                for val in options:
-                    if case_sensitive:
-                        if val == value:
-                            done = True
-                            break
-                    else:
-                        if val.lower() == value.lower():
-                            done = True
-                            break
-            else:
-                break
-
-    return value
-
-
 def specification_version():
     """
     Return specification version.
@@ -263,6 +219,31 @@ def generate_password():
     return password
 
 
+class FIPS:
+
+    @staticmethod
+    def is_enabled():
+
+        # Check if /proc/sys/crypto/fips_enabled exists
+        if not os.path.exists('/proc/sys/crypto/fips_enabled'):
+            logger.info('FIPS mode is not enabled')
+            return False
+
+        # Check to see if FIPS is enabled on this system
+        command = ['sysctl', 'crypto.fips_enabled', '-bn']
+
+        with open(os.devnull, 'w') as fnull:
+            output = subprocess.check_output(command, stderr=fnull, close_fds=True)
+
+        if output != '0':
+            logger.info('FIPS mode is enabled')
+            return True
+
+        else:
+            logger.info('FIPS mode is not enabled')
+            return False
+
+
 # pylint: disable=R0903
 class Attribute(object):
     """
