@@ -216,21 +216,20 @@ class ConfigurationRequest(object):
     """
 
     def __init__(self):
-        self.token = None
         self.isClone = "false"
-        self.secureConn = "off"
+
+
+class DatabaseSetupRequest(object):
+    def __init__(self):
+        pass
+
+
+class CertificateSetupRequest(object):
+    def __init__(self):
         self.generateServerCert = "true"
 
 
-class ConfigurationResponse(object):
-    """
-    Class used to represent the response from the Java configuration
-    servlet during the execution of pkispawn.
-
-    This class is the python equivalent of the Java class:
-    com.netscape.certsrv.system.ConfigurationRequest
-    """
-
+class CertificateSetupResponse(object):
     def __init__(self):
         pass
 
@@ -250,6 +249,21 @@ class KeyBackupRequest(object):
         pass
 
 
+class SecurityDomainSetupRequest(object):
+    def __init__(self):
+        pass
+
+
+class DatabaseUserSetupRequest(object):
+    def __init__(self):
+        pass
+
+
+class FinalizeConfigRequest(object):
+    def __init__(self):
+        pass
+
+
 class SystemCertData(object):
     """
     Class used to represent the data for a system certificate, which is
@@ -284,23 +298,21 @@ class SystemConfigClient(object):
         :param request: Configuration request containing all the input needed to
             configure the subsystem
         :type request: ConfigurationRequest
-        :return: ConfigurationResponse -- response from configuration servlet.
         """
         data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
         headers = {'Content-type': 'application/json',
                    'Accept': 'application/json'}
-        response = self.connection.post(
+        self.connection.post(
             '/rest/installer/configure',
             data,
             headers)
-        return response.json()
 
     def setupDatabase(self, request):
         """
         Set up database.
 
-        :param request: Configuration request
-        :type request: ConfigurationRequest
+        :param request: Database setup request
+        :type request: DatabaseSetupRequest
         """
         data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
         headers = {'Content-type': 'application/json',
@@ -310,21 +322,26 @@ class SystemConfigClient(object):
             data,
             headers)
 
-    def configureCerts(self, request):
+    def setupCert(self, request):
         """
-        Configure certificates.
+        Set up certificate.
 
-        :param request: Configuration request
-        :type request: ConfigurationRequest
-        :return: ConfigurationResponse
+        :param request: Certificate setup request
+        :type request: CertificateSetupRequest
+        :return: SystemCertData
         """
         data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
         headers = {'Content-type': 'application/json',
                    'Accept': 'application/json'}
+
         response = self.connection.post(
-            '/rest/installer/configureCerts',
+            '/rest/installer/setupCert',
             data,
             headers)
+
+        if not response.content:
+            return None
+
         return response.json()
 
     def setupAdmin(self, request):
@@ -363,8 +380,8 @@ class SystemConfigClient(object):
         """
         Setup security domain.
 
-        :param request: Configuration request
-        :type request: ConfigurationRequest
+        :param request: Security domain setup request
+        :type request: SecurityDomainSetupRequest
         """
         data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
         headers = {'Content-type': 'application/json',
@@ -378,8 +395,8 @@ class SystemConfigClient(object):
         """
         Set up database user.
 
-        :param request: Configuration request
-        :type request: ConfigurationRequest
+        :param request: Database user setup request
+        :type request: DatabaseUserSetupRequest
         """
         data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
         headers = {'Content-type': 'application/json',
@@ -393,8 +410,8 @@ class SystemConfigClient(object):
         """
         Finalize server configuration.
 
-        :param request: Configuration request
-        :type request: ConfigurationRequest
+        :param request: Finalize configuration request
+        :type request: FinalizeConfigRequest
         """
         data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
         headers = {'Content-type': 'application/json',
@@ -429,8 +446,13 @@ class SystemStatusClient(object):
 
 
 pki.encoder.NOTYPES['ConfigurationRequest'] = ConfigurationRequest
-pki.encoder.NOTYPES['ConfigurationResponse'] = ConfigurationResponse
+pki.encoder.NOTYPES['DatabaseSetupRequest'] = DatabaseSetupRequest
+pki.encoder.NOTYPES['CertificateSetupRequest'] = CertificateSetupRequest
+pki.encoder.NOTYPES['CertificateSetupResponse'] = CertificateSetupResponse
 pki.encoder.NOTYPES['AdminSetupRequest'] = AdminSetupRequest
 pki.encoder.NOTYPES['AdminSetupResponse'] = AdminSetupResponse
 pki.encoder.NOTYPES['KeyBackupRequest'] = KeyBackupRequest
+pki.encoder.NOTYPES['SecurityDomainSetupRequest'] = SecurityDomainSetupRequest
+pki.encoder.NOTYPES['DatabaseUserSetupRequest'] = DatabaseUserSetupRequest
+pki.encoder.NOTYPES['FinalizeConfigRequest'] = FinalizeConfigRequest
 pki.encoder.NOTYPES['SystemCertData'] = SystemCertData
