@@ -37,7 +37,6 @@ UPGRADE_DIR = pki.SHARE_DIR + '/upgrade'
 BACKUP_DIR = pki.LOG_DIR + '/upgrade'
 SYSTEM_TRACKER = pki.CONF_DIR + '/pki.version'
 
-logger = logging.getLogger(__name__)
 verbose = False
 
 
@@ -257,7 +256,7 @@ class PKIUpgradeScriptlet(object):
             if self.upgrader.silent:
                 print(message)
             else:
-                result = pki.read_text(
+                result = pki.util.read_text(
                     message + ' Continue (Yes/No)',
                     options=['Y', 'N'], default='Y', delimiter='?',
                     case_sensitive=False).lower()
@@ -287,7 +286,7 @@ class PKIUpgradeScriptlet(object):
                 if not os.path.isdir(destpath):
                     if verbose:
                         print('Restoring ' + destpath)
-                    pki.util.copydirs(sourcepath, destpath)
+                    pki.util.copydirs(sourcepath, destpath, force=True)
 
                 for filename in filenames:
                     sourcefile = os.path.join(sourcepath, filename)
@@ -295,7 +294,7 @@ class PKIUpgradeScriptlet(object):
 
                     if verbose:
                         print('Restoring ' + targetfile)
-                    pki.util.copyfile(sourcefile, targetfile)
+                    pki.util.copyfile(sourcefile, targetfile, force=True)
 
         newfiles = backup_dir + '/newfiles'
         if os.path.exists(newfiles):
@@ -341,13 +340,13 @@ class PKIUpgradeScriptlet(object):
             sourceparent = os.path.dirname(path)
             destparent = os.path.dirname(dest)
 
-            pki.util.copydirs(sourceparent, destparent)
+            pki.util.copydirs(sourceparent, destparent, force=True)
 
             if os.path.isfile(path):
                 if verbose:
                     print('Saving ' + path)
                 # do not overwrite initial backup
-                pki.util.copyfile(path, dest, overwrite=False)
+                pki.util.copyfile(path, dest, force=False)
 
             else:
                 for sourcepath, _, filenames in os.walk(path):
@@ -357,7 +356,7 @@ class PKIUpgradeScriptlet(object):
 
                     if verbose:
                         print('Saving ' + sourcepath)
-                    pki.util.copydirs(sourcepath, destpath)
+                    pki.util.copydirs(sourcepath, destpath, force=True)
 
                     for filename in filenames:
                         sourcefile = os.path.join(sourcepath, filename)
@@ -366,8 +365,7 @@ class PKIUpgradeScriptlet(object):
                         if verbose:
                             print('Saving ' + sourcefile)
                         # do not overwrite initial backup
-                        pki.util.copyfile(sourcefile, targetfile,
-                                          overwrite=False)
+                        pki.util.copyfile(sourcefile, targetfile, force=False)
 
         else:
 
@@ -428,10 +426,7 @@ class PKIUpgrader(object):
     def versions(self):
 
         current_version = self.get_current_version()
-        logger.debug('Current version: %s', current_version)
-
         target_version = self.get_target_version()
-        logger.debug('Target version: %s', target_version)
 
         upgrade_path = []
 
@@ -457,9 +452,9 @@ class PKIUpgrader(object):
         if not upgrade_path or upgrade_path[-1] != target_version:
             upgrade_path.append(target_version)
 
-        logger.debug('Upgrade path:')
+        logging.debug('Upgrade path:')
         for version in upgrade_path:
-            logger.debug(' - %s', version)
+            logging.debug(' - %s', version)
 
         versions = []
 
@@ -543,11 +538,17 @@ class PKIUpgrader(object):
 
     def get_current_version(self):
 
-        tracker = self.get_tracker()
-        return tracker.get_version()
+        current_version = self.get_tracker().get_version()
+        logging.debug('Current version: %s', current_version)
+
+        return current_version
 
     def get_target_version(self):
-        return pki.util.Version(pki.specification_version())
+
+        target_version = pki.util.Version(pki.specification_version())
+        logging.debug('Target version: %s', target_version)
+
+        return target_version
 
     def is_complete(self):
 
@@ -556,10 +557,18 @@ class PKIUpgrader(object):
 
         return current_version == target_version
 
+    def validate(self):
+
+        if not self.is_complete():
+            log_file = '/var/log/pki/pki-upgrade-%s.log' % self.get_target_version()
+            raise Exception('Upgrade incomplete: see %s' % log_file)
+
     def upgrade_version(self, version):
 
-        print('Upgrading from version ' + str(version) + ' to ' +
-              str(version.next) + ':')
+        if version == version.next:
+            print('Upgrading version %s:' % version)
+        else:
+            print('Upgrading from version %s to %s:' % (version, version.next))
 
         scriptlets = self.scriptlets(version)
 
@@ -579,7 +588,7 @@ class PKIUpgrader(object):
                 print(message)
 
             else:
-                result = pki.read_text(
+                result = pki.util.read_text(
                     message + ' (Yes/No)',
                     options=['Y', 'N'],
                     default='Y',
@@ -605,7 +614,7 @@ class PKIUpgrader(object):
 
                 print()
 
-                result = pki.read_text(
+                result = pki.util.read_text(
                     'Continue (Yes/No)',
                     options=['Y', 'N'],
                     default='Y',
@@ -645,7 +654,7 @@ class PKIUpgrader(object):
                 print(message)
 
             else:
-                result = pki.read_text(
+                result = pki.util.read_text(
                     message + ' (Yes/No)',
                     options=['Y', 'N'], default='Y',
                     case_sensitive=False).lower()
@@ -669,7 +678,7 @@ class PKIUpgrader(object):
 
                 print()
 
-                result = pki.read_text(
+                result = pki.util.read_text(
                     'Continue (Yes/No)', options=['Y', 'N'],
                     default='Y', delimiter='?', case_sensitive=False).lower()
 
