@@ -26,9 +26,11 @@ import java.io.StringWriter;
 import java.net.URLEncoder;
 import java.nio.file.Files;
 import java.nio.file.Paths;
+import java.security.Key;
 import java.security.KeyPair;
 import java.security.MessageDigest;
 import java.security.PublicKey;
+import javax.crypto.Mac;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.CommandLineParser;
@@ -38,7 +40,8 @@ import org.apache.commons.cli.PosixParser;
 import org.apache.http.HttpEntity;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpGet;
-import org.apache.http.impl.client.DefaultHttpClient;
+import org.apache.http.impl.client.CloseableHttpClient;
+import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.util.EntityUtils;
 import org.dogtagpki.common.CAInfo;
 import org.dogtagpki.common.CAInfoClient;
@@ -65,6 +68,12 @@ import org.mozilla.jss.crypto.Signature;
 import org.mozilla.jss.crypto.SignatureAlgorithm;
 import org.mozilla.jss.crypto.SymmetricKey;
 import org.mozilla.jss.crypto.X509Certificate;
+import org.mozilla.jss.netscape.security.util.Cert;
+import org.mozilla.jss.netscape.security.util.Utils;
+import org.mozilla.jss.netscape.security.util.WrappingParams;
+import org.mozilla.jss.netscape.security.x509.KeyIdentifier;
+import org.mozilla.jss.netscape.security.x509.PKIXExtensions;
+import org.mozilla.jss.netscape.security.x509.X500Name;
 import org.mozilla.jss.pkix.crmf.CertReqMsg;
 import org.mozilla.jss.pkix.crmf.CertRequest;
 import org.mozilla.jss.pkix.crmf.CertTemplate;
@@ -81,14 +90,6 @@ import com.netscape.certsrv.base.PKIException;
 import com.netscape.certsrv.client.ClientConfig;
 import com.netscape.certsrv.client.PKIClient;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.cmsutil.util.Cert;
-import com.netscape.cmsutil.util.HMACDigest;
-import com.netscape.cmsutil.util.Utils;
-
-import netscape.security.util.WrappingParams;
-import netscape.security.x509.KeyIdentifier;
-import netscape.security.x509.PKIXExtensions;
-import netscape.security.x509.X500Name;
 
 /**
  * A command-line utility used to generate a Certificate Request Message
@@ -190,7 +191,7 @@ public class CRMFPopClient {
         option.setArgName("keywrap algorithm");
         options.addOption(option);
 
-        options.addOption("y", false, "for Self-signed cmc.");
+        options.addOption("y", false, "for cmc SharedSecret requests.");
 
         options.addOption("v", "verbose", false, "Run in verbose mode.");
         options.addOption(null, "help", false, "Show help message.");
@@ -210,7 +211,7 @@ public class CRMFPopClient {
         System.out.println("  -k <true|false>              Attribute value encoding in subject DN (default: false)");
         System.out.println("                               - true: enabled");
         System.out.println("                               - false: disabled");
-        System.out.println("  -y <true|false>              Add SubjectKeyIdentifier extension in case of self-signed CMC requests (default: false)");
+        System.out.println("  -y <true|false>              Add SubjectKeyIdentifier extension in case of CMC SharedSecret requests (default: false); To be used with 'request.useSharedSecret=true' when running CMCRequest.");
         System.out.println("                               - true: enabled");
         System.out.println("                               - false: disabled");
         System.out.println("  -a <rsa|ec>                  Key algorithm (default: rsa)");
@@ -316,11 +317,11 @@ public class CRMFPopClient {
 
         String curve = cmd.getOptionValue("c", "nistp256");
         boolean sslECDH = Boolean.parseBoolean(cmd.getOptionValue("x", "false"));
-        boolean temporary = Boolean.parseBoolean(cmd.getOptionValue("t", "true"));
+        boolean temporary = Boolean.parseBoolean(cmd.getOptionValue("t", (algorithm.equals("rsa"))? "false":"true"));
         int sensitive = Integer.parseInt(cmd.getOptionValue("s", "-1"));
         int extractable = Integer.parseInt(cmd.getOptionValue("e", "-1"));
 
-        boolean self_sign = cmd.hasOption("y");
+        boolean use_shared_secret = cmd.hasOption("y");
 
         // get the keywrap algorithm
         KeyWrapAlgorithm keyWrapAlgorithm = null;
@@ -335,6 +336,7 @@ public class CRMFPopClient {
         }
 
         String output = cmd.getOptionValue("o");
+        String output_kid = output + ".keyId";
 
         String hostPort = cmd.getOptionValue("m");
         String username = cmd.getOptionValue("u");
@@ -365,11 +367,6 @@ public class CRMFPopClient {
                 System.exit(1);
             }
 
-            if (cmd.hasOption("t")) {
-                printError("Illegal parameter for RSA: -t");
-                System.exit(1);
-            }
-
             if (cmd.hasOption("s")) {
                 printError("Illegal parameter for RSA: -s");
                 System.exit(1);
@@ -470,7 +467,7 @@ public class CRMFPopClient {
             if (verbose) System.out.println("Generating key pair");
             KeyPair keyPair;
             if (algorithm.equals("rsa")) {
-                keyPair = CryptoUtil.generateRSAKeyPair(token, keySize);
+                keyPair = CryptoUtil.generateRSAKeyPair(token, keySize, temporary);
             } else if (algorithm.equals("ec")) {
                 keyPair = client.generateECCKeyPair(token, curve, sslECDH, temporary, sensitive, extractable);
 
@@ -506,7 +503,7 @@ public class CRMFPopClient {
 
             if (verbose) System.out.println("Creating certificate request");
             CertRequest certRequest = client.createCertRequest(
-                    self_sign,
+                    use_shared_secret,
                     token, transportCert, algorithm, keyPair,
                     subject, keyWrapAlgorithm);
 
@@ -562,6 +559,11 @@ public class CRMFPopClient {
                     out.write(csr);
                 }
 
+                System.out.println("Storing CRMF request key id into " + output_kid);
+                try (FileWriter out_kid = new FileWriter(output_kid)) {
+                    out_kid.write(kid);
+                }
+
             } else {
                 System.out.println(csr);
             }
@@ -654,7 +656,7 @@ public class CRMFPopClient {
     }
 
     public CertRequest createCertRequest(
-            boolean self_sign,
+            boolean use_shared_secret,
             CryptoToken token,
             X509Certificate transportCert,
             String algorithm,
@@ -701,8 +703,8 @@ public class CRMFPopClient {
         seq.addElement(new AVA(OBJECT_IDENTIFIER.id_cmc_idPOPLinkWitness, ostr));
         */
 
-        if (self_sign) { // per rfc 5272
-            System.out.println("CRMFPopClient: self_sign true. Generating SubjectKeyIdentifier extension.");
+        if (use_shared_secret) { // per rfc 5272
+            System.out.println("CRMFPopClient: use_shared_secret true. Generating SubjectKeyIdentifier extension.");
             KeyIdentifier subjKeyId = CryptoUtil.createKeyIdentifier(keyPair);
             OBJECT_IDENTIFIER oid = new OBJECT_IDENTIFIER(PKIXExtensions.SubjectKey_Id.toString());
             SEQUENCE extns = new SEQUENCE();
@@ -722,6 +724,11 @@ public class CRMFPopClient {
                 SymmetricKey.AES, KeyGenAlgorithm.AES, 128,
                 KeyWrapAlgorithm.RSA, EncryptionAlgorithm.AES_128_CBC_PAD,
                 kwAlg, ivps, ivps);
+        } else if (kwAlg == KeyWrapAlgorithm.AES_KEY_WRAP) {
+            return new WrappingParams(
+                SymmetricKey.AES, KeyGenAlgorithm.AES, 128,
+                KeyWrapAlgorithm.RSA, EncryptionAlgorithm.AES_128_CBC,
+                kwAlg, ivps, ivps);
         } else if (kwAlg == KeyWrapAlgorithm.DES3_CBC_PAD) {
             return new WrappingParams(
                     SymmetricKey.DES3, KeyGenAlgorithm.DES3, 168,
@@ -750,11 +757,12 @@ public class CRMFPopClient {
             0x6a, 0x12, 0x6b, 0x3c, 0x4c, 0x3f, 0x00, 0x14,
             0x51, 0x61, 0x15, 0x22, 0x23, 0x5f, 0x5e, 0x69
         };
-
-        MessageDigest digest2 = MessageDigest.getInstance("SHA1");
-        HMACDigest hmacDigest = new HMACDigest(digest2, key1);
-        hmacDigest.update(b);
-        byte[] finalDigest = hmacDigest.digest();
+       
+        Mac hmac = Mac.getInstance("HmacSHA1","Mozilla-JSS");
+        Key secKey = CryptoUtil.importHmacSha1Key(key1);
+        hmac.init(secKey);
+        hmac.update(b);
+        byte[] finalDigest = hmac.doFinal();
 
         return new OCTET_STRING(finalDigest);
     }
@@ -847,9 +855,9 @@ public class CRMFPopClient {
 
         if (verbose) System.out.println("Opening " + url);
 
-        DefaultHttpClient client = new DefaultHttpClient();
-        HttpGet method = new HttpGet(url);
-        try {
+        try (CloseableHttpClient client = HttpClientBuilder.create().build()) {
+
+            HttpGet method = new HttpGet(url);
             HttpResponse response = client.execute(method);
 
             if (response.getStatusLine().getStatusCode() != 200) {
@@ -857,9 +865,6 @@ public class CRMFPopClient {
             }
 
             processResponse(response);
-
-        } finally {
-            method.releaseConnection();
         }
     }
 
@@ -973,7 +978,7 @@ public class CRMFPopClient {
         X500Name x500Name = new X500Name(dn);
         Name jssName = new Name();
 
-        for (netscape.security.x509.RDN rdn : x500Name.getNames()) {
+        for (org.mozilla.jss.netscape.security.x509.RDN rdn : x500Name.getNames()) {
 
             String rdnStr = rdn.toString();
             if (verbose) System.out.println("RDN: " + rdnStr);
