@@ -28,8 +28,8 @@ import org.mozilla.jss.util.Password;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import netscape.security.pkcs.PKCS12;
-import netscape.security.pkcs.PKCS12Util;
+import org.mozilla.jss.netscape.security.pkcs.PKCS12;
+import org.mozilla.jss.netscape.security.pkcs.PKCS12Util;
 
 /**
  * Tool for creating PKCS12 file
