@@ -19,10 +19,8 @@
 package com.netscape.cmstools.pkcs12;
 
 import org.apache.commons.codec.binary.Hex;
-
-import com.netscape.cmstools.cli.CLI;
-
-import netscape.security.pkcs.PKCS12KeyInfo;
+import org.dogtagpki.cli.CLI;
+import org.mozilla.jss.netscape.security.pkcs.PKCS12KeyInfo;
 
 /**
  * @author Endi S. Dewata
