@@ -40,6 +40,11 @@ import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.EncryptionAlgorithm;
 import org.mozilla.jss.crypto.PBEAlgorithm;
 import org.mozilla.jss.crypto.PrivateKey;
+import org.mozilla.jss.netscape.security.util.BigInt;
+import org.mozilla.jss.netscape.security.util.DerInputStream;
+import org.mozilla.jss.netscape.security.util.DerValue;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
+import org.mozilla.jss.netscape.security.x509.X509Key;
 import org.mozilla.jss.pkcs12.AuthenticatedSafes;
 import org.mozilla.jss.pkcs12.CertBag;
 import org.mozilla.jss.pkcs12.PFX;
@@ -48,7 +53,6 @@ import org.mozilla.jss.pkcs12.SafeBag;
 import org.mozilla.jss.pkix.primitive.EncryptedPrivateKeyInfo;
 import org.mozilla.jss.pkix.primitive.PrivateKeyInfo;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.authentication.AuthToken;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
@@ -64,17 +68,12 @@ import com.netscape.certsrv.security.Credential;
 import com.netscape.certsrv.security.IStorageKeyUnit;
 import com.netscape.certsrv.util.IStatsSubsystem;
 import com.netscape.cms.logging.Logger;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.dbs.KeyRecord;
 import com.netscape.cmscore.security.JssSubsystem;
-import com.netscape.cmscore.util.Debug;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
-import netscape.security.util.BigInt;
-import netscape.security.util.DerInputStream;
-import netscape.security.util.DerValue;
-import netscape.security.x509.X509CertImpl;
-import netscape.security.x509.X509Key;
-
 /**
  * A class represents recovery request processor. There
  * are 2 types of recovery modes: (1) administrator or
@@ -90,6 +89,8 @@ import netscape.security.x509.X509Key;
  */
 public class RecoveryService implements IService {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(RecoveryService.class);
+
     public static final String ATTR_NICKNAME = "nickname";
     public static final String ATTR_OWNER_NAME = "ownerName";
     public static final String ATTR_SERIALNO = "serialNumber";
@@ -140,30 +141,29 @@ public class RecoveryService implements IService {
         CryptoToken ct = null;
         Boolean allowEncDecrypt_recovery = false;
 
+        CMSEngine engine = CMS.getCMSEngine();
         try {
             cm = CryptoManager.getInstance();
-            config = CMS.getConfigStore();
+            config = engine.getConfigStore();
             tokName = config.getString("kra.storageUnit.hardware", CryptoUtil.INTERNAL_TOKEN_NAME);
-            CMS.debug("RecoveryService: serviceRequest: token: " + tokName);
+            logger.debug("RecoveryService: serviceRequest: token: " + tokName);
             ct = CryptoUtil.getCryptoToken(tokName);
 
             allowEncDecrypt_recovery = config.getBoolean("kra.allowEncDecrypt.recovery", false);
         } catch (Exception e) {
-            CMS.debug("RecoveryService exception: use internal token :"
-                    + e.toString());
+            logger.error("RecoveryService exception: use internal token: " + e, e);
             ct = cm.getInternalCryptoToken();
         }
         if (ct == null) {
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR" + "cannot get crypto token"));
         }
 
-        IStatsSubsystem statsSub = (IStatsSubsystem) CMS.getSubsystem("stats");
+        IStatsSubsystem statsSub = (IStatsSubsystem) engine.getSubsystem(IStatsSubsystem.ID);
         if (statsSub != null) {
             statsSub.startTiming("recovery", true /* main action */);
         }
 
-        if (Debug.ON)
-            Debug.trace("KRA services recovery request");
+        logger.debug("KRA services recovery request");
         mKRA.log(ILogger.LL_INFO, "KRA services recovery request");
 
         // byte publicKey[] = (byte[])request.get(ATTR_PUBLIC_KEY_DATA);
@@ -214,7 +214,7 @@ public class RecoveryService implements IService {
         boolean isRSA = true;
         String keyAlg = x509cert.getPublicKey().getAlgorithm();
         if (keyAlg != null) {
-            CMS.debug("RecoveryService: publicKey alg =" + keyAlg);
+            logger.debug("RecoveryService: publicKey alg =" + keyAlg);
             if (!keyAlg.equals("RSA"))
                 isRSA = false;
         }
@@ -252,7 +252,7 @@ public class RecoveryService implements IService {
                 }
                 // verifyKeyPair() is RSA-centric
                 if (verifyKeyPair(pubData, privateKeyData) == false) {
-                    JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(privateKeyData);
                     mKRA.log(ILogger.LL_FAILURE,
                             CMS.getLogMessage("CMSCORE_KRA_PUBLIC_NOT_FOUND"));
@@ -278,7 +278,7 @@ public class RecoveryService implements IService {
                 throw e;
             } finally {
                 //We don't need this data any more
-                JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(privateKeyData);
             }
 
@@ -287,7 +287,7 @@ public class RecoveryService implements IService {
             }
         } else {
 
-            if (CMS.getConfigStore().getBoolean("kra.keySplitting")) {
+            if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
                 Credential creds[] = (Credential[])
                         params.get(ATTR_AGENT_CREDENTIALS);
                 mKRA.getStorageKeyUnit().login(creds);
@@ -310,7 +310,7 @@ public class RecoveryService implements IService {
                 statsSub.endTiming("unwrap_key");
             }
 
-            if (CMS.getConfigStore().getBoolean("kra.keySplitting")) {
+            if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
                 mKRA.getStorageKeyUnit().logout();
             }
         }
@@ -335,18 +335,16 @@ public class RecoveryService implements IService {
                         authToken.getInString(AuthToken.TOKEN_AUTHMGR_INST_NAME);
             }
         }
-        transactionLogger.log(
-                AuditFormat.LEVEL,
+        logger.info(
                 AuditFormat.FORMAT,
-                new Object[] {
-                        IRequest.KEYRECOVERY_REQUEST,
-                        request.getRequestId(),
-                        initiative,
-                        authMgr,
-                        "completed",
-                        ((X509CertImpl) x509cert).getSubjectDN(),
-                        "serial number: 0x" + serialno.toString(16) }
-                );
+                IRequest.KEYRECOVERY_REQUEST,
+                request.getRequestId(),
+                initiative,
+                authMgr,
+                "completed",
+                ((X509CertImpl) x509cert).getSubjectDN(),
+                "serial number: 0x" + serialno.toString(16)
+        );
 
         if (statsSub != null) {
             statsSub.endTiming("recovery");
@@ -383,20 +381,20 @@ public class RecoveryService implements IService {
             BigInt privateKeyExponent = privateKeyDerIn.getInteger();
 
             if (!publicKeyModulus.equals(privateKeyModulus)) {
-                CMS.debug("verifyKeyPair modulus mismatch publicKeyModulus="
+                logger.debug("verifyKeyPair modulus mismatch publicKeyModulus="
                         + publicKeyModulus + " privateKeyModulus=" + privateKeyModulus);
                 return false;
             }
 
             if (!publicKeyExponent.equals(privateKeyExponent)) {
-                CMS.debug("verifyKeyPair exponent mismatch publicKeyExponent="
+                logger.debug("verifyKeyPair exponent mismatch publicKeyExponent="
                         + publicKeyExponent + " privateKeyExponent=" + privateKeyExponent);
                 return false;
             }
 
             return true;
         } catch (Exception e) {
-            CMS.debug("verifyKeyPair error " + e);
+            logger.debug("verifyKeyPair error " + e);
             return false;
         }
     }
@@ -408,11 +406,12 @@ public class RecoveryService implements IService {
     public synchronized PrivateKey recoverKey(Hashtable<String, Object> request, KeyRecord keyRecord, boolean isRSA)
             throws EBaseException {
 
-        CMS.debug("RecoverService: recoverKey: key to recover is RSA? "+
+        logger.debug("RecoverService: recoverKey: key to recover is RSA? "+
             isRSA);
 
+        CMSEngine engine = CMS.getCMSEngine();
         try {
-            if (CMS.getConfigStore().getBoolean("kra.keySplitting")) {
+            if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
                 Credential creds[] = (Credential[])
                         request.get(ATTR_AGENT_CREDENTIALS);
 
@@ -423,7 +422,7 @@ public class RecoveryService implements IService {
             try {
                 pubkey = X509Key.parsePublicKey(new DerValue(keyRecord.getPublicKeyData()));
             } catch (Exception e) {
-                CMS.debug("RecoverService: after parsePublicKey:" + e.toString());
+                logger.error("RecoverService: after parsePublicKey:" + e.toString(), e);
                 throw new EKRAException(CMS.getUserMessage("CMS_KRA_RECOVERY_FAILED_1", "public key parsing failure"));
             }
 
@@ -439,12 +438,12 @@ public class RecoveryService implements IService {
                 throw new EKRAException(CMS.getUserMessage("CMS_KRA_RECOVERY_FAILED_1",
                         "private key unwrapping failure"), e);
             }
-            if (CMS.getConfigStore().getBoolean("kra.keySplitting")) {
+            if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
                 mStorageUnit.logout();
             }
             return privKey;
         } catch (Exception e) {
-            CMS.debug("RecoverService: recoverKey() failed with allowEncDecrypt_recovery=false:" + e.toString());
+            logger.error("RecoverService: recoverKey() failed with allowEncDecrypt_recovery=false:" + e, e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_RECOVERY_FAILED_1",
                     "recoverKey() failed with allowEncDecrypt_recovery=false:" + e.toString()));
         }
@@ -460,7 +459,10 @@ public class RecoveryService implements IService {
      */
     public void createPFX(IRequest request, Hashtable<String, Object> params,
             PrivateKey priKey, CryptoToken ct) throws EBaseException {
-        CMS.debug("RecoverService: createPFX() allowEncDecrypt_recovery=false");
+
+        logger.debug("RecoverService: createPFX() allowEncDecrypt_recovery=false");
+
+        CMSEngine engine = CMS.getCMSEngine();
         org.mozilla.jss.util.Password pass = null;
         try {
             // create p12
@@ -473,7 +475,7 @@ public class RecoveryService implements IService {
 
             // add certificate
             mKRA.log(ILogger.LL_INFO, "KRA adds certificate to P12");
-            CMS.debug("RecoverService: createPFX() adds certificate to P12");
+            logger.debug("RecoverService: createPFX() adds certificate to P12");
             SEQUENCE encSafeContents = new SEQUENCE();
             ASN1Value cert = new OCTET_STRING(x509cert.getEncoded());
             String nickname = request.getExtDataInString(ATTR_NICKNAME);
@@ -493,13 +495,13 @@ public class RecoveryService implements IService {
 
             // add key
             mKRA.log(ILogger.LL_INFO, "KRA adds key to P12");
-            CMS.debug("RecoverService: createPFX() adds key to P12");
+            logger.debug("RecoverService: createPFX() adds key to P12");
             char[] pwdChar = pwd.toCharArray();
             pass = new
                     org.mozilla.jss.util.Password(
                             pwdChar);
             {
-                JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureChars(pwdChar);
             }
 
@@ -507,12 +509,11 @@ public class RecoveryService implements IService {
             PasswordConverter passConverter = new
                     PasswordConverter();
 
-            boolean legacyP12 =
-                CMS.getConfigStore().getBoolean("kra.legacyPKCS12", true);
+            boolean legacyP12 = engine.getConfigStore().getBoolean("kra.legacyPKCS12", true);
 
             ASN1Value key;
             if (legacyP12) {
-                JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 SecureRandom ran = jssSubsystem.getRandomNumberGenerator();
                 byte[] salt = new byte[20];
                 ran.nextBytes(salt);
@@ -520,12 +521,12 @@ public class RecoveryService implements IService {
                 key = EncryptedPrivateKeyInfo.createPBE(
                         PBEAlgorithm.PBE_SHA1_DES3_CBC,
                         pass, salt, 1, passConverter, priKey, ct);
-                CMS.debug("RecoverService: createPFX() EncryptedPrivateKeyInfo.createPBE() returned");
+                logger.debug("RecoverService: createPFX() EncryptedPrivateKeyInfo.createPBE() returned");
                 if (key == null) {
-                    CMS.debug("RecoverService: createPFX() key null");
+                    logger.error("RecoverService: createPFX() key null");
                     throw new EBaseException("EncryptedPrivateKeyInfo.createPBE() failed");
                 } else {
-                    CMS.debug("RecoverService: createPFX() key not null");
+                    logger.debug("RecoverService: createPFX() key not null");
                 }
             } else {
                 byte[] epkiBytes = ct.getCryptoStore().getEncryptedPrivateKeyInfo(
@@ -544,12 +545,12 @@ public class RecoveryService implements IService {
                     EncryptionAlgorithm.AES_256_CBC,
                     0 /* iterations (use default) */,
                     priKey);
-                CMS.debug("RecoverService: createPFX() getEncryptedPrivateKeyInfo() returned");
+                logger.debug("RecoverService: createPFX() getEncryptedPrivateKeyInfo() returned");
                 if (epkiBytes == null) {
-                    CMS.debug("RecoverService: createPFX() epkiBytes null");
+                    logger.error("RecoverService: createPFX() epkiBytes null");
                     throw new EBaseException("getEncryptedPrivateKeyInfo returned null");
                 } else {
-                    CMS.debug("RecoverService: createPFX() epkiBytes not null");
+                    logger.debug("RecoverService: createPFX() epkiBytes not null");
                 }
                 key = new ANY(epkiBytes);
             }
@@ -589,12 +590,13 @@ public class RecoveryService implements IService {
 
             // put final PKCS12 into volatile request
             params.put(ATTR_PKCS12, fos.toByteArray());
-            CMS.debug("RecoverService: createPFX() completed.");
+            logger.debug("RecoverService: createPFX() completed.");
+
         } catch (Exception e) {
             mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_CONSTRUCT_P12", e.toString()));
-            CMS.debug("RecoverService: createPFX() exception caught:"+
-                e.toString());
+            logger.error("RecoverService: createPFX() exception caught:" + e, e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_PKCS12_FAILED_1", e.toString()));
+
         } finally {
             if(pass != null) {
                 pass.clear();
@@ -611,7 +613,8 @@ public class RecoveryService implements IService {
      */
     public synchronized byte[] recoverKey(Hashtable<String, Object> request, KeyRecord keyRecord)
             throws EBaseException {
-        if (CMS.getConfigStore().getBoolean("kra.keySplitting")) {
+        CMSEngine engine = CMS.getCMSEngine();
+        if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
             Credential creds[] = (Credential[])
                     request.get(ATTR_AGENT_CREDENTIALS);
 
@@ -624,7 +627,7 @@ public class RecoveryService implements IService {
                      keyRecord.getPrivateKeyData(),
                      keyRecord.getWrappingParams(mKRA.getStorageKeyUnit().getOldWrappingParams()));
 
-             if (CMS.getConfigStore().getBoolean("kra.keySplitting")) {
+             if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
                  mStorageUnit.logout();
              }
 
@@ -645,7 +648,10 @@ public class RecoveryService implements IService {
      */
     public void createPFX(IRequest request, Hashtable<String, Object> params,
             byte priData[]) throws EBaseException {
-        CMS.debug("RecoverService: createPFX() allowEncDecrypt_recovery=true");
+
+        logger.debug("RecoverService: createPFX() allowEncDecrypt_recovery=true");
+
+        CMSEngine engine = CMS.getCMSEngine();
         org.mozilla.jss.util.Password pass = null;
         try {
             // create p12
@@ -681,7 +687,7 @@ public class RecoveryService implements IService {
             pass = new org.mozilla.jss.util.Password(
                     pwdChars);
 
-            JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+            JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
             jssSubsystem.obscureChars(pwdChars);
 
 
@@ -691,8 +697,7 @@ public class RecoveryService implements IService {
                             priData);
             EncryptedPrivateKeyInfo epki = null;
 
-            boolean legacyP12 =
-                CMS.getConfigStore().getBoolean("kra.legacyPKCS12", true);
+            boolean legacyP12 = engine.getConfigStore().getBoolean("kra.legacyPKCS12", true);
 
             if (legacyP12) {
                 /* legacy mode may be required e.g. when token/HSM
