@@ -23,6 +23,10 @@ import org.mozilla.jss.crypto.PBEAlgorithm;
 import org.mozilla.jss.crypto.PBEKeyGenParams;
 import org.mozilla.jss.crypto.PrivateKey;
 import org.mozilla.jss.crypto.SymmetricKey;
+import org.mozilla.jss.netscape.security.util.DerValue;
+import org.mozilla.jss.netscape.security.util.Utils;
+import org.mozilla.jss.netscape.security.util.WrappingParams;
+import org.mozilla.jss.netscape.security.x509.X509Key;
 import org.mozilla.jss.pkcs12.PasswordConverter;
 import org.mozilla.jss.pkcs7.ContentInfo;
 import org.mozilla.jss.pkcs7.EncryptedContentInfo;
@@ -30,7 +34,6 @@ import org.mozilla.jss.pkix.primitive.AlgorithmIdentifier;
 import org.mozilla.jss.pkix.primitive.PBEParameter;
 import org.mozilla.jss.util.Password;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.dbs.keydb.IKeyRecord;
@@ -48,17 +51,15 @@ import com.netscape.certsrv.security.IStorageKeyUnit;
 import com.netscape.certsrv.security.ITransportKeyUnit;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.dbs.KeyRecord;
 import com.netscape.cmscore.security.JssSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.cmsutil.util.Utils;
-
-import netscape.security.util.DerValue;
-import netscape.security.util.WrappingParams;
-import netscape.security.x509.X509Key;
 
 public class SecurityDataProcessor {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(SecurityDataProcessor.class);
     private static Logger signedAuditLogger = SignedAuditLogger.getLogger();
 
     public final static String ATTR_KEY_RECORD = "keyRecord";
@@ -102,13 +103,14 @@ public class SecurityDataProcessor {
         // parameter for realm
         String realm = request.getRealm();
 
-        CMS.debug("SecurityDataProcessor.archive. Request id: " + requestId.toString());
-        CMS.debug("SecurityDataProcessor.archive wrappedSecurityData: " + wrappedSecurityData);
+        logger.debug("SecurityDataProcessor.archive. Request id: " + requestId);
+        logger.debug("SecurityDataProcessor.archive wrappedSecurityData: " + wrappedSecurityData);
 
+        CMSEngine engine = CMS.getCMSEngine();
         IConfigStore config = null;
 
         try {
-            config = CMS.getConfigStore();
+            config = engine.getConfigStore();
             allowEncDecrypt_archival = config.getBoolean("kra.allowEncDecrypt.archival", false);
         } catch (Exception e) {
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
@@ -195,7 +197,7 @@ public class SecurityDataProcessor {
                 }
 
                 unwrapped = Arrays.copyOfRange(tmp_unwrapped, first, tmp_unwrapped.length);
-                JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(tmp_unwrapped);
 
             } else {
@@ -239,7 +241,7 @@ public class SecurityDataProcessor {
             } else if (unwrapped != null && allowEncDecrypt_archival == true) {
                 privateSecurityData = storageUnit.encryptInternalPrivate(unwrapped, params);
                 doEncrypt = true;
-                CMS.debug("allowEncDecrypt_archival of symmetric key.");
+                logger.debug("allowEncDecrypt_archival of symmetric key.");
             } else if (securityData != null) {
                 privateSecurityData = storageUnit.encryptInternalPrivate(securityData, params);
                 doEncrypt = true;
@@ -257,7 +259,7 @@ public class SecurityDataProcessor {
                 throw new EBaseException("Failed to create security data to archive!");
             }
         } catch (Exception e) {
-            CMS.debug("Failed to create security data to archive: " + e.getMessage());
+            logger.error("Failed to create security data to archive: " + e.getMessage(), e);
 
             signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                     auditSubjectID,
@@ -271,7 +273,7 @@ public class SecurityDataProcessor {
             throw new EBaseException(CMS.getUserMessage("CMS_KRA_INVALID_PRIVATE_KEY"));
         } finally {
             // clean up some data
-            JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+            JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
             jssSubsystem.obscureBytes(securityData);
             jssSubsystem.obscureBytes(unwrapped);
         }
@@ -353,7 +355,7 @@ public class SecurityDataProcessor {
             throw new EBaseException(CMS.getUserMessage("CMS_KRA_INVALID_STATE"), e);
         }
 
-        CMS.debug("KRA adding Security Data key record " + serialNo);
+        logger.debug("KRA adding Security Data key record " + serialNo);
 
         keyRepository.addKeyRecord(rec);
 
@@ -373,11 +375,13 @@ public class SecurityDataProcessor {
     public boolean recover(IRequest request)
             throws EBaseException {
 
-        CMS.debug("SecurityDataService.recover(): start");
+        logger.debug("SecurityDataService.recover(): start");
+
+        CMSEngine engine = CMS.getCMSEngine();
         IConfigStore config = null;
 
         try {
-            config = CMS.getConfigStore();
+            config = engine.getConfigStore();
             allowEncDecrypt_recovery = config.getBoolean("kra.allowEncDecrypt.recovery", false);
         } catch (Exception e) {
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
@@ -389,7 +393,7 @@ public class SecurityDataProcessor {
         request.setExtData(ATTR_KEY_RECORD, keyId.toBigInteger());
 
         if (params == null) {
-            CMS.debug("SecurityDataProcessor.recover(): Can't get volatile params.");
+            logger.error("SecurityDataProcessor.recover(): Can't get volatile params.");
             throw new EBaseException("Can't obtain volatile params!");
         }
 
@@ -407,7 +411,7 @@ public class SecurityDataProcessor {
 
         if (transWrappedSessKeyStr == null && sessWrappedPassPhraseStr == null) {
             //We may be in recovery case where no params were initially submitted.
-            CMS.debug("SecurityDataProcessor.recover(): No params provided.");
+            logger.warn("SecurityDataProcessor.recover(): No params provided.");
             return false;
         }
 
@@ -430,7 +434,7 @@ public class SecurityDataProcessor {
 
         if (dataType.equals(KeyRequestResource.SYMMETRIC_KEY_TYPE)) {
             if (encrypted) {
-                CMS.debug("Recover symmetric key by decrypting as per allowEncDecrypt_recovery: true.");
+                logger.debug("Recover symmetric key by decrypting as per allowEncDecrypt_recovery: true.");
                 unwrappedSecData = recoverSecurityData(keyRecord);
             } else {
                 symKey = recoverSymKey(keyRecord);
@@ -441,7 +445,7 @@ public class SecurityDataProcessor {
         } else if (dataType.equals(KeyRequestResource.ASYMMETRIC_KEY_TYPE)) {
             try {
                 if (encrypted) {
-                    CMS.debug("Recover asymmetric key by decrypting as per allowEncDecrypt_recovery: true.");
+                    logger.debug("Recover asymmetric key by decrypting as per allowEncDecrypt_recovery: true.");
                     unwrappedSecData = recoverSecurityData(keyRecord);
                 } else {
                     byte[] publicKeyData = keyRecord.getPublicKeyData();
@@ -491,7 +495,7 @@ public class SecurityDataProcessor {
                     payloadWrapName,
                     transportUnit.getOldWrappingParams().getPayloadWrapAlgorithm());
         } catch (Exception e1) {
-            JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+            JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
             jssSubsystem.obscureBytes(unwrappedSecData);
             throw new EBaseException("Failed to generate IV when wrapping secret", e1);
         }
@@ -513,7 +517,7 @@ public class SecurityDataProcessor {
                     iv != null? new IVParameterSpec(iv): null,
                     iv_wrap != null? new IVParameterSpec(iv_wrap): null);
             } catch (Exception e) {
-                JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(unwrappedSecData);
                 throw new EBaseException("Cannot generate wrapping params: " + e, e);
             }
@@ -523,7 +527,7 @@ public class SecurityDataProcessor {
         String pbeWrappedData = null;
 
         if (sessWrappedPassPhraseStr != null) {
-            CMS.debug("SecurityDataProcessor.recover(): secure retrieved data with tranport passphrase");
+            logger.debug("SecurityDataProcessor.recover(): secure retrieved data with tranport passphrase");
             byte[] unwrappedPass = null;
             Password pass = null;
 
@@ -540,15 +544,15 @@ public class SecurityDataProcessor {
 
                 char[] passChars = CryptoUtil.bytesToChars(unwrappedPass);
                 pass = new Password(passChars);
-                JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureChars(passChars);
 
 
                 if (dataType.equals(KeyRequestResource.SYMMETRIC_KEY_TYPE)) {
 
-                    CMS.debug("SecurityDataProcessor.recover(): wrap or encrypt stored symmetric key with transport passphrase");
+                    logger.debug("SecurityDataProcessor.recover(): wrap or encrypt stored symmetric key with transport passphrase");
                     if (encrypted) {
-                        CMS.debug("SecurityDataProcessor.recover(): allowEncDecyypt_recovery: true, symmetric key:  create blob with unwrapped key.");
+                        logger.debug("SecurityDataProcessor.recover(): allowEncDecyypt_recovery: true, symmetric key:  create blob with unwrapped key.");
                         pbeWrappedData = createEncryptedContentInfo(ct, null, unwrappedSecData, null, pass);
                     } else {
                         pbeWrappedData = createEncryptedContentInfo(ct, symKey, null, null, pass);
@@ -556,14 +560,14 @@ public class SecurityDataProcessor {
 
                 } else if (dataType.equals(KeyRequestResource.PASS_PHRASE_TYPE)) {
 
-                    CMS.debug("SecurityDataProcessor.recover(): encrypt stored passphrase with transport passphrase");
+                    logger.debug("SecurityDataProcessor.recover(): encrypt stored passphrase with transport passphrase");
                     pbeWrappedData = createEncryptedContentInfo(ct, null, unwrappedSecData, null, pass);
                 } else if (dataType.equals(KeyRequestResource.ASYMMETRIC_KEY_TYPE)) {
                     if (encrypted) {
-                        CMS.debug("SecurityDataProcessor.recover(): allowEncDecyypt_recovery: true, asymmetric key:  create blob with unwrapped key.");
+                        logger.debug("SecurityDataProcessor.recover(): allowEncDecyypt_recovery: true, asymmetric key:  create blob with unwrapped key.");
                         pbeWrappedData = createEncryptedContentInfo(ct, null, unwrappedSecData, null, pass);
                     } else {
-                        CMS.debug("SecurityDataProcessor.recover(): wrap stored private key with transport passphrase");
+                        logger.debug("SecurityDataProcessor.recover(): wrap stored private key with transport passphrase");
                         pbeWrappedData = createEncryptedContentInfo(ct, null, null, privateKey,
                                 pass);
                     }
@@ -572,7 +576,7 @@ public class SecurityDataProcessor {
                 params.put(IRequest.SECURITY_DATA_PASS_WRAPPED_DATA, pbeWrappedData);
 
             } catch (Exception e) {
-                JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(unwrappedSecData);
                 throw new EBaseException("Cannot unwrap passphrase: " + e, e);
 
@@ -581,19 +585,19 @@ public class SecurityDataProcessor {
                     pass.clear();
                 }
 
-                JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(unwrappedPass);
 
             }
 
         } else {
-            CMS.debug("SecurityDataProcessor.recover(): secure retrieved data with session key");
+            logger.debug("SecurityDataProcessor.recover(): secure retrieved data with session key");
 
             if (dataType.equals(KeyRequestResource.SYMMETRIC_KEY_TYPE)) {
-                CMS.debug("SecurityDataProcessor.recover(): wrap or encrypt stored symmetric key with session key");
+                logger.debug("SecurityDataProcessor.recover(): wrap or encrypt stored symmetric key with session key");
                 try {
                     if (encrypted) {
-                        CMS.debug("SecurityDataProcessor.recover(): encrypt symmetric key with session key as per allowEncDecrypt_recovery: true.");
+                        logger.debug("SecurityDataProcessor.recover(): encrypt symmetric key with session key as per allowEncDecrypt_recovery: true.");
                         unwrappedSess = transportUnit.unwrap_session_key(ct, wrappedSessKey,
                                 SymmetricKey.Usage.ENCRYPT, wrapParams);
                         key_data = CryptoUtil.encryptUsingSymmetricKey(
@@ -614,13 +618,13 @@ public class SecurityDataProcessor {
                     }
 
                 } catch (Exception e) {
-                    JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(unwrappedSecData);
                     throw new EBaseException("Cannot wrap symmetric key: " + e, e);
                 }
 
             } else if (dataType.equals(KeyRequestResource.PASS_PHRASE_TYPE)) {
-                CMS.debug("SecurityDataProcessor.recover(): encrypt stored passphrase with session key");
+                logger.debug("SecurityDataProcessor.recover(): encrypt stored passphrase with session key");
                 try {
                     unwrappedSess = transportUnit.unwrap_session_key(ct, wrappedSessKey,
                             SymmetricKey.Usage.ENCRYPT, wrapParams);
@@ -632,16 +636,16 @@ public class SecurityDataProcessor {
                             wrapParams.getPayloadEncryptionAlgorithm(),
                             wrapParams.getPayloadEncryptionIV());
                 } catch (Exception e) {
-                    JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(unwrappedSecData);
                     throw new EBaseException("Cannot encrypt passphrase: " + e, e);
                 }
 
             } else if (dataType.equals(KeyRequestResource.ASYMMETRIC_KEY_TYPE)) {
-                CMS.debug("SecurityDataProcessor.recover(): wrap or encrypt stored private key with session key");
+                logger.debug("SecurityDataProcessor.recover(): wrap or encrypt stored private key with session key");
                 try {
                     if (encrypted) {
-                        CMS.debug("SecurityDataProcessor.recover(): encrypt symmetric key.");
+                        logger.debug("SecurityDataProcessor.recover(): encrypt symmetric key.");
                         unwrappedSess = transportUnit.unwrap_session_key(ct, wrappedSessKey,
                                 SymmetricKey.Usage.ENCRYPT, wrapParams);
 
@@ -664,7 +668,7 @@ public class SecurityDataProcessor {
                     }
 
                 } catch (Exception e) {
-                    JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(unwrappedSecData);
                     throw new EBaseException("Cannot wrap private key: " + e, e);
                 }
@@ -695,7 +699,7 @@ public class SecurityDataProcessor {
 
 
         //If we made it this far, all is good, and clear out the unwrappedSecData before returning.
-        JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+        JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
         jssSubsystem.obscureBytes(unwrappedSecData);
 
         params.put(IRequest.SECURITY_DATA_TYPE, dataType);
@@ -731,7 +735,8 @@ public class SecurityDataProcessor {
         int numBytes = alg.getIVLength();
         byte[] bytes = new byte[numBytes];
 
-        JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+        CMSEngine engine = CMS.getCMSEngine();
+        JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
         SecureRandom random = jssSubsystem.getRandomNumberGenerator();
         random.nextBytes(bytes);
 
@@ -765,7 +770,8 @@ public class SecurityDataProcessor {
         int numBytes = alg.getBlockSize();
         byte[] bytes = new byte[numBytes];
 
-        JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+        CMSEngine engine = CMS.getCMSEngine();
+        JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
         SecureRandom random = jssSubsystem.getRandomNumberGenerator();
         random.nextBytes(bytes);
 
@@ -796,7 +802,7 @@ public class SecurityDataProcessor {
                     keyRecord.getPrivateKeyData(),
                     keyRecord.getWrappingParams(storageUnit.getOldWrappingParams()));
         } catch (Exception e) {
-            CMS.debug("Failed to recover security data: " + e);
+            logger.error("Failed to recover security data: " + e.getMessage(), e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_RECOVERY_FAILED_1",
                     "recoverSecurityData() " + e.toString()));
         }
