@@ -23,7 +23,8 @@ import java.text.DateFormat;
 import java.util.Date;
 import java.util.Hashtable;
 
-import com.netscape.certsrv.apps.CMS;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
+
 import com.netscape.certsrv.authority.ICertAuthority;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.EPropertyNotFound;
@@ -41,13 +42,13 @@ import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestListener;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.cms.logging.Logger;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.notification.EmailFormProcessor;
 import com.netscape.cmscore.notification.EmailResolverKeys;
 import com.netscape.cmscore.notification.EmailTemplate;
 import com.netscape.cmscore.notification.ReqCertSANameEmailResolver;
 
-import netscape.security.x509.X509CertImpl;
-
 /**
  * a listener for every completed enrollment request
  * <p>
@@ -76,6 +77,9 @@ import netscape.security.x509.X509CertImpl;
  * @version $Revision$, $Date$
  */
 public class CertificateIssuedListener implements IRequestListener {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(CertificateIssuedListener.class);
+
     protected final static String PROP_CERT_ISSUED_SUBSTORE = "certIssued";
     protected static final String PROP_ENABLED = "enabled";
     protected final static String PROP_NOTIFY_SUBSTORE = "notification";
@@ -107,6 +111,7 @@ public class CertificateIssuedListener implements IRequestListener {
 
     public void init(ISubsystem sub, IConfigStore config)
             throws EListenersException, EPropertyNotFound, EBaseException {
+        CMSEngine engine = CMS.getCMSEngine();
         mSubsystem = (ICertAuthority) sub;
         mConfig = mSubsystem.getConfigStore();
 
@@ -128,7 +133,7 @@ public class CertificateIssuedListener implements IRequestListener {
         int ridx = mFormPath.lastIndexOf(File.separator);
 
         if (ridx == -1) {
-            CMS.debug("CertificateIssuedListener: file separator: " + File.separator
+            logger.debug("CertificateIssuedListener: file separator: " + File.separator
                     +
                     " not found. Use default /");
             ridx = mFormPath.lastIndexOf("/");
@@ -137,7 +142,7 @@ public class CertificateIssuedListener implements IRequestListener {
             mDir = mFormPath.substring(0, ridx +
                             File.separator.length());
         }
-        CMS.debug("CertificateIssuedListener: template file directory: " + mDir);
+        logger.debug("CertificateIssuedListener: template file directory: " + mDir);
         mRejectPath = mDir + REJECT_FILE_NAME;
         if (mFormPath.endsWith(".html"))
             mRejectPath += ".html";
@@ -148,7 +153,7 @@ public class CertificateIssuedListener implements IRequestListener {
         else if (mFormPath.endsWith(".HTM"))
             mRejectPath += ".HTM";
 
-        CMS.debug("CertificateIssuedListener: Reject file path: " + mRejectPath);
+        logger.debug("CertificateIssuedListener: Reject file path: " + mRejectPath);
 
         mDateFormat = DateFormat.getDateTimeInstance();
 
@@ -157,15 +162,15 @@ public class CertificateIssuedListener implements IRequestListener {
         mSubject = new String(mSubject_Success);
 
         // form the cert retrieval URL for the notification
-        mHttpHost = CMS.getEEHost();
-        mHttpPort = CMS.getEESSLPort();
+        mHttpHost = engine.getEEHost();
+        mHttpPort = engine.getEESSLPort();
 
         // register for this event listener
         mSubsystem.registerRequestListener(this);
     }
 
     public void accept(IRequest r) {
-        CMS.debug("CertificateIssuedListener: accept " +
+        logger.debug("CertificateIssuedListener: accept " +
                 r.getRequestId().toString());
         if (mEnabled != true)
             return;
@@ -176,12 +181,12 @@ public class CertificateIssuedListener implements IRequestListener {
         String rs = r.getRequestStatus().toString();
 
         if (rs.equals("rejected")) {
-            CMS.debug("CertificateIssuedListener: Request status: " + rs);
+            logger.debug("CertificateIssuedListener: Request status: " + rs);
             rejected(r);
             return;
         }
 
-        CMS.debug("CertificateIssuedListener: accept check status ");
+        logger.debug("CertificateIssuedListener: accept check status ");
 
         // check if it is profile request
         String profileId = r.getExtDataInString(IRequest.PROFILE_ID);
@@ -191,7 +196,7 @@ public class CertificateIssuedListener implements IRequestListener {
             if (r.getExtDataInInteger(IRequest.RESULT) == null)
                 return;
             if ((r.getExtDataInInteger(IRequest.RESULT)).equals(IRequest.RES_ERROR)) {
-                CMS.debug("CertificateIssuedListener: Request errored. " +
+                logger.debug("CertificateIssuedListener: Request errored. " +
                         "No need to email notify for enrollment request id " +
                         mReqId);
                 return;
@@ -201,7 +206,7 @@ public class CertificateIssuedListener implements IRequestListener {
 
         if (requestType.equals(IRequest.ENROLLMENT_REQUEST) ||
                 requestType.equals(IRequest.RENEWAL_REQUEST)) {
-            CMS.debug("accept() enrollment/renewal request...");
+            logger.debug("accept() enrollment/renewal request...");
             // Get the certificate from the request
             X509CertImpl issuedCert[] = null;
 
@@ -215,7 +220,7 @@ public class CertificateIssuedListener implements IRequestListener {
             }
 
             if (issuedCert != null) {
-                CMS.debug("CertificateIssuedListener: Sending email notification..");
+                logger.debug("CertificateIssuedListener: Sending email notification..");
 
                 // do we have an email to send?
                 String mEmail = null;
@@ -226,7 +231,7 @@ public class CertificateIssuedListener implements IRequestListener {
                     keys.set(IEmailResolverKeys.KEY_CERT,
                             issuedCert[0]);
                 } catch (EBaseException e) {
-                    CMS.debug("CertificateIssuedListener: setting email resolver: "+ e.toString());
+                    logger.warn("CertificateIssuedListener: setting email resolver: "+ e.getMessage(), e);
                     log(ILogger.LL_FAILURE,
                             CMS.getLogMessage("LISTENERS_CERT_ISSUED_SET_RESOLVER", e.toString()));
                 }
@@ -236,17 +241,17 @@ public class CertificateIssuedListener implements IRequestListener {
                 try {
                     mEmail = er.getEmail(keys);
                 } catch (ENotificationException e) {
-                    CMS.debug("CertificateIssuedListener: getting email: "+ e.toString());
+                    logger.warn("CertificateIssuedListener: getting email: " + e.getMessage(), e);
                     log(ILogger.LL_FAILURE,
                             CMS.getLogMessage("LISTENERS_CERT_ISSUED_EXCEPTION",
                                     e.toString()));
                 } catch (EBaseException e) {
-                    CMS.debug("CertificateIssuedListener: getting email: "+ e.toString());
+                    logger.warn("CertificateIssuedListener: getting email: " + e.getMessage(), e);
                     log(ILogger.LL_FAILURE,
                             CMS.getLogMessage("LISTENERS_CERT_ISSUED_EXCEPTION",
                                     e.toString()));
                 } catch (Exception e) {
-                    CMS.debug("CertificateIssuedListener: getting email: "+ e.toString());
+                    logger.warn("CertificateIssuedListener: getting email: " + e.getMessage(), e);
                     log(ILogger.LL_FAILURE,
                             CMS.getLogMessage("LISTENERS_CERT_ISSUED_EXCEPTION",
                                     e.toString()));
@@ -254,15 +259,15 @@ public class CertificateIssuedListener implements IRequestListener {
 
                 // now we can mail
                 if ((mEmail != null) && (!mEmail.equals(""))) {
-                    CMS.debug("CertificateIssuedListener: found email: "+ mEmail);
+                    logger.debug("CertificateIssuedListener: found email: "+ mEmail);
                     mailIt(mEmail, issuedCert);
                 } else {
-                    CMS.debug("CertificateIssuedListener: failed finding email");
+                    logger.warn("CertificateIssuedListener: failed finding email");
                     log(ILogger.LL_FAILURE,
                             CMS.getLogMessage("LISTENERS_CERT_ISSUED_NOTIFY_ERROR",
                                     issuedCert[0].getSerialNumber().toString(), mReqId.toString()));
                     // send failure notification to "sender"
-                    CMS.debug("CertificateIssuedListener: notifying sender...");
+                    logger.debug("CertificateIssuedListener: notifying sender...");
                     mSubject = "Certificate Issued notification undeliverable";
                     mailIt(mSenderEmail, issuedCert);
                 }
@@ -271,7 +276,8 @@ public class CertificateIssuedListener implements IRequestListener {
     }
 
     private void mailIt(String mEmail, X509CertImpl issuedCert[]) {
-        IMailNotification mn = CMS.getMailNotification();
+        CMSEngine engine = CMS.getCMSEngine();
+        IMailNotification mn = engine.getMailNotification();
 
         mn.setFrom(mSenderEmail);
         mn.setTo(mEmail);
@@ -285,38 +291,27 @@ public class CertificateIssuedListener implements IRequestListener {
         /*
          * parse and process the template
          */
-        if (template != null) {
-            if (!template.init()) {
-                return;
-            }
-
-            buildContentParams(issuedCert, mEmail);
-            EmailFormProcessor et = new EmailFormProcessor();
-            String c = et.getEmailContent(template.toString(), mContentParams);
-
-            if (template.isHTML()) {
-                mn.setContentType("text/html");
-            }
-            mn.setContent(c);
-        } else {
-            CMS.debug("CertificateIssuedListener: mailIt: template null");
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("LISTENERS_CERT_ISSUED_TEMPLATE_ERROR",
-                            issuedCert[0].getSerialNumber().toString(), mReqId.toString()));
-
-            mn.setContent("Serial Number = " +
-                    issuedCert[0].getSerialNumber() +
-                    "; Request ID = " + mReqId);
+        if (!template.init()) {
+            return;
         }
 
+        buildContentParams(issuedCert, mEmail);
+        EmailFormProcessor et = new EmailFormProcessor();
+        String c = et.getEmailContent(template.toString(), mContentParams);
+
+        if (template.isHTML()) {
+            mn.setContentType("text/html");
+        }
+        mn.setContent(c);
+
         try {
             mn.sendNotification();
         } catch (ENotificationException e) {
-            CMS.debug("CertificateIssuedListener: mailIt: " + e.toString());
+            logger.error("CertificateIssuedListener: mailIt: " + e.getMessage(), e);
             log(ILogger.LL_FAILURE, CMS.getLogMessage("OPERATION_ERROR", e.toString()));
 
         } catch (IOException e) {
-            CMS.debug("CertificateIssuedListener: mailIt: " + e.toString());
+            logger.error("CertificateIssuedListener: mailIt: " + e.getMessage(), e);
             log(ILogger.LL_FAILURE, CMS.getLogMessage("OPERATION_ERROR", e.toString()));
         }
     }
@@ -347,7 +342,8 @@ public class CertificateIssuedListener implements IRequestListener {
 
         // now we can mail
         if ((mEmail != null) && !mEmail.equals("")) {
-            IMailNotification mn = CMS.getMailNotification();
+            CMSEngine engine = CMS.getCMSEngine();
+            IMailNotification mn = engine.getMailNotification();
 
             mn.setFrom(mSenderEmail);
             mn.setTo(mEmail);
@@ -358,29 +354,24 @@ public class CertificateIssuedListener implements IRequestListener {
              */
             EmailTemplate template = new EmailTemplate(mRejectPath);
 
-            if (template != null) {
-                if (!template.init()) {
-                    return;
-                }
-
-                if (template.isHTML()) {
-                    mn.setContentType("text/html");
-                }
-
-                // build some token data
-                mContentParams.put(IEmailFormProcessor.TOKEN_ID, mConfig.getName());
-                mReqId = r.getRequestId();
-                mContentParams.put(IEmailFormProcessor.TOKEN_REQUEST_ID,
-                        mReqId.toString());
-                EmailFormProcessor et = new EmailFormProcessor();
-                String c = et.getEmailContent(template.toString(), mContentParams);
-
-                mn.setContent(c);
-            } else {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("LISTENERS_CERT_ISSUED_REJECTION"));
-                mn.setContent("Your Certificate Request has been rejected.  Please contact your administrator for assistance");
+            if (!template.init()) {
+                return;
             }
 
+            if (template.isHTML()) {
+                mn.setContentType("text/html");
+            }
+
+            // build some token data
+            mContentParams.put(IEmailFormProcessor.TOKEN_ID, mConfig.getName());
+            mReqId = r.getRequestId();
+            mContentParams.put(IEmailFormProcessor.TOKEN_REQUEST_ID,
+                    mReqId.toString());
+            EmailFormProcessor et = new EmailFormProcessor();
+            String c = et.getEmailContent(template.toString(), mContentParams);
+
+            mn.setContent(c);
+
             try {
                 mn.sendNotification();
             } catch (ENotificationException e) {
