@@ -20,11 +20,10 @@ package com.netscape.cms.profile.def;
 import java.io.IOException;
 import java.util.Locale;
 
-import netscape.security.x509.CertificateSubjectName;
-import netscape.security.x509.X500Name;
-import netscape.security.x509.X509CertInfo;
+import org.mozilla.jss.netscape.security.x509.CertificateSubjectName;
+import org.mozilla.jss.netscape.security.x509.X500Name;
+import org.mozilla.jss.netscape.security.x509.X509CertInfo;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.profile.IEnrollProfile;
@@ -33,6 +32,7 @@ import com.netscape.certsrv.property.Descriptor;
 import com.netscape.certsrv.property.EPropertyException;
 import com.netscape.certsrv.property.IDescriptor;
 import com.netscape.certsrv.request.IRequest;
+import com.netscape.cmscore.apps.CMS;
 
 /**
  * This class implements an enrollment default policy
@@ -43,6 +43,8 @@ import com.netscape.certsrv.request.IRequest;
  */
 public class UserSubjectNameDefault extends EnrollDefault {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(UserSubjectNameDefault.class);
+
     public static final String VAL_NAME = "name";
     public static final String CONFIG_USE_SYS_ENCODING = "useSysEncoding";
 
@@ -85,7 +87,7 @@ public class UserSubjectNameDefault extends EnrollDefault {
              * policyset.<policy set>.<#>.default.params.useSysEncoding=true
              */
             boolean useSysEncoding = getConfigBoolean(CONFIG_USE_SYS_ENCODING);
-            CMS.debug(method +
+            logger.debug(method +
                     "use system encoding: " + useSysEncoding);
 
             try {
@@ -95,9 +97,9 @@ public class UserSubjectNameDefault extends EnrollDefault {
                 // oldName is what comes with the CSR
                 CertificateSubjectName oldName = info.getSubjectObj();
                 if (oldName != null) {
-                    CMS.debug(method + "subjectDN exists in CSR. ");
+                    logger.debug(method + "subjectDN exists in CSR. ");
                 } else {
-                    CMS.debug(method + "subjectDN does not exist in CSR. ");
+                    logger.debug(method + "subjectDN does not exist in CSR. ");
                 }
                 if ((useSysEncoding == false) && (oldName != null)) {
                     /* If the canonical string representations of
@@ -105,21 +107,27 @@ public class UserSubjectNameDefault extends EnrollDefault {
                      * keep the old name so that the attribute
                      * encodings are preserved. */
                     X500Name oldX500name = oldName.getX500Name();
-                    if (x500name.toString().equals(oldX500name.toString())) {
-                        CMS.debug( method
+                    if (x500name == null) {
+                        logger.debug( method
+                            + "new Subject DN is null; "
+                            + "retaining current value."
+                        );
+                        x500name = oldX500name;
+                    } else if (x500name.toString().equals(oldX500name.toString())) {
+                        logger.debug( method
                             + "new Subject DN has same string representation "
                             + "as current value; retaining current value."
                         );
                         x500name = oldX500name;
                     } else {
-                        CMS.debug(method
+                        logger.debug(method
                             + "replacing current value `" + oldX500name.toString() + "` "
                             + "with new value `" + x500name.toString() + "`"
                         );
                     }
                 }
             } catch (IOException e) {
-                CMS.debug(method + e.toString());
+                logger.warn(method + e.getMessage(), e);
                 // failed to build x500 name
             }
             return x500name;
@@ -130,25 +138,25 @@ public class UserSubjectNameDefault extends EnrollDefault {
             throws EPropertyException {
         String method = "UserSubjectNameDefault: setValue: ";
         if (name == null) {
-            CMS.debug(name + "name null");
+            logger.error(name + "name null");
             throw new EPropertyException(CMS.getUserMessage(
                         locale, "CMS_INVALID_PROPERTY", name));
         }
-        CMS.debug(method + "name = " + name);
+        logger.debug(method + "name = " + name);
         if (value != null)
-            CMS.debug(method + "value = " + value);
+            logger.debug(method + "value = " + value);
         else
-            CMS.debug(method + "value = null");
+            logger.debug(method + "value = null");
 
         if (name.equals(VAL_NAME)) {
             X500Name x500name = getX500Name(info, value);
-            CMS.debug(method + "setting name=" + x500name);
+            logger.debug(method + "setting name=" + x500name);
             try {
                 info.set(X509CertInfo.SUBJECT,
                         new CertificateSubjectName(x500name));
             } catch (Exception e) {
                 // failed to insert subject name
-                CMS.debug(method + e.toString());
+                logger.error(method + e.getMessage(), e);
                 throw new EPropertyException(CMS.getUserMessage(
                             locale, "CMS_INVALID_PROPERTY", name));
             }
@@ -196,6 +204,12 @@ public class UserSubjectNameDefault extends EnrollDefault {
         // to the certinfo
         CertificateSubjectName req_sbj = request.getExtDataInCertSubjectName(
                     IEnrollProfile.REQUEST_SUBJECT_NAME);
+        if (req_sbj == null) {
+            // failed to retrieve subject name
+            logger.error("UserSubjectNameDefault: populate req_sbj is null");
+            throw new EProfileException(CMS.getUserMessage(getLocale(request),
+                        "CMS_PROFILE_SUBJECT_NAME_NOT_FOUND"));
+        }
         try {
             info.set(X509CertInfo.SUBJECT, req_sbj);
 
@@ -207,7 +221,7 @@ public class UserSubjectNameDefault extends EnrollDefault {
             }
         } catch (Exception e) {
             // failed to insert subject name
-            CMS.debug("UserSubjectNameDefault: populate " + e.toString());
+            logger.error("UserSubjectNameDefault: populate " + e.getMessage(), e);
             throw new EProfileException(e.toString());
         }
     }
