@@ -20,11 +20,13 @@ package com.netscape.cms.profile.input;
 import java.util.Locale;
 
 import org.mozilla.jss.asn1.SEQUENCE;
+import org.mozilla.jss.netscape.security.pkcs.PKCS10;
+import org.mozilla.jss.netscape.security.util.DerInputStream;
+import org.mozilla.jss.netscape.security.x509.X509CertInfo;
 import org.mozilla.jss.pkix.cmc.PKIData;
 import org.mozilla.jss.pkix.cmc.TaggedRequest;
 import org.mozilla.jss.pkix.crmf.CertReqMsg;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.profile.IProfile;
@@ -34,10 +36,7 @@ import com.netscape.certsrv.property.Descriptor;
 import com.netscape.certsrv.property.IDescriptor;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.cms.profile.common.EnrollProfile;
-
-import netscape.security.pkcs.PKCS10;
-import netscape.security.util.DerInputStream;
-import netscape.security.x509.X509CertInfo;
+import com.netscape.cmscore.apps.CMS;
 
 /**
  * This class implements the certificate request input.
@@ -50,6 +49,9 @@ import netscape.security.x509.X509CertInfo;
  * @version $Revision$, $Date$
  */
 public class CertReqInput extends EnrollInput implements IProfileInput {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(CertReqInput.class);
+
     public static final String VAL_CERT_REQUEST_TYPE =
             EnrollProfile.CTX_CERT_REQUEST_TYPE;
     public static final String VAL_CERT_REQUEST =
@@ -92,7 +94,7 @@ public class CertReqInput extends EnrollInput implements IProfileInput {
     public void populate(IProfileContext ctx, IRequest request)
             throws EProfileException {
         String method = "CertReqInput: populate: ";
-        CMS.debug(method + "begins");
+        logger.debug(method + "begins");
 
         String cert_request_type = ctx.get(VAL_CERT_REQUEST_TYPE);
         String cert_request = ctx.get(VAL_CERT_REQUEST);
@@ -100,21 +102,20 @@ public class CertReqInput extends EnrollInput implements IProfileInput {
                 request.getExtDataInCertInfo(EnrollProfile.REQUEST_CERTINFO);
 
         if (cert_request_type == null) {
-            CMS.debug(method + "invalid cert request type " +
-                    "");
+            logger.error(method + "invalid cert request type");
             throw new EProfileException(
                     CMS.getUserMessage(getLocale(request),
                             "CMS_PROFILE_UNKNOWN_CERT_REQ_TYPE",
                             ""));
         }
         if (cert_request == null) {
-            CMS.debug(method + "invalid certificate request");
+            logger.error(method + "invalid certificate request");
             throw new EProfileException(CMS.getUserMessage(
                         getLocale(request), "CMS_PROFILE_NO_CERT_REQ"));
         }
 
         if (cert_request_type.equals(EnrollProfile.REQ_TYPE_PKCS10)) {
-            CMS.debug(method + "cert_request_type= REQ_TYPE_PKCS10");
+            logger.debug(method + "cert_request_type= REQ_TYPE_PKCS10");
 
             PKCS10 pkcs10 = mEnrollProfile.parsePKCS10(getLocale(request), cert_request);
 
@@ -125,7 +126,7 @@ public class CertReqInput extends EnrollInput implements IProfileInput {
 
             mEnrollProfile.fillPKCS10(getLocale(request), pkcs10, info, request);
         } else if (cert_request_type.startsWith(EnrollProfile.REQ_TYPE_KEYGEN)) {
-            CMS.debug(method + "cert_request_type= REQ_TYPE_KEYGEN");
+            logger.debug(method + "cert_request_type= REQ_TYPE_KEYGEN");
             DerInputStream keygen = mEnrollProfile.parseKeyGen(getLocale(request), cert_request);
 
             if (keygen == null) {
@@ -135,7 +136,7 @@ public class CertReqInput extends EnrollInput implements IProfileInput {
 
             mEnrollProfile.fillKeyGen(getLocale(request), keygen, info, request);
         } else if (cert_request_type.startsWith(EnrollProfile.REQ_TYPE_CRMF)) {
-            CMS.debug(method + "cert_request_type= REQ_TYPE_CRMF");
+            logger.debug(method + "cert_request_type= REQ_TYPE_CRMF");
             CertReqMsg msgs[] = mEnrollProfile.parseCRMF(getLocale(request), cert_request);
 
             if (msgs == null) {
@@ -151,14 +152,14 @@ public class CertReqInput extends EnrollInput implements IProfileInput {
             mEnrollProfile.fillCertReqMsg(getLocale(request), msgs[seqNum.intValue()], info, request
                     );
         } else if (cert_request_type.startsWith(EnrollProfile.REQ_TYPE_CMC)) {
-            CMS.debug(method + "cert_request_type= REQ_TYPE_CMC");
+            logger.debug(method + "cert_request_type= REQ_TYPE_CMC");
             // cfu: getPKIDataFromCMCblob() is extracted from parseCMC
             // so it's less confusing
             //TaggedRequest msgs[] = mEnrollProfile.parseCMC(getLocale(request), cert_request);
             PKIData pkiData = mEnrollProfile.getPKIDataFromCMCblob(getLocale(request), cert_request);
             SEQUENCE reqSeq = pkiData.getReqSequence();
             int nummsgs = reqSeq.size(); // for now we only handle one anyways
-            CMS.debug(method + "pkiData.getReqSequence() called; nummsgs =" + nummsgs);
+            logger.debug(method + "pkiData.getReqSequence() called; nummsgs =" + nummsgs);
             TaggedRequest[] msgs = new TaggedRequest[reqSeq.size()];
             for (int i = 0; i < nummsgs; i++) {
                 msgs[i] = (TaggedRequest) reqSeq.elementAt(i);
@@ -174,8 +175,7 @@ public class CertReqInput extends EnrollInput implements IProfileInput {
 
             mEnrollProfile.fillTaggedRequest(getLocale(request), msgs[seqNum.intValue()], info, request);
         } else {
-            // error
-            CMS.debug(method + "invalid cert request type " +
+            logger.error(method + "invalid cert request type " +
                     cert_request_type);
             throw new EProfileException(
                     CMS.getUserMessage(getLocale(request),
