@@ -22,7 +22,12 @@ import java.security.cert.X509Certificate;
 import java.util.Locale;
 import java.util.Vector;
 
-import com.netscape.certsrv.apps.CMS;
+import org.mozilla.jss.netscape.security.x509.CertificateExtensions;
+import org.mozilla.jss.netscape.security.x509.X500Name;
+import org.mozilla.jss.netscape.security.x509.X509CRLImpl;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
+import org.mozilla.jss.netscape.security.x509.X509CertInfo;
+
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
@@ -32,6 +37,7 @@ import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.publish.ILdapMapper;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.cms.logging.Logger;
+import com.netscape.cmscore.apps.CMS;
 
 import netscape.ldap.LDAPAttribute;
 import netscape.ldap.LDAPAttributeSet;
@@ -42,11 +48,6 @@ import netscape.ldap.LDAPSearchResults;
 import netscape.ldap.LDAPv2;
 import netscape.ldap.LDAPv3;
 import netscape.ldap.util.DN;
-import netscape.security.x509.CertificateExtensions;
-import netscape.security.x509.X500Name;
-import netscape.security.x509.X509CRLImpl;
-import netscape.security.x509.X509CertImpl;
-import netscape.security.x509.X509CertInfo;
 
 /**
  * Maps a request to an entry in the LDAP server.
@@ -59,6 +60,9 @@ import netscape.security.x509.X509CertInfo;
  * @version $Revision$, $Date$
  */
 public class LdapCaSimpleMap implements ILdapMapper, IExtendedPluginInfo {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LdapCaSimpleMap.class);
+
     protected static final String PROP_DNPATTERN = "dnPattern";
     protected static final String PROP_CREATECA = "createCAEntry";
     protected String mDnPattern = null;
@@ -290,7 +294,7 @@ public class LdapCaSimpleMap implements ILdapMapper, IExtendedPluginInfo {
             X509Certificate cert = (X509Certificate) obj;
             subjectDN = (X500Name) cert.getSubjectDN();
 
-            CMS.debug("LdapCaSimpleMap: cert subject dn:" + subjectDN.toString());
+            logger.debug("LdapCaSimpleMap: cert subject dn:" + subjectDN.toString());
             X509CertInfo info = (X509CertInfo)
                     ((X509CertImpl) cert).get(
                             X509CertImpl.NAME + "." + X509CertImpl.INFO);
@@ -308,8 +312,8 @@ public class LdapCaSimpleMap implements ILdapMapper, IExtendedPluginInfo {
                 X509CRLImpl crl = (X509CRLImpl) obj;
                 subjectDN = (X500Name) crl.getIssuerDN();
 
-                CMS.debug("LdapCaSimpleMap: crl issuer dn: " +
-                        subjectDN.toString());
+                logger.warn("LdapCaSimpleMap: crl issuer dn: " + subjectDN + ": " + e.getMessage(), e);
+
             } catch (ClassCastException ex) {
                 log(ILogger.LL_FAILURE, CMS.getLogMessage("PUBLISH_PUBLISH_OBJ_NOT_SUPPORTED",
                         ((req == null) ? "" : req.getRequestId().toString())));
