@@ -30,7 +30,12 @@ import java.security.cert.X509Certificate;
 import java.util.Locale;
 import java.util.Vector;
 
-import com.netscape.certsrv.apps.CMS;
+import org.mozilla.jss.netscape.security.x509.CertificateExtensions;
+import org.mozilla.jss.netscape.security.x509.X500Name;
+import org.mozilla.jss.netscape.security.x509.X509CRLImpl;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
+import org.mozilla.jss.netscape.security.x509.X509CertInfo;
+
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
@@ -40,6 +45,7 @@ import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.publish.ILdapMapper;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.cms.logging.Logger;
+import com.netscape.cmscore.apps.CMS;
 
 import netscape.ldap.LDAPAttribute;
 import netscape.ldap.LDAPAttributeSet;
@@ -50,11 +56,6 @@ import netscape.ldap.LDAPSearchResults;
 import netscape.ldap.LDAPv2;
 import netscape.ldap.LDAPv3;
 import netscape.ldap.util.DN;
-import netscape.security.x509.CertificateExtensions;
-import netscape.security.x509.X500Name;
-import netscape.security.x509.X509CRLImpl;
-import netscape.security.x509.X509CertImpl;
-import netscape.security.x509.X509CertInfo;
 
 //////////////////////
 // class definition //
@@ -78,6 +79,9 @@ import netscape.security.x509.X509CertInfo;
  */
 public class LdapEnhancedMap
         implements ILdapMapper, IExtendedPluginInfo {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LdapEnhancedMap.class);
+
     ////////////////////////
     // default parameters //
     ////////////////////////
@@ -219,9 +223,7 @@ public class LdapEnhancedMap
         try {
             X509Certificate cert = (X509Certificate) obj;
             subjectDN = (X500Name) cert.getSubjectDN();
-            CMS.debug(
-                    "LdapEnhancedMap: cert subject dn:" +
-                            subjectDN.toString());
+            logger.debug("LdapEnhancedMap: cert subject dn:" + subjectDN);
 
             //certExt = (CertificateExtensions)
             //          ((X509CertImpl)cert).get(
@@ -249,9 +251,7 @@ public class LdapEnhancedMap
                 X509CRLImpl crl = (X509CRLImpl) obj;
                 subjectDN = (X500Name) crl.getIssuerDN();
 
-                CMS.debug(
-                        "LdapEnhancedMap: crl issuer dn: " +
-                        subjectDN.toString());
+                logger.warn("LdapEnhancedMap: crl issuer dn: " + subjectDN + ": " + e.getMessage(), e);
             } catch (ClassCastException ex) {
                 log(ILogger.LL_FAILURE,
                         CMS.getLogMessage("PUBLISH_PUBLISH_OBJ_NOT_SUPPORTED",
@@ -620,7 +620,7 @@ public class LdapEnhancedMap
         }
 
         String params[] =
-                com.netscape.cmsutil.util.Utils.getStringArrayFromVector(v);
+                org.mozilla.jss.netscape.security.util.Utils.getStringArrayFromVector(v);
 
         return params;
     }
