@@ -30,7 +30,12 @@ import javax.servlet.ServletOutputStream;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import com.netscape.certsrv.apps.CMS;
+import org.mozilla.jss.netscape.security.x509.CRLExtensions;
+import org.mozilla.jss.netscape.security.x509.CRLReasonExtension;
+import org.mozilla.jss.netscape.security.x509.InvalidityDateExtension;
+import org.mozilla.jss.netscape.security.x509.RevocationReason;
+import org.mozilla.jss.netscape.security.x509.RevokedCertImpl;
+
 import com.netscape.certsrv.authentication.AuthToken;
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.authorization.AuthzToken;
@@ -54,12 +59,9 @@ import com.netscape.cms.servlet.common.CMSRequest;
 import com.netscape.cms.servlet.common.CMSTemplate;
 import com.netscape.cms.servlet.common.CMSTemplateParams;
 import com.netscape.cms.servlet.common.ECMSGWException;
-
-import netscape.security.x509.CRLExtensions;
-import netscape.security.x509.CRLReasonExtension;
-import netscape.security.x509.InvalidityDateExtension;
-import netscape.security.x509.RevocationReason;
-import netscape.security.x509.RevokedCertImpl;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.base.ArgBlock;
 
 /**
  * Force the CRL to be updated now.
@@ -68,9 +70,8 @@ import netscape.security.x509.RevokedCertImpl;
  */
 public class UpdateCRL extends CMSServlet {
 
-    /**
-     *
-     */
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(UpdateCRL.class);
+
     private static final long serialVersionUID = -1182106454856991246L;
     private final static String TPL_FILE = "updateCRL.template";
 
@@ -117,7 +118,8 @@ public class UpdateCRL extends CMSServlet {
         HttpServletRequest req = cmsReq.getHttpReq();
         HttpServletResponse resp = cmsReq.getHttpResp();
 
-        IStatsSubsystem statsSub = (IStatsSubsystem) CMS.getSubsystem("stats");
+        CMSEngine engine = CMS.getCMSEngine();
+        IStatsSubsystem statsSub = (IStatsSubsystem) engine.getSubsystem(IStatsSubsystem.ID);
         if (statsSub != null) {
             statsSub.startTiming("crl", true /* main action */);
         }
@@ -145,8 +147,8 @@ public class UpdateCRL extends CMSServlet {
 
         EBaseException error = null;
 
-        IArgBlock header = CMS.createArgBlock();
-        IArgBlock fixed = CMS.createArgBlock();
+        ArgBlock header = new ArgBlock();
+        ArgBlock fixed = new ArgBlock();
         CMSTemplateParams argSet = new CMSTemplateParams(header, fixed);
 
         CMSTemplate form = null;
@@ -216,7 +218,7 @@ public class UpdateCRL extends CMSServlet {
                     revReason = RevocationReason.UNSPECIFIED;
                 crlReasonExtn = new CRLReasonExtension(revReason);
             } catch (Exception e) {
-                CMS.debug("Invalid revocation reason: " + reason);
+                logger.warn("Invalid revocation reason: " + reason + ": " + e.getMessage(), e);
             }
         }
 
@@ -228,13 +230,13 @@ public class UpdateCRL extends CMSServlet {
                 long backInTime = Long.parseLong(invalidity);
                 invalidityDate = new Date(now - (backInTime * 60000));
             } catch (Exception e) {
-                CMS.debug("Invalid invalidity time offset: " + invalidity);
+                logger.warn("Invalid invalidity time offset: " + invalidity + ": " + e.getMessage(), e);
             }
             if (invalidityDate != null) {
                 try {
                     invalidityDateExtn = new InvalidityDateExtension(invalidityDate);
                 } catch (Exception e) {
-                    CMS.debug("Error creating invalidity extension: " + e);
+                    logger.warn("Error creating invalidity extension: " + e.getMessage(), e);
                 }
             }
         }
@@ -243,7 +245,7 @@ public class UpdateCRL extends CMSServlet {
             try {
                 entryExts.set(crlReasonExtn.getName(), crlReasonExtn);
             } catch (Exception e) {
-                CMS.debug("Error adding revocation reason extension to entry extensions: " + e);
+                logger.warn("Error adding revocation reason extension to entry extensions: " + e.getMessage(), e);
             }
         }
 
@@ -251,7 +253,7 @@ public class UpdateCRL extends CMSServlet {
             try {
                 entryExts.set(invalidityDateExtn.getName(), invalidityDateExtn);
             } catch (Exception e) {
-                CMS.debug("Error adding invalidity date extension to entry extensions: " + e);
+                logger.warn("Error adding invalidity date extension to entry extensions: " + e.getMessage(), e);
             }
         }
 
@@ -259,7 +261,7 @@ public class UpdateCRL extends CMSServlet {
     }
 
     private void addInfo(CMSTemplateParams argSet, ICRLIssuingPoint crlIssuingPoint, long cacheUpdate) {
-        IArgBlock rarg = CMS.createArgBlock();
+        ArgBlock rarg = new ArgBlock();
 
         rarg.addLongValue("cacheUpdate", cacheUpdate);
 
@@ -296,7 +298,7 @@ public class UpdateCRL extends CMSServlet {
             Locale locale)
             throws EBaseException {
 
-        long startTime = CMS.getCurrentDate().getTime();
+        long startTime = new Date().getTime();
         String waitForUpdate =
                 req.getParameter("waitForUpdate");
         String clearCache =
@@ -335,49 +337,47 @@ public class UpdateCRL extends CMSServlet {
         IPublisherProcessor lpm = mCA.getPublisherProcessor();
 
         if (crlIssuingPoint == null) {
-            CMS.debug("UpdateCRL: no CRL issuing point");
+            logger.debug("UpdateCRL: no CRL issuing point");
             return;
         }
 
-        CMS.debug("UpdateCRL: CRL issuing point: " + crlIssuingPoint.getId());
+        logger.debug("UpdateCRL: CRL issuing point: " + crlIssuingPoint.getId());
 
         if (clearCache != null && clearCache.equals("true") &&
                 crlIssuingPoint.isCRLGenerationEnabled() &&
                 crlIssuingPoint.isCRLUpdateInProgress() == ICRLIssuingPoint.CRL_UPDATE_DONE &&
-                crlIssuingPoint.isCRLIssuingPointInitialized()
-                            == ICRLIssuingPoint.CRL_IP_INITIALIZED) {
+                crlIssuingPoint.isCRLIssuingPointInitialized()) {
 
-            CMS.debug("UpdateCRL: clearing CRL cache");
+            logger.debug("UpdateCRL: clearing CRL cache");
             crlIssuingPoint.clearCRLCache();
         }
 
         if (!(waitForUpdate != null && waitForUpdate.equals("true") &&
                 crlIssuingPoint.isCRLGenerationEnabled() &&
                 crlIssuingPoint.isCRLUpdateInProgress() == ICRLIssuingPoint.CRL_UPDATE_DONE &&
-                crlIssuingPoint.isCRLIssuingPointInitialized()
-                            == ICRLIssuingPoint.CRL_IP_INITIALIZED)) {
+                crlIssuingPoint.isCRLIssuingPointInitialized())) {
 
-            if (crlIssuingPoint.isCRLIssuingPointInitialized() != ICRLIssuingPoint.CRL_IP_INITIALIZED) {
+            if (!crlIssuingPoint.isCRLIssuingPointInitialized()) {
 
-                CMS.debug("UpdateCRL: CRL issuing point not initialized");
+                logger.debug("UpdateCRL: CRL issuing point not initialized");
                 header.addStringValue("crlUpdate", "notInitialized");
 
             } else if (crlIssuingPoint.isCRLUpdateInProgress()
                        != ICRLIssuingPoint.CRL_UPDATE_DONE ||
                        crlIssuingPoint.isManualUpdateSet()) {
 
-                CMS.debug("UpdateCRL: CRL update in progress");
+                logger.debug("UpdateCRL: CRL update in progress");
                 header.addStringValue("crlUpdate", "inProgress");
 
             } else if (!crlIssuingPoint.isCRLGenerationEnabled()) {
 
-                CMS.debug("UpdateCRL: CRL update disabled");
+                logger.debug("UpdateCRL: CRL update disabled");
                 header.addStringValue("crlUpdate", "Disabled");
 
             } else {
 
                 try {
-                    CMS.debug("UpdateCRL: scheduling CRL update");
+                    logger.debug("UpdateCRL: scheduling CRL update");
 
                     crlIssuingPoint.setManualUpdate(signatureAlgorithm);
                     header.addStringValue("crlUpdate", "Scheduled");
@@ -397,7 +397,7 @@ public class UpdateCRL extends CMSServlet {
                 crlIssuingPoint.isCRLCacheTestingEnabled() &&
                 (!mTesting.contains(crlIssuingPointId))) {
 
-            CMS.debug("UpdateCRL: CRL test started");
+            logger.debug("UpdateCRL: CRL test started");
 
             mTesting.add(crlIssuingPointId);
             BigInteger addLen = null;
@@ -413,7 +413,7 @@ public class UpdateCRL extends CMSServlet {
             }
 
             if (addLen != null && startFrom != null) {
-                Date revocationDate = CMS.getCurrentDate();
+                Date revocationDate = new Date();
                 String err = null;
 
                 CRLExtensions entryExts = crlEntryExtensions(reason, invalidity);
@@ -472,12 +472,12 @@ public class UpdateCRL extends CMSServlet {
                 }
 
             } else {
-                CMS.debug("UpdateCRL: CRL test error: missing parameters");
+                logger.debug("UpdateCRL: CRL test error: missing parameters");
                 header.addStringValue("crlUpdate", "missingParameters");
             }
 
             mTesting.remove(crlIssuingPointId);
-            CMS.debug("UpdateCRL: CRL test finished");
+            logger.debug("UpdateCRL: CRL test finished");
             return;
 
         } else if (test != null && test.equals("true") &&
@@ -492,7 +492,7 @@ public class UpdateCRL extends CMSServlet {
             return;
         }
 
-        CMS.debug("UpdateCRL: updating CRL");
+        logger.debug("UpdateCRL: updating CRL");
 
         try {
             EBaseException publishError = null;
@@ -536,38 +536,32 @@ public class UpdateCRL extends CMSServlet {
                 authMgr = authToken.getInString(AuthToken.TOKEN_AUTHMGR_INST_NAME);
             }
 
-            long endTime = CMS.getCurrentDate().getTime();
+            long endTime = new Date().getTime();
 
             if (crlIssuingPoint.getNextUpdate() != null) {
-                mLogger.log(ILogger.EV_AUDIT, ILogger.S_OTHER,
-                        AuditFormat.LEVEL,
+                logger.info(
                         AuditFormat.CRLUPDATEFORMAT,
-                        new Object[] {
-                                AuditFormat.FROMAGENT + " agentID: " + agentId,
-                                authMgr,
-                                "completed",
-                                crlIssuingPoint.getId(),
-                                crlIssuingPoint.getCRLNumber(),
-                                crlIssuingPoint.getLastUpdate(),
-                                crlIssuingPoint.getNextUpdate(),
-                                Long.toString(crlIssuingPoint.getCRLSize())
-                                        + " time: " + (endTime - startTime) }
-                        );
+                        AuditFormat.FROMAGENT + " agentID: " + agentId,
+                        authMgr,
+                        "completed",
+                        crlIssuingPoint.getId(),
+                        crlIssuingPoint.getCRLNumber(),
+                        crlIssuingPoint.getLastUpdate(),
+                        crlIssuingPoint.getNextUpdate(),
+                        crlIssuingPoint.getCRLSize() + " time: " + (endTime - startTime)
+                );
             } else {
-                mLogger.log(ILogger.EV_AUDIT, ILogger.S_OTHER,
-                        AuditFormat.LEVEL,
+                logger.info(
                         AuditFormat.CRLUPDATEFORMAT,
-                        new Object[] {
-                                AuditFormat.FROMAGENT + " agentID: " + agentId,
-                                authMgr,
-                                "completed",
-                                crlIssuingPoint.getId(),
-                                crlIssuingPoint.getCRLNumber(),
-                                crlIssuingPoint.getLastUpdate(),
-                                "not set",
-                                Long.toString(crlIssuingPoint.getCRLSize())
-                                        + " time: " + (endTime - startTime) }
-                        );
+                        AuditFormat.FROMAGENT + " agentID: " + agentId,
+                        authMgr,
+                        "completed",
+                        crlIssuingPoint.getId(),
+                        crlIssuingPoint.getCRLNumber(),
+                        crlIssuingPoint.getLastUpdate(),
+                        "not set",
+                        crlIssuingPoint.getCRLSize() + " time: " + (endTime - startTime)
+                );
             }
 
         } catch (EBaseException e) {
