@@ -27,24 +27,28 @@ import java.util.Iterator;
 import java.util.Properties;
 import java.util.Set;
 
-import javax.servlet.http.HttpServletResponse;
 import javax.ws.rs.core.MultivaluedMap;
 
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.velocity.context.Context;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.crypto.CryptoStore;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.ObjectNotFoundException;
 import org.mozilla.jss.crypto.PrivateKey;
 import org.mozilla.jss.crypto.X509Certificate;
+import org.mozilla.jss.netscape.security.pkcs.PKCS10;
+import org.mozilla.jss.netscape.security.x509.CertificateExtensions;
+import org.mozilla.jss.netscape.security.x509.CertificateIssuerName;
+import org.mozilla.jss.netscape.security.x509.X500Name;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
+import org.mozilla.jss.netscape.security.x509.X509CertInfo;
+import org.mozilla.jss.netscape.security.x509.X509Key;
 import org.mozilla.jss.pkcs11.PK11Store;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.xml.sax.SAXException;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.ConflictingOperationException;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.EPropertyNotFound;
@@ -53,26 +57,19 @@ import com.netscape.certsrv.base.MetaInfo;
 import com.netscape.certsrv.ca.ICertificateAuthority;
 import com.netscape.certsrv.dbs.certdb.ICertRecord;
 import com.netscape.certsrv.dbs.certdb.ICertificateRepository;
-import com.netscape.certsrv.profile.CertInfoProfile;
 import com.netscape.certsrv.profile.IEnrollProfile;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.certsrv.usrgrp.IGroup;
-import com.netscape.certsrv.usrgrp.IUGSubsystem;
 import com.netscape.certsrv.usrgrp.IUser;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 import com.netscape.cmsutil.xml.XMLObject;
 
-import netscape.security.pkcs.PKCS10;
-import netscape.security.x509.CertificateExtensions;
-import netscape.security.x509.CertificateIssuerName;
-import netscape.security.x509.X500Name;
-import netscape.security.x509.X509CertImpl;
-import netscape.security.x509.X509CertInfo;
-import netscape.security.x509.X509Key;
-
 public class CertUtil {
 
     public final static Logger logger = LoggerFactory.getLogger(CertUtil.class);
@@ -80,12 +77,12 @@ public class CertUtil {
     static final int LINE_COUNT = 76;
 
     public static X509CertImpl createRemoteCert(String hostname,
-            int port, MultivaluedMap<String, String> content, HttpServletResponse response)
+            int port, MultivaluedMap<String, String> content)
             throws Exception {
 
         logger.debug("CertUtil: content: " + content);
 
-        String c = ConfigurationUtils.post(hostname, port, true, "/ca/ee/ca/profileSubmit", content, null, null);
+        String c = Configurator.post(hostname, port, true, "/ca/ee/ca/profileSubmit", content, null, null);
 
         if (c != null) {
             ByteArrayInputStream bis = new ByteArrayInputStream(c.getBytes());
@@ -121,66 +118,67 @@ public class CertUtil {
         }
     }
 
-    public static PKCS10 getPKCS10(IConfigStore config, String prefix,
-            Cert certObj, Context context) throws IOException {
+    public static PKCS10 getPKCS10(
+            IConfigStore config,
+            String prefix,
+            Cert certObj) throws Exception {
+
         String certTag = certObj.getCertTag();
+        logger.info("CertUtil: Generating CSR for " + certTag);
 
-        X509Key pubk = null;
-        try {
-            String pubKeyType = config.getString(
-                        prefix + certTag + ".keytype");
-            String algorithm = config.getString(
-                        prefix + certTag + ".keyalgorithm");
-            if (pubKeyType.equals("rsa")) {
-                String pubKeyModulus = config.getString(
-                        prefix + certTag + ".pubkey.modulus");
-                String pubKeyPublicExponent = config.getString(
-                        prefix + certTag + ".pubkey.exponent");
-                pubk = CryptoUtil.getPublicX509Key(
-                        CryptoUtil.string2byte(pubKeyModulus),
-                        CryptoUtil.string2byte(pubKeyPublicExponent));
-            } else if (pubKeyType.equals("ecc")) {
-                String pubKeyEncoded = config.getString(
-                        prefix + certTag + ".pubkey.encoded");
-                pubk = CryptoUtil.getPublicX509ECCKey(
-                        CryptoUtil.string2byte(pubKeyEncoded));
-            } else {
-                logger.error("CertUtil: getPKCS10() - "
-                        + "public key type is unsupported: " + pubKeyType);
-                throw new IOException("Public key type is unsupported: " + pubKeyType);
-            }
+        String dn = config.getString(prefix + certTag + ".dn");
+        logger.debug("CertUtil: subject: " + dn);
 
-            if (pubk != null) {
-                logger.debug("CertUtil: got public key");
-            } else {
-                logger.error("CertUtil: error getting public key null");
-                throw new IOException("public key is null");
-            }
-            // get private key
-            String privKeyID = config.getString(prefix + certTag + ".privkey.id");
-            byte[] keyIDb = CryptoUtil.decodeKeyID(privKeyID);
+        String keyType = config.getString(prefix + certTag + ".keytype");
 
-            PrivateKey privk = CryptoUtil.findPrivateKeyFromID(keyIDb);
+        X509Key publicKey;
 
-            if (privk != null) {
-                logger.debug("CertUtil: got private key");
-            } else {
-                logger.warn("CertUtil: error getting private key null");
-            }
+        if (keyType.equals("rsa")) {
 
-            // construct cert request
-            String dn = config.getString(prefix + certTag + ".dn");
+            String pubKeyModulus = config.getString(prefix + certTag + ".pubkey.modulus");
+            String pubKeyPublicExponent = config.getString(prefix + certTag + ".pubkey.exponent");
 
-            return CryptoUtil.createCertificationRequest(dn, pubk,
-                    privk, algorithm);
+            publicKey = CryptoUtil.getPublicX509Key(
+                    CryptoUtil.string2byte(pubKeyModulus),
+                    CryptoUtil.string2byte(pubKeyPublicExponent));
 
-        } catch (Throwable e) {
-            logger.error("CertUtil: getPKCS10: " + e, e);
-            if (context != null) {
-                context.put("errorString", e.toString());
-            }
-            throw new IOException(e);
+        } else if (keyType.equals("ecc")) {
+
+            String pubKeyEncoded = config.getString(prefix + certTag + ".pubkey.encoded");
+
+            publicKey = CryptoUtil.getPublicX509ECCKey(CryptoUtil.string2byte(pubKeyEncoded));
+
+        } else {
+            logger.error("CertUtil: Unsupported public key type: " + keyType);
+            throw new IOException("Unsupported public key type: " + keyType);
         }
+
+        if (publicKey == null) {
+            logger.error("CertUtil: Unable to get public key for " + certTag);
+            throw new IOException("Unable to get public key for " + certTag);
+        }
+
+        logger.debug("CertUtil: public key: " + publicKey.getAlgorithm());
+
+        String privateKeyID = config.getString(prefix + certTag + ".privkey.id");
+        byte[] keyID = CryptoUtil.decodeKeyID(privateKeyID);
+
+        PrivateKey privateKey = CryptoUtil.findPrivateKeyFromID(keyID);
+
+        if (privateKey == null) {
+            logger.warn("CertUtil: Unable to get private key for " + certTag);
+            throw new IOException("Unable to get private key for " + certTag);
+        }
+
+        logger.debug("CertUtil: private key: " + privateKey.getAlgorithm());
+
+        String algorithm = config.getString(prefix + certTag + ".keyalgorithm");
+
+        return CryptoUtil.createCertificationRequest(
+                dn,
+                publicKey,
+                privateKey,
+                algorithm);
     }
 
 
@@ -359,7 +357,8 @@ public class CertUtil {
             return;
         }
 
-        ICertificateAuthority ca = (ICertificateAuthority) CMS.getSubsystem(ICertificateAuthority.ID);
+        CMSEngine engine = CMS.getCMSEngine();
+        ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
         IRequestQueue queue = ca.getRequestQueue();
 
         IRequest req = queue.findRequest(new RequestId(reqId));
@@ -482,7 +481,8 @@ public class CertUtil {
             keyAlgorithm = config.getString(prefix + certTag + ".keyalgorithm");
         }
 
-        ICertificateAuthority ca = (ICertificateAuthority) CMS.getSubsystem(ICertificateAuthority.ID);
+        CMSEngine engine = CMS.getCMSEngine();
+        ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
         ICertificateRepository cr = ca.getCertificateRepository();
 
         X509CertInfo info;
@@ -612,7 +612,8 @@ public class CertUtil {
                 cert.getSerialNumber() + ", " +
                 cert.getSubjectDN() + ")");
 
-        ICertificateAuthority ca = (ICertificateAuthority) CMS.getSubsystem(ICertificateAuthority.ID);
+        CMSEngine engine = CMS.getCMSEngine();
+        ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
         ICertificateRepository cr = ca.getCertificateRepository();
 
         MetaInfo meta = new MetaInfo();
@@ -624,14 +625,16 @@ public class CertUtil {
     }
 
     public static void addUserCertificate(X509CertImpl cert) {
-        IConfigStore cs = CMS.getConfigStore();
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
         int num = 0;
         try {
             num = cs.getInteger("preop.subsystem.count", 0);
         } catch (Exception e) {
             logger.warn("Unable to retrieve server configuration: " + e, e);
         }
-        IUGSubsystem system = (IUGSubsystem) (CMS.getSubsystem(IUGSubsystem.ID));
+
+        UGSubsystem system = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
         String id = "user" + num;
 
         try {
@@ -726,7 +729,8 @@ public class CertUtil {
 
     public static boolean privateKeyExistsOnToken(String certTag,
             String tokenname, String nickname) {
-        IConfigStore cs = CMS.getConfigStore();
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
         String givenid = "";
         try {
             givenid = cs.getString("preop.cert." + certTag + ".privkey.id");
