@@ -17,8 +17,9 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.cms.servlet.csadmin;
 
-import java.io.IOException;
 import java.io.FileInputStream;
+import java.io.FileNotFoundException;
+import java.io.IOException;
 import java.util.Locale;
 
 import javax.servlet.ServletConfig;
@@ -26,19 +27,20 @@ import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import org.apache.commons.io.IOUtils;
+import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.w3c.dom.Node;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.cms.servlet.base.CMSServlet;
 import com.netscape.cms.servlet.base.UserInfo;
 import com.netscape.cms.servlet.common.CMSRequest;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmsutil.xml.XMLObject;
-import org.apache.commons.io.IOUtils;
-import org.apache.commons.lang.StringUtils;
 
 public class GetStatus extends CMSServlet {
 
@@ -71,11 +73,12 @@ public class GetStatus extends CMSServlet {
         logger.debug("GetStatus: process()");
 
         HttpServletResponse httpResp = cmsReq.getHttpResp();
-        IConfigStore config = CMS.getConfigStore();
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore config = engine.getConfigStore();
 
         String state = config.getString("cs.state", "");
         String type = config.getString("cs.type", "");
-        String status = CMS.getServerStatus();
+        String status = engine.isReady() ? "running" : "starting";
         String version = GetStatus.class.getPackage().getImplementationVersion();
 
         try {
@@ -126,32 +129,36 @@ public class GetStatus extends CMSServlet {
     }
 
     /**
-     * Return the product version if the file: /usr/share/pki/CS_SERVER_VERSION
-     * exists.
+     * Return the product version in /usr/share/pki/CS_SERVER_VERSION
+     * which is provided by the server theme package.
      *
      * Caller only cares if there is a string or not, exceptions handled here.
      */
-    private String getProductVersion(String versionFilePathName) {
-        String version = null;
+    private String getProductVersion(String versionFilePathName) throws IOException {
+
         FileInputStream inputStream = null;
 
-        if(StringUtils.isEmpty(versionFilePathName)) {
-            CMS.debug("Missing product version file path!");
+        if (StringUtils.isEmpty(versionFilePathName)) {
+            logger.warn("Missing product version file path!");
             return null;
         }
 
         try {
             inputStream = new FileInputStream(versionFilePathName);
-            String contents = IOUtils.toString(inputStream);
+            String version = IOUtils.toString(inputStream);
 
-            if(contents != null) {
-                CMS.debug("Returning product version: " + version);
-                version = contents.trim();
+            if (version != null) {
+                version = version.trim();
+                logger.debug("Returning product version: " + version);
             }
-        } catch (Exception e) {
-            CMS.debug("Failed to read product version String. " + e);
-        }
-        finally {
+
+            return version;
+
+        } catch (FileNotFoundException e) {
+            // CS_SERVER_VERSION does not exist
+            return null;
+
+        } finally {
             if(inputStream != null) {
                 try {
                     inputStream.close();
@@ -159,6 +166,5 @@ public class GetStatus extends CMSServlet {
                 }
             }
         }
-        return version;
     }
 }
