@@ -23,10 +23,10 @@ import java.util.Enumeration;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.ldap.ILdapConnFactory;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
 import com.netscape.cmsutil.ldap.LDAPUtil;
 
@@ -47,7 +47,8 @@ public class ReplicationUtil {
 
         logger.info("ReplicationUtil: setting up replication");
 
-        IConfigStore cs = CMS.getConfigStore();
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
         IConfigStore masterCfg = cs.getSubStore("preop.internaldb.master");
         IConfigStore replicaCfg = cs.getSubStore("internaldb");
 
@@ -81,13 +82,13 @@ public class ReplicationUtil {
 
         try {
             logger.info("ReplicationUtil: connecting to master");
-            ILdapConnFactory masterFactory = new LdapBoundConnFactory("ConfigurationUtils");
-            masterFactory.init(masterCfg);
+            LdapBoundConnFactory masterFactory = new LdapBoundConnFactory("ReplicationUtil");
+            masterFactory.init(cs, masterCfg, engine.getPasswordStore());
             masterConn = masterFactory.getConn();
 
             logger.info("ReplicationUtil: connecting to replica");
-            ILdapConnFactory replicaFactory = new LdapBoundConnFactory("ConfigurationUtils");
-            replicaFactory.init(replicaCfg);
+            LdapBoundConnFactory replicaFactory = new LdapBoundConnFactory("ReplicationUtil");
+            replicaFactory.init(cs, replicaCfg, engine.getPasswordStore());
             replicaConn = replicaFactory.getConn();
 
             String replicadn = "cn=replica,cn=\"" + suffix + "\",cn=mapping tree,cn=config";
@@ -151,7 +152,7 @@ public class ReplicationUtil {
 
             // remove master ldap password from password.conf (if present)
             String passwordFile = cs.getString("passwordFile");
-            IConfigStore psStore = CMS.createFileConfigStore(passwordFile);
+            IConfigStore psStore = engine.createFileConfigStore(passwordFile);
             psStore.remove("master_internaldb");
             psStore.commit(false);
 
