@@ -35,31 +35,35 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.EPropertyNotFound;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.ISecurityDomainSessionTable;
 import com.netscape.certsrv.base.PKIException;
+import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.base.UnauthorizedException;
-import com.netscape.certsrv.ldap.ILdapConnFactory;
 import com.netscape.certsrv.logging.AuditEvent;
 import com.netscape.certsrv.logging.ILogger;
+import com.netscape.certsrv.logging.event.ConfigRoleEvent;
 import com.netscape.certsrv.logging.event.RoleAssumeEvent;
 import com.netscape.certsrv.system.DomainInfo;
 import com.netscape.certsrv.system.InstallToken;
 import com.netscape.certsrv.system.SecurityDomainHost;
 import com.netscape.certsrv.system.SecurityDomainSubsystem;
-import com.netscape.certsrv.usrgrp.IUGSubsystem;
 import com.netscape.cms.servlet.processors.CAProcessor;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
 import com.netscape.cmscore.security.JssSubsystem;
+import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmsutil.xml.XMLObject;
 
 import netscape.ldap.LDAPAttribute;
 import netscape.ldap.LDAPAttributeSet;
 import netscape.ldap.LDAPConnection;
 import netscape.ldap.LDAPEntry;
+import netscape.ldap.LDAPException;
+import netscape.ldap.LDAPModification;
 import netscape.ldap.LDAPSearchConstraints;
 import netscape.ldap.LDAPSearchResults;
 
@@ -68,14 +72,18 @@ import netscape.ldap.LDAPSearchResults;
  */
 public class SecurityDomainProcessor extends CAProcessor {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(SecurityDomainProcessor.class);
+
     public final static String[] TYPES = { "CA", "KRA", "OCSP", "TKS", "RA", "TPS" };
+    public final static String SUCCESS = "0";
+    public final static String FAILED = "1";
 
-    SecureRandom random = null;
-
+    SecureRandom random;
 
     public SecurityDomainProcessor(Locale locale) throws EPropertyNotFound, EBaseException {
         super("securitydomain", locale);
-        JssSubsystem jssSubsystem = (JssSubsystem) CMS.getSubsystem(JssSubsystem.ID);
+        CMSEngine engine = CMS.getCMSEngine();
+        JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
         random = jssSubsystem.getRandomNumberGenerator();
     }
 
@@ -89,10 +97,11 @@ public class SecurityDomainProcessor extends CAProcessor {
             String subsystem) throws Exception {
 
         subsystem = subsystem.toUpperCase();
-        IUGSubsystem ugSubsystem = (IUGSubsystem) CMS.getSubsystem(IUGSubsystem.ID);
+        CMSEngine engine = CMS.getCMSEngine();
+        UGSubsystem ugSubsystem = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
 
         String group = getEnterpriseGroupName(subsystem);
-        CMS.debug("SecurityDomainProcessor: group: " + group);
+        logger.debug("SecurityDomainProcessor: group: " + group);
 
         if (!ugSubsystem.isMemberOf(user, group)) {
 
@@ -111,7 +120,7 @@ public class SecurityDomainProcessor extends CAProcessor {
         try {
             ip = InetAddress.getByName(host).getHostAddress();
         } catch (Exception e) {
-            CMS.debug("Unable to determine IP address for " + host + ": " + e);
+            logger.warn("Unable to determine IP address for " + host + ": " + e.getMessage(), e);
         }
 
         // generate random session ID
@@ -122,7 +131,7 @@ public class SecurityDomainProcessor extends CAProcessor {
         String auditParams = "operation;;issue_token+token;;" + sessionID + "+ip;;" + ip +
                       "+uid;;" + user + "+groupname;;" + group;
 
-        ISecurityDomainSessionTable ctable = CMS.getSecurityDomainSessionTable();
+        ISecurityDomainSessionTable ctable = engine.getSecurityDomainSessionTable();
         int status = ctable.addEntry(sessionID, ip, user, group);
         String message;
 
@@ -151,26 +160,29 @@ public class SecurityDomainProcessor extends CAProcessor {
 
     public DomainInfo getDomainInfo() throws EBaseException {
 
-        ILdapConnFactory connFactory = null;
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
+
+        LdapBoundConnFactory connFactory = null;
         LDAPConnection conn = null;
 
         try {
             LDAPSearchConstraints cons = null;
             String[] attrs = null;
 
-            IConfigStore cs = CMS.getConfigStore();
             String basedn = cs.getString("internaldb.basedn");
             String dn = "ou=Security Domain," + basedn;
             String filter = "objectclass=pkiSecurityGroup";
 
             IConfigStore ldapConfig = cs.getSubStore("internaldb");
             connFactory = new LdapBoundConnFactory("SecurityDomainProcessor");
-            connFactory.init(ldapConfig);
+            connFactory.init(cs, ldapConfig, engine.getPasswordStore());
+
             conn = connFactory.getConn();
 
             // get the security domain name
-            String name = (String) conn.read(dn).getAttribute("name").getStringValues().nextElement();
-            CMS.debug("SecurityDomainProcessor: name: "+name);
+            String name = conn.read(dn).getAttribute("name").getStringValues().nextElement();
+            logger.debug("SecurityDomainProcessor: name: " + name);
 
             DomainInfo domain = new DomainInfo();
             domain.setName(name);
@@ -183,7 +195,7 @@ public class SecurityDomainProcessor extends CAProcessor {
                 dn = res.next().getDN();
                 String listName = dn.substring(3, dn.indexOf(","));
                 String subType = listName.substring(0, listName.indexOf("List"));
-                CMS.debug("SecurityDomainProcessor: subtype: "+subType);
+                logger.debug("SecurityDomainProcessor: subtype: " + subType);
 
                 filter = "objectclass=pkiSubsystem";
                 LDAPSearchResults res2 = conn.search(dn, LDAPConnection.SCOPE_ONE, filter,
@@ -191,7 +203,7 @@ public class SecurityDomainProcessor extends CAProcessor {
 
                 while (res2.hasMoreElements()) {
                     LDAPEntry entry = res2.next();
-                    CMS.debug("SecurityDomainProcessor:  - "+entry.getDN());
+                    logger.debug("SecurityDomainProcessor:  - " + entry.getDN());
 
                     SecurityDomainHost host = new SecurityDomainHost();
 
@@ -202,8 +214,8 @@ public class SecurityDomainProcessor extends CAProcessor {
                     while (attrsInSet.hasMoreElements()) {
                         LDAPAttribute nextAttr = attrsInSet.nextElement();
                         String attrName = nextAttr.getName();
-                        String attrValue = (String) nextAttr.getStringValues().nextElement();
-                        CMS.debug("SecurityDomainProcessor:    - "+attrName+": "+attrValue);
+                        String attrValue = nextAttr.getStringValues().nextElement();
+                        logger.debug("SecurityDomainProcessor:    - " + attrName+": " + attrValue);
 
                         if ("Host".equalsIgnoreCase(attrName)) {
                             host.setHostname(attrValue);
@@ -245,12 +257,12 @@ public class SecurityDomainProcessor extends CAProcessor {
             return domain;
 
         } catch (Exception e) {
-            CMS.debug("SecurityDomainProcessor: Failed to read domain info from ldap " + e);
+            logger.error("SecurityDomainProcessor: Failed to read domain info from ldap " + e.getMessage(), e);
             throw new EBaseException(e.getMessage(), e);
 
         } finally {
             if (conn != null && connFactory != null) {
-                CMS.debug("Releasing ldap connection");
+                logger.debug("Releasing ldap connection");
                 connFactory.returnConn(conn);
             }
         }
@@ -370,6 +382,244 @@ public class SecurityDomainProcessor extends CAProcessor {
         return domain;
     }
 
+    public String removeHost(
+            String dn,
+            String type,
+            String hostname,
+            String securePort,
+            String agentSecurePort)
+            throws EBaseException {
+
+        logger.info("SecurityDomainProcessor: Removing host " + dn);
+
+        String auditSubjectID = auditSubjectID();
+
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
+        String baseDN = cs.getString("internaldb.basedn");
+
+        String status = removeEntry(dn);
+
+        if (!status.equals(SUCCESS)) {
+            return status;
+        }
+
+        String adminUserDN;
+        if (agentSecurePort != null && !agentSecurePort.equals("")) {
+            adminUserDN = "uid=" + type + "-" + hostname + "-" + agentSecurePort + ",ou=People," + baseDN;
+        } else {
+            adminUserDN = "uid=" + type + "-" + hostname + "-" + securePort + ",ou=People," + baseDN;
+        }
+
+        logger.info("SecurityDomainProcessor: Removing admin " + adminUserDN);
+
+        String userAuditParams = "Scope;;users+Operation;;OP_DELETE+source;;SecurityDomainProcessor" +
+                                     "+resource;;" + adminUserDN;
+
+        status = removeEntry(adminUserDN);
+
+        if (!status.equals(SUCCESS)) {
+            signedAuditLogger.log(new ConfigRoleEvent(
+                    auditSubjectID,
+                    ILogger.FAILURE,
+                    userAuditParams));
+            return status;
+        }
+
+        signedAuditLogger.log(new ConfigRoleEvent(
+                               auditSubjectID,
+                               ILogger.SUCCESS,
+                               userAuditParams));
+
+        dn = "cn=Subsystem Group, ou=groups," + baseDN;
+
+        logger.info("SecurityDomainProcessor: Removing admin from group " + dn);
+
+        userAuditParams = "Scope;;groups+Operation;;OP_DELETE_USER" +
+                              "+source;;SecurityDomainProcessor" +
+                              "+resource;;Subsystem Group+user;;" + adminUserDN;
+
+        LDAPModification mod = new LDAPModification(
+                LDAPModification.DELETE,
+                new LDAPAttribute("uniqueMember", adminUserDN));
+
+        status = modifyEntry(dn, mod);
+
+        if (!status.equals(SUCCESS)) {
+            signedAuditLogger.log(new ConfigRoleEvent(
+                                   auditSubjectID,
+                                   ILogger.FAILURE,
+                                   userAuditParams));
+            return status;
+        }
+
+        signedAuditLogger.log(new ConfigRoleEvent(
+                auditSubjectID,
+                ILogger.SUCCESS,
+                userAuditParams));
+
+        return SUCCESS;
+    }
+
+    public String addEntry(LDAPEntry entry) {
+
+        logger.info("SecurityDomainProcessor: Adding entry " + entry.getDN());
+
+        String status = SUCCESS;
+        LdapBoundConnFactory connFactory = null;
+        LDAPConnection conn = null;
+
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
+
+        try {
+            IConfigStore ldapConfig = cs.getSubStore("internaldb");
+            connFactory = new LdapBoundConnFactory("UpdateDomainXML");
+            connFactory.init(cs, ldapConfig, engine.getPasswordStore());
+
+            conn = connFactory.getConn();
+            conn.add(entry);
+
+        } catch (LDAPException e) {
+            if (e.getLDAPResultCode() == LDAPException.ENTRY_ALREADY_EXISTS) {
+                logger.warn("SecurityDomainProcessor: Entry already exists");
+                try {
+                    conn.delete(entry.getDN());
+                    conn.add(entry);
+
+                } catch (LDAPException ee) {
+                    logger.error("SecurityDomainProcessor: Unable to replace entry: " + e.getMessage(), e);
+                    status = FAILED;
+                }
+
+            } else {
+                logger.error("SecurityDomainProcessor: Unable to add entry: " + e.getMessage(), e);
+                status = FAILED;
+            }
+
+        } catch (Exception e) {
+            logger.warn("SecurityDomainProcessor: Unable to add entry: " + e.getMessage(), e);
+
+        } finally {
+            try {
+                if (conn != null && connFactory != null) {
+                    logger.debug("SecurityDomainProcessor: Releasing LDAP connection");
+                    connFactory.returnConn(conn);
+                }
+
+            } catch (Exception e) {
+                logger.warn("SecurityDomainProcessor: Unable to release LDAP connection: " + e.getMessage(), e);
+            }
+        }
+
+        return status;
+    }
+
+    public String modifyEntry(String dn, LDAPModification mod) {
+
+        logger.info("SecurityDomainProcessor: Modifying entry " + dn);
+
+        String status = SUCCESS;
+        LdapBoundConnFactory connFactory = null;
+        LDAPConnection conn = null;
+
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
+
+        try {
+            IConfigStore ldapConfig = cs.getSubStore("internaldb");
+            connFactory = new LdapBoundConnFactory("UpdateDomainXML");
+            connFactory.init(cs, ldapConfig, engine.getPasswordStore());
+
+            conn = connFactory.getConn();
+            conn.modify(dn, mod);
+
+        } catch (LDAPException e) {
+            int resultCode = e.getLDAPResultCode();
+            if (resultCode != LDAPException.NO_SUCH_OBJECT && resultCode != LDAPException.NO_SUCH_ATTRIBUTE) {
+                logger.error("SecurityDomainProcessor: Unable to modify entry: " + e.getMessage(), e);
+                status = FAILED;
+            }
+
+        } catch (Exception e) {
+            logger.warn("SecurityDomainProcessor: Unable to modify entry: " + e.getMessage(), e);
+
+        } finally {
+            try {
+                if (conn != null && connFactory != null) {
+                    logger.debug("SecurityDomainProcessor: Releasing LDAP connection");
+                    connFactory.returnConn(conn);
+                }
+
+            } catch (Exception e) {
+                logger.warn("SecurityDomainProcessor: Unable to release LDAP connection: " + e.getMessage(), e);
+            }
+        }
+
+        return status;
+    }
+
+    public String removeEntry(String dn) {
+
+        logger.info("SecurityDomainProcessor: Removing entry " + dn);
+
+        String status = SUCCESS;
+        LdapBoundConnFactory connFactory = null;
+        LDAPConnection conn = null;
+
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
+
+        try {
+            IConfigStore ldapConfig = cs.getSubStore("internaldb");
+            connFactory = new LdapBoundConnFactory("UpdateDomainXML");
+            connFactory.init(cs, ldapConfig, engine.getPasswordStore());
+
+            conn = connFactory.getConn();
+            conn.delete(dn);
+
+        } catch (LDAPException e) {
+            int resultCode = e.getLDAPResultCode();
+            if (resultCode != LDAPException.NO_SUCH_OBJECT) {
+                status = FAILED;
+                logger.error("SecurityDomainProcessor: Unable to delete entry: " + e.getMessage(), e);
+            }
+
+        } catch (Exception e) {
+            logger.warn("SecurityDomainProcessor: Unable to delete entry: " + e.getMessage(), e);
+
+        } finally {
+            try {
+                if (conn != null && connFactory != null) {
+                    logger.debug("SecurityDomainProcessor: Releasing LDAP connection");
+                    connFactory.returnConn(conn);
+                }
+
+            } catch (Exception e) {
+                logger.warn("SecurityDomainProcessor: Unable to release LDAP connection: " + e.getMessage(), e);
+            }
+        }
+
+        return status;
+    }
+
+    protected String auditSubjectID() {
+
+        SessionContext auditContext = SessionContext.getExistingContext();
+
+        if (auditContext == null) {
+            return ILogger.UNIDENTIFIED;
+        }
+
+        String subjectID = (String) auditContext.get(SessionContext.USER_ID);
+
+        if (subjectID == null) {
+            return ILogger.NONROLEUSER;
+        }
+
+        return subjectID.trim();
+    }
+
     public static void main(String args[]) throws Exception {
 
         DomainInfo before = new DomainInfo();
