@@ -21,11 +21,12 @@ import org.mozilla.jss.crypto.JSSMessageDigest;
 import org.mozilla.jss.crypto.SymmetricKey;
 import org.mozilla.jss.crypto.TokenException;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 
 public class NistSP800_108KDF extends KDF {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(NistSP800_108KDF.class);
+
     static final int KDF_OUTPUT_SIZE_BITS = 384;
     static final int KDF_OUTPUT_SIZE_BYTES = KDF_OUTPUT_SIZE_BITS / 8;
     static final int KEY_DATA_SIZE_BYTES = KDF_OUTPUT_SIZE_BYTES / 3;
@@ -141,6 +142,18 @@ public class NistSP800_108KDF extends KDF {
     }
 
     //Compute the AES based CMAC operation. Used to derive session keys and cryptograms
+    //
+  
+    // Stub version:
+
+     public byte[] kdf_AES_CMAC_SCP03(SymmetricKey masterKey, byte[] context, byte kdfConstant,
+            int kdfOutputSizeBytes) throws EBaseException {
+
+	    throw new EBaseException("Not Implemented!");
+     } 
+
+    // Comment out for now until can be moved
+    /*
     public byte[] kdf_AES_CMAC_SCP03(SymmetricKey masterKey, byte[] context, byte kdfConstant,
             int kdfOutputSizeBytes) throws EBaseException {
 
@@ -212,18 +225,28 @@ public class NistSP800_108KDF extends KDF {
 
         return output.toByteArray();
     }
+    */
 
     /*******************************************************************************
      Key Derivation Function in Counter Mode using PRF = SHA256HMAC (NIST SP 800-108)
        Calculates 384 bits of diversified output from the provided master key (K_I)
     *******************************************************************************/
 
+     // Stub:
+     private byte[] kdf_CM_SHA256_HMAC_L384(SymmetricKey masterKey, byte[] context, byte kdfLabel,
+            int kdfOutputSizeBytes, CryptoToken token) throws EBaseException {
+            throw new EBaseException("Not Implemented.");
+     }
+
+    // Comment out for now.
+
+    /*
     private byte[] kdf_CM_SHA256_HMAC_L384(SymmetricKey masterKey, byte[] context, byte kdfLabel,
             int kdfOutputSizeBytes, CryptoToken token) throws EBaseException {
 
         String method = "NistSP800_108KDF.kdf_CM_SHA256_HMAC_L384:";
 
-        CMS.debug(method + " entering..");
+        logger.debug(method + " entering..");
         final byte n = 2; // ceil(384 / (SHA256LENGTH * 8)) == 2
         int L_BYTE_array_length = 2; // 384 = 0x0180 hex; 2 byte long representation
 
@@ -261,12 +284,12 @@ public class NistSP800_108KDF extends KDF {
         for (byte i = 1; i <= n; i++) {
             hmac_data_input[0] = i;
             outputHMAC256 = sha256HMAC(masterKey, hmac_data_input, HMAC_DATA_INPUT_SIZE, token);
-            CMS.debug(method + "outputHMAC256 len: " + outputHMAC256.length);
+            logger.debug(method + "outputHMAC256 len: " + outputHMAC256.length);
             System.arraycopy(outputHMAC256, 0, K, (i - 1) * SHA256_LENGTH, SHA256_LENGTH);
             Arrays.fill(outputHMAC256, (byte)0);
         }
 
-        CMS.debug(method + " Full array: " + K.length + " bytes...");
+        logger.debug(method + " Full array: " + K.length + " bytes...");
 
         byte[] finalOutput = new byte[KDF_OUTPUT_SIZE_BYTES];
 
@@ -274,11 +297,14 @@ public class NistSP800_108KDF extends KDF {
 
         Arrays.fill(K, (byte) 0);
 
-        CMS.debug(method + " finalOutput: " + finalOutput.length + " bytes...");
+        logger.debug(method + " finalOutput: " + finalOutput.length + " bytes...");
 
         return finalOutput;
     }
+    */
 
+
+    // This should be ok since it just uses the HMAC digest exposed by JSS from NSS.
     private byte[] sha256HMAC(SymmetricKey masterKey, // HMAC Secret Key (K_I)
             byte[] hmac_data_input, // HMAC Input (i||04||00||context||0180)
             int hMAC_DATA_INPUT_SIZE, // Input Length
@@ -286,7 +312,7 @@ public class NistSP800_108KDF extends KDF {
 
         String method = "NistSP800_108KDF.sha256HMAC:";
 
-        CMS.debug(method + " Entering...");
+        logger.debug(method + " Entering...");
 
         byte[] digestBytes = null;
 
@@ -299,9 +325,9 @@ public class NistSP800_108KDF extends KDF {
             digest.initHMAC(masterKey);
 
             digestBytes = digest.digest(hmac_data_input);
-        } catch (Exception e) {
 
-            CMS.debug(method + " Failure to HMAC the input data: " + e);
+        } catch (Exception e) {
+            logger.error(method + " Failure to HMAC the input data: " + e.getMessage(), e);
             throw new EBaseException(method + e);
         }
 
@@ -315,6 +341,15 @@ public class NistSP800_108KDF extends KDF {
     // For now calling code only using 128
     // Will move later to common class used by both tks and tps
 
+    // Stub:
+
+     public static byte[] computeAES_CMAC(SymmetricKey aesKey, byte[] input) throws EBaseException {
+         throw new EBaseException("Not Implemented.");
+     }
+
+    //Comment out for now.
+
+    /*
     public static byte[] computeAES_CMAC(SymmetricKey aesKey, byte[] input) throws EBaseException {
 
         String method = "NistSP800_108KDF.computeAES_CMAC:";
@@ -440,8 +475,18 @@ public class NistSP800_108KDF extends KDF {
         return encData;
 
     }
-
+    */
     // SCP03 AES-CMAC support function
+    //
+    // Stub:
+
+    private static byte[] getAES_CMAC_SubKey(byte[] input) {
+        return null;
+    }
+
+    // Comment out for now.
+
+    /*
     private static byte[] getAES_CMAC_SubKey(byte[] input) {
 
         byte[] output = new byte[input.length];
@@ -458,6 +503,7 @@ public class NistSP800_108KDF extends KDF {
         }
         return output;
     }
+    */
 
     // Collection of informal invocations of api used to create various session keys
     // Done with test data.
