@@ -25,16 +25,16 @@ import java.util.Vector;
 import org.dogtagpki.legacy.policy.IEnrollmentPolicy;
 import org.dogtagpki.legacy.server.policy.APolicyRule;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
 import com.netscape.certsrv.base.ISubsystem;
-import com.netscape.certsrv.ldap.ILdapConnFactory;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.PolicyResult;
 import com.netscape.cms.logging.Logger;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.ldapconn.LdapBoundConnFactory;
 
 import netscape.ldap.LDAPAttribute;
@@ -57,6 +57,9 @@ import netscape.ldap.LDAPv2;
  */
 public class AttributePresentConstraints extends APolicyRule
         implements IEnrollmentPolicy, IExtendedPluginInfo {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(AttributePresentConstraints.class);
+
     protected static final String PROP_ENABLED = "enabled";
     protected static final String PROP_LDAP = "ldap";
 
@@ -67,7 +70,7 @@ public class AttributePresentConstraints extends APolicyRule
 
     private IConfigStore mConfig = null;
     private IConfigStore mLdapConfig = null;
-    private ILdapConnFactory mConnFactory = null;
+    private LdapBoundConnFactory mConnFactory;
     private LDAPConnection mCheckAttrLdapConnection = null;
 
     public AttributePresentConstraints() {
@@ -239,6 +242,10 @@ public class AttributePresentConstraints extends APolicyRule
 
     public void init(ISubsystem owner, IConfigStore config)
             throws EBaseException {
+
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
+
         mConfig = config;
 
         mParamValue = new Hashtable<String, Object>();
@@ -260,9 +267,9 @@ public class AttributePresentConstraints extends APolicyRule
         mLdapConfig = mConfig.getSubStore(PROP_LDAP);
 
         mConnFactory = new LdapBoundConnFactory("AttributePresentConstraints");
-        mConnFactory.init(mLdapConfig);
-        mCheckAttrLdapConnection = mConnFactory.getConn();
+        mConnFactory.init(cs, mLdapConfig, engine.getPasswordStore());
 
+        mCheckAttrLdapConnection = mConnFactory.getConn();
     }
 
     public PolicyResult apply(IRequest r) {
@@ -326,7 +333,7 @@ public class AttributePresentConstraints extends APolicyRule
                     }
                 }
 
-                CMS.debug("AttributePresentConstraints: Attribute is present for user: \"" + userdn + "\"");
+                logger.debug("AttributePresentConstraints: Attribute is present for user: \"" + userdn + "\"");
 
             } catch (LDAPException e) {
                 log(ILogger.LL_FAILURE, CMS.getLogMessage("POLICY_PIN_UNAUTHORIZED"));
