@@ -21,7 +21,6 @@ import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.Vector;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.authentication.AuthManagerProxy;
 import com.netscape.certsrv.authentication.AuthMgrPlugin;
 import com.netscape.certsrv.authentication.EAuthException;
@@ -36,9 +35,8 @@ import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.ISubsystem;
-import com.netscape.certsrv.logging.ILogger;
-import com.netscape.cms.logging.Logger;
-import com.netscape.cmscore.util.Debug;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 
 /**
  * Default authentication subsystem
@@ -49,6 +47,9 @@ import com.netscape.cmscore.util.Debug;
  * @version $Revision$, $Date$
  */
 public class AuthSubsystem implements IAuthSubsystem {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(AuthSubsystem.class);
+
     public static final String ID = "auths";
 
     public Hashtable<String, AuthMgrPlugin> mAuthMgrPlugins = new Hashtable<String, AuthMgrPlugin>();
@@ -56,8 +57,6 @@ public class AuthSubsystem implements IAuthSubsystem {
     private String mId = "auths";
     private IConfigStore mConfig = null;
 
-    private Logger mLogger = null;
-
     // singleton enforcement
 
     private static AuthSubsystem mInstance = new AuthSubsystem();
@@ -81,8 +80,8 @@ public class AuthSubsystem implements IAuthSubsystem {
      */
     public void init(ISubsystem owner, IConfigStore config)
             throws EBaseException {
+        CMSEngine engine = CMS.getCMSEngine();
         try {
-            mLogger = Logger.getLogger();
             mConfig = config;
 
             // hardcode admin and agent plugins required for the server to be
@@ -133,9 +132,8 @@ public class AuthSubsystem implements IAuthSubsystem {
 
                 mAuthMgrPlugins.put(id, plugin);
             }
-            if (Debug.ON) {
-                Debug.trace("loaded auth plugins");
-            }
+
+            logger.debug("loaded auth plugins");
 
             // hardcode admin and agent auth manager instances for the server
             // to be functional
@@ -145,50 +143,44 @@ public class AuthSubsystem implements IAuthSubsystem {
             passwdUserDBAuth.init(PASSWDUSERDB_AUTHMGR_ID, PASSWDUSERDB_PLUGIN_ID, null);
             mAuthMgrInsts.put(PASSWDUSERDB_AUTHMGR_ID, new
                     AuthManagerProxy(true, passwdUserDBAuth));
-            if (Debug.ON) {
-                Debug.trace("loaded password based auth manager");
-            }
+
+            logger.debug("loaded password based auth manager");
 
             IAuthManager certUserDBAuth = new CertUserDBAuthentication();
 
             certUserDBAuth.init(CERTUSERDB_AUTHMGR_ID, CERTUSERDB_PLUGIN_ID, config);
             mAuthMgrInsts.put(CERTUSERDB_AUTHMGR_ID, new AuthManagerProxy(true, certUserDBAuth));
-            if (Debug.ON) {
-                Debug.trace("loaded certificate based auth manager");
-            }
+
+            logger.debug("loaded certificate based auth manager");
 
             IAuthManager challengeAuth = new ChallengePhraseAuthentication();
 
             challengeAuth.init(CHALLENGE_AUTHMGR_ID, CHALLENGE_PLUGIN_ID, config);
             mAuthMgrInsts.put(CHALLENGE_AUTHMGR_ID, new AuthManagerProxy(true, challengeAuth));
-            if (Debug.ON) {
-                Debug.trace("loaded challenge phrase auth manager");
-            }
+
+            logger.debug("loaded challenge phrase auth manager");
 
             IAuthManager cmcAuth = new com.netscape.cms.authentication.CMCAuth();
 
             cmcAuth.init(CMCAUTH_AUTHMGR_ID, CMCAUTH_PLUGIN_ID, config);
             mAuthMgrInsts.put(CMCAUTH_AUTHMGR_ID, new AuthManagerProxy(true, cmcAuth));
-            if (Debug.ON) {
-                Debug.trace("loaded cmc auth manager");
-            }
+
+            logger.debug("loaded cmc auth manager");
 
             // #56659
             // IAuthManager nullAuth = new NullAuthentication();
 
             // nullAuth.init(NULL_AUTHMGR_ID, NULL_PLUGIN_ID, config);
             // mAuthMgrInsts.put(NULL_AUTHMGR_ID, new AuthManagerProxy(true, nullAuth));
-            // if (Debug.ON) {
-            //    Debug.trace("loaded null auth manager");
-            // }
+            //
+            // logger.debug("loaded null auth manager");
 
             IAuthManager sslClientCertAuth = new SSLClientCertAuthentication();
 
             sslClientCertAuth.init(SSLCLIENTCERT_AUTHMGR_ID, SSLCLIENTCERT_PLUGIN_ID, config);
             mAuthMgrInsts.put(SSLCLIENTCERT_AUTHMGR_ID, new AuthManagerProxy(true, sslClientCertAuth));
-            if (Debug.ON) {
-                Debug.trace("loaded sslClientCert auth manager");
-            }
+
+            logger.debug("loaded sslClientCert auth manager");
 
             // get auth manager instances.
             c = config.getSubStore(PROP_INSTANCE);
@@ -196,14 +188,14 @@ public class AuthSubsystem implements IAuthSubsystem {
 
             while (instances.hasMoreElements()) {
                 String insName = instances.nextElement();
-                CMS.debug("AuthSubsystem: initializing authentication manager " + insName);
+                logger.debug("AuthSubsystem: initializing authentication manager " + insName);
 
                 String implName = c.getString(insName + "." + PROP_PLUGIN);
                 AuthMgrPlugin plugin =
                         mAuthMgrPlugins.get(implName);
 
                 if (plugin == null) {
-                    log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_CANT_FIND_PLUGIN", implName));
+                    logger.error("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_CANT_FIND_PLUGIN", implName));
                     throw new EAuthMgrPluginNotFound(CMS.getUserMessage("CMS_AUTHENTICATION_AUTHMGR_NOT_FOUND",
                             implName));
                 }
@@ -221,31 +213,31 @@ public class AuthSubsystem implements IAuthSubsystem {
                     authMgrInst.init(insName, implName, authMgrConfig);
                     isEnable = true;
 
-                    log(ILogger.LL_INFO, CMS.getLogMessage("CMSCORE_AUTH_ADD_AUTH_INSTANCE", insName));
+                    logger.info("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_ADD_AUTH_INSTANCE", insName));
 
                 } catch (ClassNotFoundException e) {
-                    log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_AUTHSUB_ERROR", e.toString()));
+                    logger.error("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_AUTHSUB_ERROR", e.toString()));
                     throw new EAuthException(CMS.getUserMessage("CMS_ACL_CLASS_LOAD_FAIL", className), e);
 
                 } catch (IllegalAccessException e) {
-                    log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_AUTHSUB_ERROR", e.toString()));
+                    logger.error("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_AUTHSUB_ERROR", e.toString()));
                     throw new EAuthException(CMS.getUserMessage("CMS_ACL_CLASS_LOAD_FAIL", className), e);
 
                 } catch (InstantiationException e) {
-                    log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_AUTHSUB_ERROR", e.toString()));
+                    logger.error("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_AUTHSUB_ERROR", e.toString()));
                     throw new EAuthException(CMS.getUserMessage("CMS_ACL_CLASS_LOAD_FAIL", className), e);
 
                 } catch (EBaseException e) {
-                    CMS.debug(e);
-                    log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_AUTH_INIT_ERROR", insName, e.toString()));
+                    String message = CMS.getLogMessage("CMSCORE_AUTH_AUTH_INIT_ERROR", insName, e.toString());
+                    logger.warn("AuthSubsystem: " + message, e);
                     // Skip the authenticaiton instance if
                     // it is mis-configurated. This give
                     // administrator another chance to
                     // fix the problem via console
 
                 } catch (Throwable e) {
-                    CMS.debug(e);
-                    log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_AUTH_INIT_ERROR", insName, e.toString()));
+                    String message = CMS.getLogMessage("CMSCORE_AUTH_AUTH_INIT_ERROR", insName, e.toString());
+                    logger.warn("AuthSubsystem: " + message, e);
                     // Skip the authenticaiton instance if
                     // it is mis-configurated. This give
                     // administrator another chance to
@@ -254,16 +246,15 @@ public class AuthSubsystem implements IAuthSubsystem {
                 // add manager instance to list.
                 mAuthMgrInsts.put(insName, new
                         AuthManagerProxy(isEnable, authMgrInst));
-                if (Debug.ON) {
-                    Debug.trace("loaded auth instance " + insName + " impl " + implName);
-                }
+
+                logger.debug("loaded auth instance " + insName + " impl " + implName);
             }
-            log(ILogger.LL_INFO, CMS.getLogMessage("INIT_DONE", getId()));
+            logger.info("AuthSubsystem: " + CMS.getLogMessage("INIT_DONE", getId()));
 
         } catch (EBaseException e) {
-            CMS.debug(e);
-            if (CMS.isPreOpMode()) {
-                CMS.debug("AuthSubsystem.init(): Swallow exception in pre-op mode");
+            logger.error("Unable to initialize AuthSubsystem: " + e.getMessage(), e);
+            if (engine.isPreOpMode()) {
+                logger.warn("AuthSubsystem.init(): Swallow exception in pre-op mode");
                 return;
             }
             throw e;
@@ -332,7 +323,7 @@ public class AuthSubsystem implements IAuthSubsystem {
         AuthMgrPlugin plugin = mAuthMgrPlugins.get(implName);
 
         if (plugin == null) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_PLUGIN_NOT_FOUND", implName));
+            logger.error("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_PLUGIN_NOT_FOUND", implName));
             throw new EAuthMgrPluginNotFound(CMS.getUserMessage("CMS_AUTHENTICATION_AUTHMGR_NOT_FOUND", implName));
         }
 
@@ -346,15 +337,14 @@ public class AuthSubsystem implements IAuthSubsystem {
             return (authMgrInst.getConfigParams());
 
         } catch (InstantiationException e) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()));
-
+            logger.error("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()), e);
             throw new EAuthException(CMS.getUserMessage("CMS_ACL_CLASS_LOAD_FAIL", className), e);
         } catch (ClassNotFoundException e) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()));
+            logger.error("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()), e);
             throw new EAuthException(CMS.getUserMessage("CMS_ACL_CLASS_LOAD_FAIL", className), e);
 
         } catch (IllegalAccessException e) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()));
+            logger.error("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()), e);
             throw new EAuthException(CMS.getUserMessage("CMS_ACL_CLASS_LOAD_FAIL", className), e);
         }
     }
@@ -436,7 +426,7 @@ public class AuthSubsystem implements IAuthSubsystem {
             authMgrInst = (IAuthManager) Class.forName(classpath).newInstance();
             return (authMgrInst);
         } catch (Exception e) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()));
+            logger.warn("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_NOT_CREATED", e.toString()), e);
             return null;
         }
     }
@@ -467,7 +457,7 @@ public class AuthSubsystem implements IAuthSubsystem {
     public void startup() throws EBaseException {
         //remove the log since it's already logged from S_ADMIN
         //String infoMsg = "Auth subsystem administration Servlet registered";
-        //log(ILogger.LL_INFO, infoMsg);
+        //logger.info("AuthSubsystem: " + infoMsg);
     }
 
     /**
@@ -479,7 +469,7 @@ public class AuthSubsystem implements IAuthSubsystem {
 
             IAuthManager mgr = proxy.getAuthManager();
 
-            log(ILogger.LL_INFO, CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_SHUTDOWN", mgr.getName()));
+            logger.info("AuthSubsystem: " + CMS.getLogMessage("CMSCORE_AUTH_INSTANCE_SHUTDOWN", mgr.getName()));
 
             mgr.shutdown();
         }
@@ -514,15 +504,4 @@ public class AuthSubsystem implements IAuthSubsystem {
     public IAuthManager getAuthManager(String name) {
         return get(name);
     }
-
-    /**
-     * logs an entry in the log file.
-     */
-    public void log(int level, String msg) {
-        if (mLogger == null)
-            return;
-        mLogger.log(ILogger.EV_SYSTEM, ILogger.S_AUTHENTICATION,
-                level, msg);
-    }
-
 }
