@@ -17,7 +17,6 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.cmscore.authentication;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.authentication.AuthToken;
 import com.netscape.certsrv.authentication.EInvalidCredentials;
 import com.netscape.certsrv.authentication.EMissingCredential;
@@ -31,6 +30,8 @@ import com.netscape.certsrv.ldap.ELdapException;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cms.logging.Logger;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.dbs.DBSubsystem;
 import com.netscape.cmscore.ldapconn.LdapAnonConnFactory;
 import com.netscape.cmscore.ldapconn.LdapConnInfo;
@@ -51,6 +52,8 @@ import netscape.ldap.LDAPException;
  */
 public class PasswdUserDBAuthentication implements IAuthManager, IPasswdUserDBAuthentication {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(PasswdUserDBAuthentication.class);
+
     /* required credentials. uid, pwd are strings */
     protected static String[] mRequiredCred = { CRED_UID, CRED_PWD };
 
@@ -82,15 +85,15 @@ public class PasswdUserDBAuthentication implements IAuthManager, IPasswdUserDBAu
         mImplName = implName;
         mConfig = config;
 
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
+
         /* internal database directory used */
         DBSubsystem dbs = (DBSubsystem) DBSubsystem.getInstance();
         LdapConnInfo ldapinfo = dbs.getLdapConnInfo();
-        if (ldapinfo == null && CMS.isPreOpMode()) {
-            CMS.debug("PasswdUserDBAuthentication.init(): Abort due to missing LDAP connection info in pre-op mode");
-            return;
-        }
 
         mAnonConnFactory = new LdapAnonConnFactory("PasswdUserDBAuthentication", 3, 20, ldapinfo);
+        mAnonConnFactory.init(cs);
 
         log(ILogger.LL_INFO, CMS.getLogMessage("CMSCORE_AUTH_INIT_AUTH", mName));
     }
@@ -118,7 +121,7 @@ public class PasswdUserDBAuthentication implements IAuthManager, IPasswdUserDBAu
 
         // make sure the required credentials are provided
         String uid = (String) authCred.get(CRED_UID);
-        CMS.debug("PasswdUserDBAuthentication: UID: " + uid);
+        logger.debug("PasswdUserDBAuthentication: UID: " + uid);
         if (uid == null) {
             log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_AUTH_MISSING_UID"));
             throw new EMissingCredential(CMS.getUserMessage("CMS_AUTHENTICATION_NULL_CREDENTIAL", CRED_UID));
@@ -142,20 +145,20 @@ public class PasswdUserDBAuthentication implements IAuthManager, IPasswdUserDBAu
         try {
             user = ug.getUser(uid);
         } catch (EBaseException e) {
-            CMS.debug(e);
             // not a user in our user/group database.
+            logger.error("Unable to authenticate user: " + e.getMessage(), e);
             log(ILogger.LL_SECURITY, CMS.getLogMessage("CMSCORE_AUTH_UID_NOT_FOUND", uid, e.toString()));
             throw new EInvalidCredentials(CMS.getUserMessage("CMS_AUTHENTICATION_INVALID_CREDENTIAL") + " " + e.getMessage());
         }
 
         if (user == null) {
-            CMS.debug("PasswdUserDBAuthentication: User not found: " + uid);
+            logger.error("PasswdUserDBAuthentication: User not found: " + uid);
             throw new EInvalidCredentials(CMS.getUserMessage("CMS_AUTHENTICATION_INTERNAL_ERROR",
                     "Failure in User Group subsystem."));
         }
 
         String userdn = user.getUserDN();
-        CMS.debug("PasswdUserDBAuthentication: DN: " + userdn);
+        logger.debug("PasswdUserDBAuthentication: DN: " + userdn);
 
         LDAPConnection anonConn = null;
 
