@@ -24,7 +24,8 @@ import java.math.BigInteger;
 import java.security.Principal;
 import java.security.cert.X509Certificate;
 
-import com.netscape.certsrv.apps.CMS;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
+
 import com.netscape.certsrv.authentication.AuthToken;
 import com.netscape.certsrv.authentication.EAuthUserError;
 import com.netscape.certsrv.authentication.EInvalidCredentials;
@@ -43,9 +44,8 @@ import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestQueue;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.cms.logging.Logger;
-import com.netscape.cmscore.util.Debug;
-
-import netscape.security.x509.X509CertImpl;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 
 /**
  * SSL client based authentication.
@@ -56,6 +56,8 @@ import netscape.security.x509.X509CertImpl;
  */
 public class SSLClientCertAuthentication implements IAuthManager {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(SSLClientCertAuthentication.class);
+
     /* required credential to authenticate, client certificate */
     public static final String CRED_CERT = IAuthManager.CRED_SSL_CLIENT_CERT;
     public static final String SERIALNUMBER = "serialNumber";
@@ -98,19 +100,20 @@ public class SSLClientCertAuthentication implements IAuthManager {
 
         AuthToken authToken = new AuthToken(this);
 
-        CMS.debug("SSLCertAuth: Retrieving client certificates");
+        logger.debug("SSLCertAuth: Retrieving client certificates");
         X509Certificate[] x509Certs =
                 (X509Certificate[]) authCred.get(CRED_CERT);
 
         if (x509Certs == null) {
-            CMS.debug("SSLCertAuth: No client certificate found");
+            logger.error("SSLCertAuth: No client certificate found");
             log(ILogger.LL_FAILURE,
                     CMS.getLogMessage("CMSCORE_AUTH_MISSING_CERT"));
             throw new EMissingCredential(CMS.getUserMessage("CMS_AUTHENTICATION_NULL_CREDENTIAL", CRED_CERT));
         }
-        CMS.debug("SSLCertAuth: Got client certificate");
+        logger.debug("SSLCertAuth: Got client certificate");
 
-        mCA = (ICertificateAuthority) CMS.getSubsystem("ca");
+        CMSEngine engine = CMS.getCMSEngine();
+        mCA = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
 
         if (mCA != null) {
             mCertDB = mCA.getCertificateRepository();
@@ -136,9 +139,7 @@ public class SSLClientCertAuthentication implements IAuthManager {
             try {
                 record = mCertDB.readCertificateRecord(serialNum);
             } catch (EBaseException ee) {
-                if (Debug.ON) {
-                    Debug.trace(ee.toString());
-                }
+                logger.warn("SSLClientCertAuthentication: " + ee.getMessage(), ee);
             }
             if (record != null) {
                 String status = record.getStatus();
@@ -248,11 +249,12 @@ public class SSLClientCertAuthentication implements IAuthManager {
     }
 
     private IRequestQueue getReqQueue() {
+
+        CMSEngine engine = CMS.getCMSEngine();
         IRequestQueue queue = null;
 
         try {
-            IRegistrationAuthority ra =
-                    (IRegistrationAuthority) CMS.getSubsystem("ra");
+            IRegistrationAuthority ra = (IRegistrationAuthority) engine.getSubsystem(IRegistrationAuthority.ID);
 
             if (ra != null) {
                 queue = ra.getRequestQueue();
