@@ -23,7 +23,6 @@ import java.util.Hashtable;
 import java.util.List;
 import java.util.Vector;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.authorization.AuthzManagerProxy;
 import com.netscape.certsrv.authorization.AuthzMgrPlugin;
@@ -40,7 +39,8 @@ import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.cms.logging.Logger;
-import com.netscape.cmscore.util.Debug;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 
 /**
  * Default authorization subsystem
@@ -50,6 +50,9 @@ import com.netscape.cmscore.util.Debug;
  * @version $Revision$, $Date$
  */
 public class AuthzSubsystem implements IAuthzSubsystem {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(AuthzSubsystem.class);
+
     public static final String ID = "authz";
 
     public Hashtable<String, AuthzMgrPlugin> mAuthzMgrPlugins = new Hashtable<String, AuthzMgrPlugin>();
@@ -82,6 +85,7 @@ public class AuthzSubsystem implements IAuthzSubsystem {
      */
     public void init(ISubsystem owner, IConfigStore config)
             throws EBaseException {
+        CMSEngine engine = CMS.getCMSEngine();
         try {
             mLogger = Logger.getLogger();
             mConfig = config;
@@ -99,9 +103,8 @@ public class AuthzSubsystem implements IAuthzSubsystem {
 
                 mAuthzMgrPlugins.put(id, plugin);
             }
-            if (Debug.ON) {
-                Debug.trace("loaded authz plugins");
-            }
+
+            logger.debug("loaded authz plugins");
 
             // get authz manager instances.
 
@@ -120,8 +123,7 @@ public class AuthzSubsystem implements IAuthzSubsystem {
                     throw new EAuthzMgrPluginNotFound(CMS.getUserMessage("CMS_AUTHORIZATION_AUTHZMGR_PLUGIN_NOT_FOUND",
                             implName));
                 } else {
-                    CMS.debug(
-                            CMS.getLogMessage("CMSCORE_AUTHZ_PLUGIN_FOUND", implName));
+                    logger.debug(CMS.getLogMessage("CMSCORE_AUTHZ_PLUGIN_FOUND", implName));
                 }
 
                 String className = plugin.getClassPath();
@@ -156,33 +158,33 @@ public class AuthzSubsystem implements IAuthzSubsystem {
                     log(ILogger.LL_FAILURE, CMS.getLogMessage("OPERATION_ERROR", errMsg));
                     throw new EAuthzException(CMS.getUserMessage("CMS_AUTHORIZATION_LOAD_CLASS_FAIL", className));
                 } catch (EBaseException e) {
-                    log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_AUTHZ_PLUGIN_INIT_FAILED", insName, e.toString()));
+                    String message = CMS.getLogMessage("CMSCORE_AUTHZ_PLUGIN_INIT_FAILED", insName, e.toString());
+                    log(ILogger.LL_FAILURE, message);
                     // it is mis-configurated. This give
                     // administrator another chance to
                     // fix the problem via console
-                    CMS.debug(e);
+                    logger.warn(message, e);
+
                 } catch (Throwable e) {
-                    log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_AUTHZ_PLUGIN_INIT_FAILED", insName, e.toString()));
+                    String message = CMS.getLogMessage("CMSCORE_AUTHZ_PLUGIN_INIT_FAILED", insName, e.toString());
+                    log(ILogger.LL_FAILURE, message);
                     // Skip the authorization instance if
                     // it is mis-configurated. This give
                     // administrator another chance to
                     // fix the problem via console
-                    CMS.debug(e);
+                    logger.warn(message, e);
                 }
                 // add manager instance to list.
                 mAuthzMgrInsts.put(insName, new
                         AuthzManagerProxy(isEnable, authzMgrInst));
-                if (Debug.ON) {
-                    Debug.trace("loaded authz instance " + insName + " impl " + implName);
-                }
+
+                logger.debug("loaded authz instance " + insName + " impl " + implName);
             }
 
         } catch (EBaseException e) {
-            CMS.debug(e);
-            if (CMS.isPreOpMode()) {
-                CMS.debug("AuthzSubsystem.init(): Swallow exception in pre-op mode");
+            logger.error("Unable to initialize AuthzSubsystem: " + e.getMessage(), e);
+            if (engine.isPreOpMode()) {
+                logger.warn("AuthzSubsystem.init(): Swallow exception in pre-op mode");
                 return;
             }
             throw e;
