@@ -37,8 +37,27 @@ import java.util.StringTokenizer;
 
 import org.mozilla.jss.CertificateUsage;
 import org.mozilla.jss.CryptoManager;
+import org.mozilla.jss.netscape.security.extensions.NSCertTypeExtension;
+import org.mozilla.jss.netscape.security.pkcs.PKCS10;
+import org.mozilla.jss.netscape.security.pkcs.PKCS7;
+import org.mozilla.jss.netscape.security.util.Cert;
+import org.mozilla.jss.netscape.security.util.DerInputStream;
+import org.mozilla.jss.netscape.security.util.DerOutputStream;
+import org.mozilla.jss.netscape.security.util.ObjectIdentifier;
+import org.mozilla.jss.netscape.security.util.Utils;
+import org.mozilla.jss.netscape.security.x509.AlgorithmId;
+import org.mozilla.jss.netscape.security.x509.CertificateAlgorithmId;
+import org.mozilla.jss.netscape.security.x509.CertificateExtensions;
+import org.mozilla.jss.netscape.security.x509.CertificateIssuerName;
+import org.mozilla.jss.netscape.security.x509.CertificateSerialNumber;
+import org.mozilla.jss.netscape.security.x509.CertificateValidity;
+import org.mozilla.jss.netscape.security.x509.CertificateVersion;
+import org.mozilla.jss.netscape.security.x509.X500Name;
+import org.mozilla.jss.netscape.security.x509.X509CRLImpl;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
+import org.mozilla.jss.netscape.security.x509.X509CertInfo;
+import org.mozilla.jss.netscape.security.x509.X509Key;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.logging.AuditEvent;
@@ -46,27 +65,8 @@ import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.LogEvent;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
-import com.netscape.cmsutil.util.Cert;
-import com.netscape.cmsutil.util.Utils;
-
-import netscape.security.extensions.NSCertTypeExtension;
-import netscape.security.pkcs.PKCS10;
-import netscape.security.pkcs.PKCS7;
-import netscape.security.util.DerInputStream;
-import netscape.security.util.DerOutputStream;
-import netscape.security.util.ObjectIdentifier;
-import netscape.security.x509.AlgorithmId;
-import netscape.security.x509.CertificateAlgorithmId;
-import netscape.security.x509.CertificateExtensions;
-import netscape.security.x509.CertificateIssuerName;
-import netscape.security.x509.CertificateSerialNumber;
-import netscape.security.x509.CertificateValidity;
-import netscape.security.x509.CertificateVersion;
-import netscape.security.x509.X500Name;
-import netscape.security.x509.X509CRLImpl;
-import netscape.security.x509.X509CertImpl;
-import netscape.security.x509.X509CertInfo;
-import netscape.security.x509.X509Key;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 
 /**
  * Utility class with assorted methods to check for
@@ -78,6 +78,7 @@ import netscape.security.x509.X509Key;
  */
 public class CertUtils {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(CertUtils.class);
     private static Logger signedAuditLogger = SignedAuditLogger.getLogger();
 
     public static final String CERT_NEW_REQUEST_HEADER = "-----BEGIN NEW CERTIFICATE REQUEST-----";
@@ -611,6 +612,16 @@ public class CertUtils {
         return crl;
     }
 
+    public static String getEncodedCert(X509Certificate cert) {
+        try {
+            return Cert.HEADER + "\n" +
+                    Utils.base64encode(cert.getEncoded(), true) +
+                    Cert.FOOTER + "\n";
+        } catch (Exception e) {
+            return null;
+        }
+    }
+
     public static String normalizeCertStr(String s) {
         StringBuffer val = new StringBuffer();
 
@@ -821,7 +832,7 @@ public class CertUtils {
 
         String method = "Certutils.verifySystemCertValidityByNickname: ";
 
-        CMS.debug(method + "(" + nickname + ")");
+        logger.debug(method + "(" + nickname + ")");
         try {
             CryptoManager cm = CryptoManager.getInstance();
             org.mozilla.jss.crypto.X509Certificate cert = cm.findCertByNickname(nickname);
@@ -834,11 +845,11 @@ public class CertUtils {
                 throw new Exception(method + " failed: nickname: " + nickname);
             }
         } catch (Exception e) {
-            CMS.debug(method + " failed : " + e);
+            logger.error(method + " failed : " + e.getMessage(), e);
             throw new Exception(method + " faliled: nickname: "+ nickname + "cause: " + e);
         }
 
-        CMS.debug(method + "success");
+        logger.debug(method + "success");
     }
 
     /*
@@ -846,23 +857,23 @@ public class CertUtils {
      * @throws Exception if something is wrong
      */
     public static void verifySystemCertByNickname(String nickname, String certusage) throws Exception {
-        CMS.debug("CertUtils: verifySystemCertByNickname(" + nickname + ", " + certusage + ")");
+        logger.debug("CertUtils: verifySystemCertByNickname(" + nickname + ", " + certusage + ")");
         CertificateUsage cu = getCertificateUsage(certusage);
         int ccu = 0;
 
         if (cu == null) {
-            CMS.debug("CertUtils: verifySystemCertByNickname() failed: " +
+            logger.debug("CertUtils: verifySystemCertByNickname() failed: " +
                     nickname + " with unsupported certusage =" + certusage);
             throw new Exception("Unsupported certificate usage " + certusage + " in certificate " + nickname);
         }
 
         if (certusage == null || certusage.equals(""))
-            CMS.debug("CertUtils: verifySystemCertByNickname(): required certusage not defined, getting current certusage");
+            logger.debug("CertUtils: verifySystemCertByNickname(): required certusage not defined, getting current certusage");
 
         try {
             CryptoManager cm = CryptoManager.getInstance();
             if (cu.getUsage() != CertificateUsage.CheckAllUsages.getUsage()) {
-                CMS.debug("CertUtils: verifySystemCertByNickname(): calling verifyCertificate(" + nickname + ", true, " + cu + ")");
+                logger.debug("CertUtils: verifySystemCertByNickname(): calling verifyCertificate(" + nickname + ", true, " + cu + ")");
                 try {
                     cm.verifyCertificate(nickname, true, cu);
                 } catch (CertificateException e) {
@@ -870,46 +881,46 @@ public class CertUtils {
                 }
 
             } else {
-                CMS.debug("CertUtils: verifySystemCertByNickname(): calling isCertValid(" + nickname + ", true)");
+                logger.debug("CertUtils: verifySystemCertByNickname(): calling isCertValid(" + nickname + ", true)");
                 // find out about current cert usage
                 ccu = cm.isCertValid(nickname, true);
                 if (ccu == CertificateUsage.basicCertificateUsages) {
                     /* cert is good for nothing */
-                    CMS.debug("CertUtils: verifySystemCertByNickname() failed: cert is good for nothing:" + nickname);
+                    logger.error("CertUtils: verifySystemCertByNickname() failed: cert is good for nothing:" + nickname);
                     throw new Exception("Unusable certificate " + nickname);
 
                 } else {
-                    CMS.debug("CertUtils: verifySystemCertByNickname() passed: " + nickname);
+                    logger.debug("CertUtils: verifySystemCertByNickname() passed: " + nickname);
 
                     if ((ccu & CertificateUsage.SSLServer.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is SSLServer");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is SSLServer");
                     if ((ccu & CertificateUsage.SSLClient.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is SSLClient");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is SSLClient");
                     if ((ccu & CertificateUsage.SSLServerWithStepUp.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is SSLServerWithStepUp");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is SSLServerWithStepUp");
                     if ((ccu & CertificateUsage.SSLCA.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is SSLCA");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is SSLCA");
                     if ((ccu & CertificateUsage.EmailSigner.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is EmailSigner");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is EmailSigner");
                     if ((ccu & CertificateUsage.EmailRecipient.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is EmailRecipient");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is EmailRecipient");
                     if ((ccu & CertificateUsage.ObjectSigner.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is ObjectSigner");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is ObjectSigner");
                     if ((ccu & CertificateUsage.UserCertImport.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is UserCertImport");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is UserCertImport");
                     if ((ccu & CertificateUsage.VerifyCA.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is VerifyCA");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is VerifyCA");
                     if ((ccu & CertificateUsage.ProtectedObjectSigner.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is ProtectedObjectSigner");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is ProtectedObjectSigner");
                     if ((ccu & CertificateUsage.StatusResponder.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is StatusResponder");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is StatusResponder");
                     if ((ccu & CertificateUsage.AnyCA.getUsage()) != 0)
-                        CMS.debug("CertUtils: verifySystemCertByNickname(): cert is AnyCA");
+                        logger.debug("CertUtils: verifySystemCertByNickname(): cert is AnyCA");
                 }
             }
 
         } catch (Exception e) {
-            CMS.debug("CertUtils: verifySystemCertByNickname() failed: " + e);
+            logger.error("CertUtils: verifySystemCertByNickname() failed: " + e.getMessage(), e);
             throw e;
         }
     }
@@ -928,21 +939,22 @@ public class CertUtils {
      */
     public static void verifySystemCertByTag(String tag,boolean checkValidityOnly) throws Exception {
 
-        CMS.debug("CertUtils: verifySystemCertByTag(" + tag + ")");
+        logger.debug("CertUtils: verifySystemCertByTag(" + tag + ")");
 
+        CMSEngine engine = CMS.getCMSEngine();
         String auditMessage = null;
-        IConfigStore config = CMS.getConfigStore();
+        IConfigStore config = engine.getConfigStore();
 
         try {
             String subsysType = config.getString("cs.type", "");
             if (subsysType.equals("")) {
-                CMS.debug("CertUtils: verifySystemCertByTag() cs.type not defined in CS.cfg. System certificates verification not done");
+                logger.error("CertUtils: verifySystemCertByTag() cs.type not defined in CS.cfg. System certificates verification not done");
                 throw new Exception("Missing cs.type in CS.cfg");
             }
 
             subsysType = toLowerCaseSubsystemType(subsysType);
             if (subsysType == null) {
-                CMS.debug("CertUtils: verifySystemCerts() invalid cs.type in CS.cfg. System certificates verification not done");
+                logger.error("CertUtils: verifySystemCerts() invalid cs.type in CS.cfg. System certificates verification not done");
                 auditMessage = CMS.getLogMessage(
                             AuditEvent.CIMC_CERT_VERIFICATION,
                             ILogger.SYSTEM_UID,
@@ -955,13 +967,13 @@ public class CertUtils {
 
             String nickname = config.getString(subsysType + ".cert." + tag + ".nickname", "");
             if (nickname.equals("")) {
-                CMS.debug("CertUtils: verifySystemCertByTag() nickname for cert tag " + tag + " undefined in CS.cfg");
+                logger.error("CertUtils: verifySystemCertByTag() nickname for cert tag " + tag + " undefined in CS.cfg");
                 throw new Exception("Missing nickname for " + tag + " certificate");
             }
 
             String certusage = config.getString(subsysType + ".cert." + tag + ".certusage", "");
             if (certusage.equals("")) {
-                CMS.debug("CertUtils: verifySystemCertByTag() certusage for cert tag "
+                logger.warn("CertUtils: verifySystemCertByTag() certusage for cert tag "
                         + tag + " undefined in CS.cfg, getting current certificate usage");
                 // throw new Exception("Missing certificate usage for " + tag + " certificate"); ?
             }
@@ -981,8 +993,7 @@ public class CertUtils {
             audit(auditMessage);
 
         } catch (Exception e) {
-            CMS.debug("CertUtils: verifySystemCertsByTag() failed: " +
-                    e.toString());
+            logger.error("CertUtils: verifySystemCertsByTag() failed: " + e.getMessage(), e);
             auditMessage = CMS.getLogMessage(
                         AuditEvent.CIMC_CERT_VERIFICATION,
                         ILogger.SYSTEM_UID,
@@ -1039,13 +1050,14 @@ public class CertUtils {
      */
     public static void verifySystemCerts(boolean checkValidityOnly) throws Exception {
 
+        CMSEngine engine = CMS.getCMSEngine();
         String auditMessage = null;
-        IConfigStore config = CMS.getConfigStore();
+        IConfigStore config = engine.getConfigStore();
 
         try {
             String subsysType = config.getString("cs.type", "");
             if (subsysType.equals("")) {
-                CMS.debug("CertUtils: verifySystemCerts() cs.type not defined in CS.cfg. System certificates verification not done");
+                logger.error("CertUtils: verifySystemCerts() cs.type not defined in CS.cfg. System certificates verification not done");
                 auditMessage = CMS.getLogMessage(
                             AuditEvent.CIMC_CERT_VERIFICATION,
                             ILogger.SYSTEM_UID,
@@ -1058,7 +1070,7 @@ public class CertUtils {
 
             subsysType = toLowerCaseSubsystemType(subsysType);
             if (subsysType == null) {
-                CMS.debug("CertUtils: verifySystemCerts() invalid cs.type in CS.cfg. System certificates verification not done");
+                logger.error("CertUtils: verifySystemCerts() invalid cs.type in CS.cfg. System certificates verification not done");
                 auditMessage = CMS.getLogMessage(
                             AuditEvent.CIMC_CERT_VERIFICATION,
                             ILogger.SYSTEM_UID,
@@ -1071,7 +1083,7 @@ public class CertUtils {
 
             String certlist = config.getString(subsysType + ".cert.list", "");
             if (certlist.equals("")) {
-                CMS.debug("CertUtils: verifySystemCerts() "
+                logger.error("CertUtils: verifySystemCerts() "
                         + subsysType + ".cert.list not defined in CS.cfg. System certificates verification not done");
                 auditMessage = CMS.getLogMessage(
                             AuditEvent.CIMC_CERT_VERIFICATION,
@@ -1087,7 +1099,7 @@ public class CertUtils {
             while (tokenizer.hasMoreTokens()) {
                 String tag = tokenizer.nextToken();
                 tag = tag.trim();
-                CMS.debug("CertUtils: verifySystemCerts() cert tag=" + tag);
+                logger.debug("CertUtils: verifySystemCerts() cert tag=" + tag);
 
                 if (!checkValidityOnly) {
                     verifySystemCertByTag(tag);
