@@ -17,11 +17,16 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.cmscore.logging;
 
+import java.util.Collection;
 import java.util.Enumeration;
 import java.util.Hashtable;
+import java.util.ResourceBundle;
+import java.util.Set;
+import java.util.TreeSet;
 import java.util.Vector;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.ISubsystem;
@@ -31,7 +36,7 @@ import com.netscape.certsrv.logging.ILogQueue;
 import com.netscape.certsrv.logging.ILogSubsystem;
 import com.netscape.certsrv.logging.LogPlugin;
 import com.netscape.cms.logging.LogQueue;
-import com.netscape.cmscore.util.Debug;
+import com.netscape.cmscore.apps.CMS;
 
 /**
  * A class represents a log subsystem.
@@ -43,6 +48,8 @@ import com.netscape.cmscore.util.Debug;
  */
 public class LogSubsystem implements ILogSubsystem {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(LogSubsystem.class);
+
     private static LogSubsystem mInstance = new LogSubsystem();
     private static ILogQueue mLogQueue = LogQueue.getLogQueue();
     private IConfigStore mConfig = null;
@@ -58,6 +65,7 @@ public class LogSubsystem implements ILogSubsystem {
 
     public Hashtable<String, LogPlugin> mLogPlugins = new Hashtable<String, LogPlugin>();
     public Hashtable<String, ILogEventListener> mLogInsts = new Hashtable<String, ILogEventListener>();
+    public Set<String> auditEvents = new TreeSet<>();
 
     /**
      * Constructs a log subsystem.
@@ -96,8 +104,7 @@ public class LogSubsystem implements ILogSubsystem {
 
             mLogPlugins.put(id, plugin);
         }
-        if (Debug.ON)
-            Debug.trace("loaded logger plugins");
+        logger.trace("loaded logger plugins");
 
         // load log instances
         c = config.getSubStore(PROP_INSTANCE);
@@ -135,20 +142,40 @@ public class LogSubsystem implements ILogSubsystem {
 
             // add log instance to list.
             mLogInsts.put(insName, logInst);
-            if (Debug.ON)
-                Debug.trace("loaded log instance " + insName + " impl " + implName);
+            logger.trace("loaded log instance " + insName + " impl " + implName);
         }
 
+        // load audit events from audit-events.properties
+        ResourceBundle rb = ResourceBundle.getBundle("audit-events");
+        Pattern value_pattern = Pattern.compile("^<type=(.*)>:.*");
+
+        for (String name : rb.keySet()) {
+
+            String value = rb.getString(name);
+
+            Matcher value_matcher = value_pattern.matcher(value);
+            if (!value_matcher.matches()) {
+                continue;
+            }
+
+            String event = value_matcher.group(1);
+
+            auditEvents.add(event.trim());
+        }
+    }
+
+    public Collection<String> getAuditEvents() {
+        return auditEvents;
     }
 
     public void startup() throws EBaseException {
-        Debug.trace("entering LogSubsystem.startup()");
+        logger.trace("entering LogSubsystem.startup()");
         Enumeration<String> enum1 = mLogInsts.keys();
 
         while (enum1.hasMoreElements()) {
             String instName = enum1.nextElement();
 
-            Debug.trace("about to call inst=" + instName + " in LogSubsystem.startup()");
+            logger.trace("about to call inst=" + instName + " in LogSubsystem.startup()");
             ILogEventListener inst = mLogInsts.get(instName);
 
             inst.startup();
