@@ -33,7 +33,6 @@ import org.dogtagpki.legacy.policy.IPolicySet;
 import org.dogtagpki.legacy.policy.IRenewalPolicy;
 import org.dogtagpki.legacy.policy.IRevocationPolicy;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.authority.IAuthority;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
@@ -42,11 +41,11 @@ import com.netscape.certsrv.common.Constants;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.PolicyResult;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.base.PropConfigStore;
-import com.netscape.cmscore.base.SubsystemRegistry;
 import com.netscape.cmscore.request.ARequestQueue;
 import com.netscape.cmscore.util.AssertionException;
-import com.netscape.cmscore.util.Debug;
 
 /**
  * This is a Generic policy processor. The three main functions of
@@ -65,6 +64,9 @@ import com.netscape.cmscore.util.Debug;
  * @version $Revision$, $Date$
  */
 public class GenericPolicyProcessor implements IPolicyProcessor {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(GenericPolicyProcessor.class);
+
     protected IConfigStore mConfig = null;
     protected IConfigStore mGlobalStore = null;
     protected IAuthority mAuthority = null;
@@ -143,15 +145,15 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
      */
     public synchronized void init(ISubsystem owner, IConfigStore config)
             throws EBaseException {
-        // Debug.trace("GenericPolicyProcessor::init");
-        CMS.debug("GenericPolicyProcessor::init begins");
+        logger.debug("GenericPolicyProcessor::init begins");
+
+        CMSEngine engine = CMS.getCMSEngine();
         mAuthority = (IAuthority) owner;
         mConfig = config;
-        mGlobalStore =
-                SubsystemRegistry.getInstance().get("MAIN").getConfigStore();
+        mGlobalStore = engine.getConfigStore();
 
         try {
-            IConfigStore configStore = CMS.getConfigStore();
+            IConfigStore configStore = engine.getConfigStore();
             String PKI_Subsystem = configStore.getString("subsystem.0.id",
                                                           null);
 
@@ -179,12 +181,12 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
                     //        'CS.cfg' file, and thus we err on the
                     //        side that the user may still need to
                     //        use the policy framework.
-                    CMS.debug("GenericPolicyProcessor::init Certificate "
+                    logger.debug("GenericPolicyProcessor::init Certificate "
                              + "Policy Framework (deprecated) "
                              + "is ENABLED");
                 } else {
                     // CS 8.1 Default:  <subsystem>.Policy.enable=false
-                    CMS.debug("GenericPolicyProcessor::init Certificate "
+                    logger.debug("GenericPolicyProcessor::init Certificate "
                              + "Policy Framework (deprecated) "
                              + "is DISABLED");
                     return;
@@ -239,9 +241,9 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             } catch (EBaseException e) {
                 throw e;
             } catch (Exception e) {
-                Debug.printStackTrace(e);
-                throw new EPolicyException(CMS.getUserMessage("CMS_POLICY_NO_POLICY_IMPL",
-                            id));
+                String message = CMS.getUserMessage("CMS_POLICY_NO_POLICY_IMPL", id);
+                logger.error(message + ": " + e.getMessage(), e);
+                throw new EPolicyException(message, e);
             }
 
             // Register the implementation.
@@ -378,9 +380,9 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
         IPolicySet rules = null;
         String op = req.getRequestType();
 
-        CMS.debug("GenericPolicyProcessor: apply begins");
+        logger.debug("GenericPolicyProcessor: apply begins");
         if (op == null) {
-            CMS.debug("GenericPolicyProcessor: apply op null");
+            logger.debug("GenericPolicyProcessor: apply op null");
             // throw new AssertionException("Missing operation type in request. Can't happen!");
             // Return ACCEPTED for now. Looks like even get CA chain
             // is being passed in here with request type set elsewhere
@@ -388,11 +390,11 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             return PolicyResult.ACCEPTED;
         }
         if (isProfileRequest(req)) {
-            Debug.trace("GenericPolicyProcessor: Profile-base Request " +
+            logger.debug("GenericPolicyProcessor: Profile-base Request " +
                     req.getRequestId().toString());
             return PolicyResult.ACCEPTED;
         }
-        CMS.debug("GenericPolicyProcessor: apply not ProfileRequest. op=" + op);
+        logger.debug("GenericPolicyProcessor: apply not ProfileRequest. op=" + op);
 
         if (op.equalsIgnoreCase(IRequest.ENROLLMENT_REQUEST))
             rules = mEnrollmentRules;
@@ -413,7 +415,7 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
         // ((PolicySet)rules).printPolicies();
         // If there are no rules, then it is a serious error.
         if (rules.count() == 0) {
-            CMS.debug("GenericPolicyProcessor: apply: rule count 0");
+            logger.debug("GenericPolicyProcessor: apply: rule count 0");
             // if no policy is specified, just accept the request.
             // KRA has no policy configured by default
             return PolicyResult.ACCEPTED;
@@ -423,7 +425,7 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
              * return PolicyResult.REJECTED;
              **/
         }
-        CMS.debug("GenericPolicyProcessor: apply: rules.count=" + rules.count());
+        logger.debug("GenericPolicyProcessor: apply: rules.count=" + rules.count());
 
         // request must be up to date or can't process it.
         PolicyResult res = PolicyResult.ACCEPTED;
@@ -439,7 +441,7 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
         if (res == PolicyResult.REJECTED)
             return res;
 
-        CMS.debug("GenericPolicyProcessor: apply: calling rules.apply()");
+        logger.debug("GenericPolicyProcessor: apply: calling rules.apply()");
         // Apply the policy rules.
         return rules.apply(req);
     }
@@ -473,7 +475,7 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             }
             ret = impls.elements();
         } catch (Exception e) {
-            Debug.printStackTrace(e);
+            logger.warn("Unable to get policy implementations: " + e.getMessage(), e);
         }
         return ret;
     }
@@ -490,7 +492,7 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             }
             ret = impls.elements();
         } catch (Exception e) {
-            Debug.printStackTrace(e);
+            logger.warn("Unable to get policy implementation infos: " + e.getMessage(), e);
         }
         return ret;
     }
@@ -503,10 +505,9 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
         IPolicyRule impl = null;
 
         try {
-            impl =
-                    (IPolicyRule) Class.forName(regImpl.getClassPath()).newInstance();
+            impl = (IPolicyRule) Class.forName(regImpl.getClassPath()).newInstance();
         } catch (Exception e) {
-            Debug.printStackTrace(e);
+            logger.warn("Unable to get policy implementation: " + e.getMessage(), e);
         }
         return impl;
     }
@@ -563,11 +564,10 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
         try {
             mGlobalStore.commit(true);
         } catch (Exception ex) {
-            Debug.printStackTrace(ex);
             String[] params = { "implementation", id };
-
-            throw new EPolicyException(
-                    CMS.getUserMessage("CMS_POLICY_DELETING_POLICY_ERROR", params));
+            String message = CMS.getUserMessage("CMS_POLICY_DELETING_POLICY_ERROR", params);
+            logger.error(message + ": " + ex.getMessage(), ex);
+            throw new EPolicyException(message, ex);
         }
     }
 
@@ -635,7 +635,7 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             }
             ret = rules.elements();
         } catch (Exception e) {
-            Debug.printStackTrace(e);
+            logger.warn("Unable to get policy instances: " + e.getMessage(), e);
         }
         return ret;
     }
@@ -653,7 +653,7 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             }
             ret = rules.elements();
         } catch (Exception e) {
-            Debug.printStackTrace(e);
+            logger.warn("Unable to get policy instance infos: " + e.getMessage(), e);
         }
         return ret;
     }
@@ -719,11 +719,11 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             // Put the rule back in the rule order vector.
             mPolicyOrder.insertElementAt(id, index);
 
-            Debug.printStackTrace(e);
             String[] params = { "instance", id };
 
-            throw new EPolicyException(
-                    CMS.getUserMessage("CMS_POLICY_DELETING_POLICY_ERROR", params));
+            String message = CMS.getUserMessage("CMS_POLICY_DELETING_POLICY_ERROR", params);
+            logger.error(message + ": " + e.getMessage(), e);
+            throw new EPolicyException(message, e);
         }
 
         IPolicyRule rule = instance.getRule();
@@ -919,11 +919,11 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             String k = newkeys.nextElement();
             String v = ht.get(k);
 
-            Debug.trace("newstore key " + k + "=" + v);
+            logger.debug("newstore key " + k + "=" + v);
             if (v != null) {
                 if (!k.equals(Constants.OP_TYPE) && !k.equals(Constants.OP_SCOPE) &&
                         !k.equals(Constants.RS_ID) && !k.equals("RULENAME")) {
-                    Debug.trace("newstore.put(" + k + "=" + v + ")");
+                    logger.debug("newstore.put(" + k + "=" + v + ")");
                     newStore.put(k, v);
                 }
             }
@@ -958,8 +958,7 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
                 String key = e.nextElement();
 
                 if (key != null) {
-                    Debug.trace(
-                            "oldstore.put(" + key + "," +
+                    logger.debug("oldstore.put(" + key + "," +
                                     newStore.getString(key) + ")");
                     oldStore.put(key, newStore.getString(key));
                 }
@@ -1054,11 +1053,12 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
                 // else ignore the darned rule.
             }
         } catch (Throwable e) {
-            Debug.printStackTrace(e);
             EBaseException ex = new EBaseException(CMS.getUserMessage("CMS_BASE_INTERNAL_ERROR",
-                        "Cannot create default policy rule. Error: " + e.getMessage()));
+                        "Cannot create default policy rule. Error: " + e.getMessage()), e);
 
-            mAuthority.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_POLICY_DEF_CREATE", e.toString()));
+            String message = CMS.getLogMessage("CMSCORE_POLICY_DEF_CREATE", e.getMessage());
+            logger.error(message, e);
+            mAuthority.log(ILogger.LL_FAILURE, message);
             throw ex;
         }
 
@@ -1104,9 +1104,9 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
         try {
             mGlobalStore.commit(true);
         } catch (Exception ex) {
-            Debug.printStackTrace(ex);
-            throw new EPolicyException(
-                    CMS.getUserMessage("CMS_POLICY_ORDER_ERROR", policyOrderStr));
+            String message = CMS.getUserMessage("CMS_POLICY_ORDER_ERROR", policyOrderStr);
+            logger.error(message + ": " + ex.getMessage(), ex);
+            throw new EPolicyException(message, ex);
         }
     }
 
@@ -1243,9 +1243,9 @@ public class GenericPolicyProcessor implements IPolicyProcessor {
             } catch (EBaseException e) {
                 throw e;
             } catch (Exception e) {
-                Debug.printStackTrace(e);
-                throw new EPolicyException(CMS.getUserMessage("CMS_POLICY_NO_POLICY_IMPL",
-                            ruleName));
+                String message = CMS.getUserMessage("CMS_POLICY_NO_POLICY_IMPL", ruleName);
+                logger.error(message + ": " + e.getMessage(), e);
+                throw new EPolicyException(message, e);
             }
         }
     }
