@@ -194,6 +194,7 @@ class SubsystemEnableCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                   Run in verbose mode.')
+        print('      --silent                    Run in silent mode.')
         print('      --help                      Show help message.')
         print()
 
@@ -202,7 +203,7 @@ class SubsystemEnableCLI(pki.cli.CLI):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=', 'all',
-                'verbose', 'help'])
+                'verbose', 'silent', 'help'])
 
         except getopt.GetoptError as e:
             print('ERROR: ' + str(e))
@@ -211,6 +212,7 @@ class SubsystemEnableCLI(pki.cli.CLI):
 
         instance_name = 'pki-tomcat'
         all_subsystems = False
+        silent = False
 
         for o, a in opts:
             if o in ('-i', '--instance'):
@@ -222,6 +224,9 @@ class SubsystemEnableCLI(pki.cli.CLI):
             elif o in ('-v', '--verbose'):
                 self.set_verbose(True)
 
+            elif o == '--silent':
+                silent = True
+
             elif o == '--help':
                 self.usage()
                 sys.exit()
@@ -244,7 +249,8 @@ class SubsystemEnableCLI(pki.cli.CLI):
                 if not subsystem.is_enabled():
                     subsystem.enable()
 
-            self.print_message('Enabled all subsystems')
+            if not silent:
+                self.print_message('Enabled all subsystems')
 
             return
 
@@ -262,13 +268,16 @@ class SubsystemEnableCLI(pki.cli.CLI):
             sys.exit(1)
 
         if subsystem.is_enabled():
-            self.print_message('Subsystem "%s" is already '
-                               'enabled' % subsystem_name)
+            if not silent:
+                self.print_message(
+                    'Subsystem "%s" is already enabled' % subsystem_name)
         else:
             subsystem.enable()
-            self.print_message('Enabled "%s" subsystem' % subsystem_name)
+            if not silent:
+                self.print_message('Enabled "%s" subsystem' % subsystem_name)
 
-        SubsystemCLI.print_subsystem(subsystem)
+        if not silent:
+            SubsystemCLI.print_subsystem(subsystem)
 
 
 class SubsystemDisableCLI(pki.cli.CLI):
@@ -564,15 +573,19 @@ class SubsystemCertExportCLI(pki.cli.CLI):
         super(SubsystemCertExportCLI, self).__init__(
             'export', 'Export subsystem certificate')
 
-    def print_help(self):  # flake8: noqa
+    def print_help(self):
         print('Usage: pki-server subsystem-cert-export [OPTIONS] <subsystem ID> [cert ID]')
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
-        print('      --cert-file <path>             Output file to store the exported certificate in PEM format.')
-        print('      --csr-file <path>              Output file to store the exported CSR in PEM format.')
-        print('      --pkcs12-file <path>           Output file to store the exported certificate and key in PKCS #12 format.')
+        print('      --cert-file <path>             Output file to store the exported certificate '
+              'in PEM format.')
+        print('      --csr-file <path>              Output file to store the exported CSR in PEM '
+              'format.')
+        print('      --pkcs12-file <path>           Output file to store the exported certificate '
+              'and key in PKCS #12 format.')
         print('      --pkcs12-password <password>   Password for the PKCS #12 file.')
-        print('      --pkcs12-password-file <path>  Input file containing the password for the PKCS #12 file.')
+        print('      --pkcs12-password-file <path>  Input file containing the password for the '
+              'PKCS #12 file.')
         print('      --append                       Append into an existing PKCS #12 file.')
         print('      --no-trust-flags               Do not include trust flags')
         print('      --no-key                       Do not include private key')
@@ -839,7 +852,8 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
 
             if data:
                 if self.verbose:
-                    print('Removing old %s certificate from database.' % subsystem_cert['nickname'])
+                    print('Removing old %s certificate from database.'
+                          % subsystem_cert['nickname'])
                 nssdb.remove_cert(nickname=subsystem_cert['nickname'])
             if self.verbose:
                 print('Adding new %s certificate into database.' % subsystem_cert['nickname'])
