@@ -24,8 +24,6 @@ import logging
 import os
 import pprint
 
-from pki.server.deployment import pkiconfig as config
-
 sensitive_parameters = []
 
 # Initialize 'pretty print' for objects
@@ -55,48 +53,36 @@ def enable_pki_logger(log_dir, log_name, log_level, console_log_level, name):
     # Configure console handler
     console = logging.StreamHandler()
     console.setLevel(console_log_level)
-    console_format = logging.Formatter('%(name)-14s: ' +
-                                       '%(levelname)-8s ' +
-                                       '%(indent)s%(message)s')
+    console_format = logging.Formatter('%(levelname)-8s: %(name)-14s %(message)s')
     console.setFormatter(console_format)
 
     # Configure file handler
     log_file = logging.FileHandler(log_dir + "/" + log_name, 'w')
     log_file.setLevel(log_level)
-    file_format = logging.Formatter('%(asctime)s %(name)-14s: ' +
-                                    '%(levelname)-8s ' +
-                                    '%(indent)s%(message)s',
+    file_format = logging.Formatter('%(levelname)-8s: %(name)-14s %(message)s',
                                     '%Y-%m-%d %H:%M:%S')
     log_file.setFormatter(file_format)
 
-    # Configure pki logger
-    logger = logging.getLogger('pki')
-    logger.setLevel(log_level)
-    logger.addHandler(console)
-    logger.addHandler(log_file)
-
-    # Configure pkispawn/pkidestroy logger
-    config.pki_log = logging.getLogger(name)
-    config.pki_log.setLevel(log_level)
-    config.pki_log.addHandler(console)
-    config.pki_log.addHandler(log_file)
-
-    # Configure scriptlet loggers
-    scriptlets = [
+    # Configure loggers
+    modules = [
+        'pkihelper',
+        'pkimanifest',
+        'pkiparser',
         'initialization',
         'infrastructure',
-        'instance'
+        'instance',
         'subsystem',
         'webapp',
         'nssdb',
         'selinux',
         'keygen',
         'configuration',
-        'finalization'
+        'finalization',
+        name
     ]
 
-    for scriptlet in scriptlets:
-        logger = logging.getLogger(scriptlet)
+    for module in modules:
+        logger = logging.getLogger(module)
         logger.setLevel(log_level)
         logger.addHandler(console)
         logger.addHandler(log_file)
