@@ -46,6 +46,8 @@ from . import pkiconfig as config
 from . import pkimessages as log
 from . import pkilogging
 
+logger = logging.getLogger('pkiparser')
+
 
 class PKIConfigParser:
 
@@ -261,13 +263,17 @@ class PKIConfigParser:
             )
         return dbtype
 
-    def init_config(self):
+    def init_config(self, pki_instance_name=None):
         self.deployer.nss_db_type = self.get_nss_db_type()
         java_home = self._getenv('JAVA_HOME').strip()
-        resteasy_lib = self._getenv('RESTEASY_LIB').strip()
-        jni_jar_dir = self._getenv('JNI_JAR_DIR').strip()
 
-        default_instance_name = 'pki-tomcat'
+        # Check if a instance name is provided before assigning a default
+        # instance_name
+        if pki_instance_name:
+            default_instance_name = pki_instance_name
+        else:
+            default_instance_name = 'pki-tomcat'
+
         default_http_port = '8080'
         default_https_port = '8443'
 
@@ -284,8 +290,6 @@ class PKIConfigParser:
             'pki_subsystem_type': self.deployer.subsystem_name.lower(),
             'nss_default_db_type': self.deployer.nss_db_type,
             'java_home': java_home,
-            'resteasy_lib': resteasy_lib,
-            'jni_jar_dir': jni_jar_dir,
             'home_dir': os.path.expanduser("~"),
             'pki_hostname': self.deployer.hostname})
 
@@ -591,12 +595,8 @@ class PKIConfigParser:
         try:
             info = sd.get_security_domain_info()
         except requests.exceptions.HTTPError as e:
-            config.pki_log.warning(
-                'Unable to get security domain info: %s', e,
-                extra=config.PKI_INDENTATION_LEVEL_2)
-            config.pki_log.info(
-                'Trying older interface.',
-                extra=config.PKI_INDENTATION_LEVEL_2)
+            logger.warning('Unable to get security domain info: %s', e)
+            logger.info('Trying older interface.')
             info = sd.get_old_security_domain_info()
         return info
 
@@ -612,9 +612,7 @@ class PKIConfigParser:
         except requests.exceptions.HTTPError as e:
             code = e.response.status_code
             if code == 404 or code == 501:
-                config.pki_log.warning(
-                    'Unable to authenticate against security domain: %s', e,
-                    extra=config.PKI_INDENTATION_LEVEL_2)
+                logger.warning('Unable to authenticate against security domain: %s', e)
             else:
                 raise
 
@@ -745,10 +743,9 @@ class PKIConfigParser:
                     self.mdict['pki_one_time_pin'] = \
                         cs_cfg.get('preop.pin')
                 else:
-                    config.pki_log.error(
+                    logger.error(
                         log.PKI_FILE_MISSING_OR_NOT_A_FILE_1,
-                        self.mdict['pki_target_cs_cfg'],
-                        extra=config.PKI_INDENTATION_LEVEL_2)
+                        self.mdict['pki_target_cs_cfg'])
                     raise Exception(log.PKI_FILE_MISSING_OR_NOT_A_FILE_1)
             else:
                 # Generate a one-time pin to be used prior to configuration
@@ -844,9 +841,6 @@ class PKIConfigParser:
             #     NOTE:  Master key == Slots key; Master value ==> Slots value
             self.mdict['PKI_INSTANCE_NAME_SLOT'] = \
                 self.mdict['pki_instance_name']
-            self.mdict['PKI_INSTANCE_INITSCRIPT_SLOT'] = \
-                os.path.join(self.mdict['pki_instance_path'],
-                             self.mdict['pki_instance_name'])
             self.mdict['PKI_REGISTRY_FILE_SLOT'] = \
                 os.path.join(self.mdict['pki_subsystem_registry_path'],
                              self.mdict['pki_instance_name'])
@@ -891,9 +885,6 @@ class PKIConfigParser:
                 self.mdict['pki_instance_path']
             self.mdict['PKI_INSTANCE_ROOT_SLOT'] = \
                 self.mdict['pki_path']
-            self.mdict['PKI_LOCKDIR_SLOT'] = \
-                os.path.join("/var/lock/pki",
-                             "tomcat")
             self.mdict['PKI_HOSTNAME_SLOT'] = \
                 self.mdict['pki_hostname']
             self.mdict['PKI_OPEN_SEPARATE_PORTS_SERVER_COMMENT_SLOT'] = \
@@ -951,8 +942,6 @@ class PKIConfigParser:
                     "<!--"
             self.mdict['PKI_TMPDIR_SLOT'] = \
                 self.mdict['pki_tomcat_tmpdir_path']
-            self.mdict['PKI_RESTEASY_LIB_SLOT'] = \
-                self.mdict['resteasy_lib']
             self.mdict['PKI_RANDOM_NUMBER_SLOT'] = \
                 self.mdict['pki_one_time_pin']
             self.mdict['PKI_SECURE_PORT_SLOT'] = \
@@ -1088,13 +1077,6 @@ class PKIConfigParser:
                     "+TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384," + \
                     "-TLS_RSA_WITH_AES_256_GCM_SHA384"
 
-            if self.deployer.architecture == 64:
-                self.mdict['NUXWDOG_JNI_PATH_SLOT'] = (
-                    '/usr/lib64/nuxwdog-jni')
-            else:
-                self.mdict['NUXWDOG_JNI_PATH_SLOT'] = (
-                    '/usr/lib/nuxwdog-jni')
-
             # tps parameters
             self.mdict['TOKENDB_HOST_SLOT'] = \
                 self.mdict['pki_ds_hostname']
@@ -1124,31 +1106,14 @@ class PKIConfigParser:
                 os.path.join(
                     self.mdict['pki_instance_configuration_path'],
                     "password.conf")
-            self.mdict['pki_cert_database'] = \
-                os.path.join(self.mdict['pki_server_database_path'],
-                             "cert8.db")
-            self.mdict['pki_key_database'] = \
-                os.path.join(self.mdict['pki_server_database_path'],
-                             "key3.db")
-            self.mdict['pki_secmod_database'] = \
-                os.path.join(self.mdict['pki_server_database_path'],
-                             "secmod.db")
-            self.mdict['pki_self_signed_nickname'] = \
-                self.mdict['pki_sslserver_nickname']
+
             self.mdict['pki_self_signed_subject'] = \
                 "cn=" + self.mdict['pki_hostname'] + "," + \
                 "o=" + self.mdict['pki_certificate_timestamp']
             self.mdict['pki_self_signed_serial_number'] = 0
             self.mdict['pki_self_signed_validity_period'] = 12
-            self.mdict['pki_self_signed_issuer_name'] = \
-                "cn=" + self.mdict['pki_hostname'] + "," + \
-                "o=" + self.mdict['pki_certificate_timestamp']
             self.mdict['pki_self_signed_trustargs'] = "CTu,CTu,CTu"
-            self.mdict['pki_self_signed_noise_file'] = \
-                os.path.join(
-                    self.mdict['pki_subsystem_configuration_path'],
-                    "noise")
-            self.mdict['pki_self_signed_noise_bytes'] = 1024
+
             # Tomcat NSS security database convenience
             # symbolic links
             self.mdict['pki_subsystem_configuration_password_conf_link'] = \
@@ -1170,7 +1135,6 @@ class PKIConfigParser:
             #     The following variables are defined below:
             #
             #         self.mdict['pki_security_domain_type']
-            #         self.mdict['pki_security_domain_uri']
             #
             #     The following variables are established via the specified PKI
             #     deployment configuration file and are NOT redefined below:
@@ -1229,28 +1193,31 @@ class PKIConfigParser:
                 else:
                     self.mdict['pki_security_domain_user'] = "caadmin"
 
-            if not config.str2bool(self.mdict['pki_skip_configuration']) and\
-                    (config.str2bool(self.mdict['pki_standalone'])):
+            if not config.str2bool(self.mdict['pki_skip_configuration']) and \
+                    config.str2bool(self.mdict['pki_standalone']):
+
                 # Stand-alone PKI
                 self.mdict['pki_security_domain_type'] = "new"
                 self.mdict['pki_issuing_ca'] = "External CA"
-            elif (self.deployer.subsystem_name != "CA" or
-                    config.str2bool(self.mdict['pki_clone']) or
-                    config.str2bool(self.mdict['pki_subordinate'])):
+
+            elif self.deployer.subsystem_name != "CA" or \
+                    config.str2bool(self.mdict['pki_clone']) or \
+                    config.str2bool(self.mdict['pki_subordinate']) and \
+                    not config.str2bool(self.mdict['pki_subordinate_create_new_security_domain']):
+
                 # PKI KRA, PKI OCSP, PKI TKS, PKI TPS,
                 # CA Clone, KRA Clone, OCSP Clone, TKS Clone, TPS Clone
-                # Subordinate CA
+                # Subordinate CA (existing)
                 self.mdict['pki_security_domain_type'] = "existing"
-                self.mdict['pki_security_domain_uri'] = \
-                    "https" + "://" + \
-                    self.mdict['pki_security_domain_hostname'] + ":" + \
-                    self.mdict['pki_security_domain_https_port']
+
             elif config.str2bool(self.mdict['pki_external']):
+
                 # External CA
                 self.mdict['pki_security_domain_type'] = "new"
                 self.mdict['pki_issuing_ca'] = "External CA"
+
             else:
-                # PKI CA (master)
+                # PKI CA (master) and Subordinate CA (new)
                 self.mdict['pki_security_domain_type'] = "new"
 
             # 'External CA' Configuration name/value pairs
@@ -1266,26 +1233,6 @@ class PKIConfigParser:
             #        self.mdict['pki_external_step_two']
             #
 
-            # 'Backup' Configuration name/value pairs
-            #
-            #     Tomcat - [CA], [KRA], [OCSP], [TKS], [TPS]
-            #            - [External CA]
-            #            - [Subordinate CA]
-            #
-            #     The following variables are established via the specified PKI
-            #     deployment configuration file and are NOT redefined below:
-            #
-            #        self.mdict['pki_backup_password']
-            #        self.mdict['pki_backup_keys']
-            #
-            if config.str2bool(self.mdict['pki_backup_keys']):
-                # NOTE:  ALWAYS store the PKCS #12 backup keys file
-                #        in with the NSS "server" security databases
-                self.mdict['pki_backup_keys_p12'] = \
-                    self.mdict['pki_server_database_path'] + "/" + \
-                    self.mdict['pki_subsystem'].lower() + "_" + \
-                    "backup" + "_" + "keys" + "." + "p12"
-
             self.mdict['pki_admin_profile_id'] = "caAdminCert"
 
             if 'pki_import_admin_cert' not in self.mdict:
@@ -1333,18 +1280,14 @@ class PKIConfigParser:
                 self.mdict['pki_instance_name'] + "." + "service"
 
         except OSError as exc:
-            config.pki_log.error(log.PKI_OSERROR_1, exc,
-                                 extra=config.PKI_INDENTATION_LEVEL_2)
+            logger.error(log.PKI_OSERROR_1, exc)
             raise
         except KeyError as err:
-            config.pki_log.error(log.PKIHELPER_DICTIONARY_MASTER_MISSING_KEY_1,
-                                 err, extra=config.PKI_INDENTATION_LEVEL_2)
+            logger.error(log.PKIHELPER_DICTIONARY_MASTER_MISSING_KEY_1, err)
             raise
         except configparser.InterpolationSyntaxError as err:
-            config.pki_log.error(log.PKIHELPER_DICTIONARY_INTERPOLATION_1,
-                                 extra=config.PKI_INDENTATION_LEVEL_2)
-            config.pki_log.error(log.PKIHELPER_DICTIONARY_INTERPOLATION_2, err,
-                                 extra=config.PKI_INDENTATION_LEVEL_2)
+            logger.error(log.PKIHELPER_DICTIONARY_INTERPOLATION_1)
+            logger.error(log.PKIHELPER_DICTIONARY_INTERPOLATION_2, err)
             raise
         return
 
