@@ -37,9 +37,7 @@ import pki.server
 import pki.system
 import pki.util
 
-logger = logging.LoggerAdapter(
-    logging.getLogger('configuration'),
-    extra={'indent': ''})
+logger = logging.getLogger('configuration')
 
 
 # PKI Deployment Configuration Scriptlet
@@ -403,15 +401,15 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         if len(deployer.instance.tomcat_instance_subsystems()) > 1:
             return False
 
+        nickname = deployer.mdict['pki_sslserver_nickname']
+        instance.set_sslserver_cert_nickname(nickname)
+
+        tmpdir = tempfile.mkdtemp()
         nssdb = instance.open_nssdb()
 
         try:
-            nickname = deployer.mdict['pki_self_signed_nickname']
-
             logger.info('Checking existing SSL server cert: %s', nickname)
-
-            pem_cert = nssdb.get_cert(
-                nickname=nickname)
+            pem_cert = nssdb.get_cert(nickname=nickname)
 
             if pem_cert:
                 cert = x509.load_pem_x509_certificate(pem_cert, default_backend())
@@ -432,56 +430,42 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
             logger.info('Creating temp SSL server cert for %s', deployer.mdict['pki_hostname'])
 
-            instance.set_sslserver_cert_nickname(nickname)
-
             # TODO: replace with pki-server create-cert sslserver --temp
 
-            logger.info('Creating password file: %s', deployer.mdict['pki_shared_pfile'])
-            deployer.password.create_password_conf(
-                deployer.mdict['pki_shared_pfile'],
-                deployer.mdict['pki_server_database_password'], pin_sans_token=True)
-
-            # only create a self signed cert for a new instance
-            #
             # NOTE:  ALWAYS create the temporary sslserver certificate
             #        in the software DB regardless of whether the
             #        instance will utilize 'softokn' or an HSM
-            #
-            # note: in the function below, certutil is used to generate
-            # the request for the self signed cert.  The keys are generated
-            # by NSS, which does not actually use the data in the noise
-            # file, so it does not matter what is in this file.  Certutil
-            # still requires it though, otherwise it waits for keyboard
-            # input
 
-            with open(deployer.mdict['pki_self_signed_noise_file'], 'w') as f:
-                f.write("not_so_random_data")
+            csr_file = os.path.join(tmpdir, 'sslserver.csr')
+            cert_file = os.path.join(tmpdir, 'sslserver.crt')
 
-            deployer.certutil.generate_self_signed_certificate(
-                deployer.mdict['pki_server_database_path'],
-                deployer.mdict['pki_self_signed_token'],
-                deployer.mdict['pki_self_signed_nickname'],
-                deployer.mdict['pki_self_signed_subject'],
-                deployer.mdict['pki_sslserver_key_type'],
-                deployer.mdict['pki_sslserver_key_size'],
-                deployer.mdict['pki_self_signed_serial_number'],
-                deployer.mdict['pki_self_signed_validity_period'],
-                deployer.mdict['pki_self_signed_issuer_name'],
-                deployer.mdict['pki_self_signed_trustargs'],
-                deployer.mdict['pki_self_signed_noise_file'],
-                password_file=deployer.mdict['pki_shared_pfile'])
+            nssdb.create_request(
+                subject_dn=deployer.mdict['pki_self_signed_subject'],
+                request_file=csr_file,
+                token=deployer.mdict['pki_self_signed_token'],
+                key_type=deployer.mdict['pki_sslserver_key_type'],
+                key_size=deployer.mdict['pki_sslserver_key_size']
+            )
 
-            # Delete the temporary 'noise' file
-            deployer.file.delete(
-                deployer.mdict['pki_self_signed_noise_file'])
+            nssdb.create_cert(
+                request_file=csr_file,
+                cert_file=cert_file,
+                serial=deployer.mdict['pki_self_signed_serial_number'],
+                validity=deployer.mdict['pki_self_signed_validity_period']
+            )
 
-            # Always delete the temporary 'pfile'
-            deployer.file.delete(deployer.mdict['pki_shared_pfile'])
+            nssdb.add_cert(
+                nickname=nickname,
+                cert_file=cert_file,
+                token=deployer.mdict['pki_self_signed_token'],
+                trust_attributes=deployer.mdict['pki_self_signed_trustargs']
+            )
 
             return True
 
         finally:
             nssdb.close()
+            shutil.rmtree(tmpdir)
 
     def remove_temp_sslserver_cert(self, instance, sslserver):
 
@@ -564,8 +548,39 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         instance = pki.server.PKIInstance(deployer.mdict['pki_instance_name'])
         instance.load()
 
-        subsystem = instance.get_subsystem(
-            deployer.mdict['pki_subsystem'].lower())
+        subsystem = instance.get_subsystem(deployer.mdict['pki_subsystem'].lower())
+
+        # configure internal database
+        subsystem.config['internaldb.ldapconn.host'] = deployer.mdict['pki_ds_hostname']
+
+        if config.str2bool(deployer.mdict['pki_ds_secure_connection']):
+            subsystem.config['internaldb.ldapconn.secureConn'] = 'true'
+            subsystem.config['internaldb.ldapconn.port'] = deployer.mdict['pki_ds_ldaps_port']
+        else:
+            subsystem.config['internaldb.ldapconn.secureConn'] = 'false'
+            subsystem.config['internaldb.ldapconn.port'] = deployer.mdict['pki_ds_ldap_port']
+
+        subsystem.config['internaldb.ldapauth.bindDN'] = deployer.mdict['pki_ds_bind_dn']
+        subsystem.config['internaldb.basedn'] = deployer.mdict['pki_ds_base_dn']
+        subsystem.config['internaldb.database'] = deployer.mdict['pki_ds_database']
+
+        if config.str2bool(deployer.mdict['pki_share_db']):
+            subsystem.config['preop.internaldb.dbuser'] = deployer.mdict['pki_share_dbuser_dn']
+
+        if config.str2bool(deployer.mdict['pki_ds_create_new_db']):
+            subsystem.config['preop.database.createNewDB'] = 'true'
+        else:
+            subsystem.config['preop.database.createNewDB'] = 'false'
+
+        if config.str2bool(deployer.mdict['pki_ds_remove_data']):
+            subsystem.config['preop.database.removeData'] = 'true'
+        else:
+            subsystem.config['preop.database.removeData'] = 'false'
+
+        # configure cloning
+        subsystem.config['preop.database.setupReplication'] = \
+            deployer.mdict['pki_clone_setup_replication']
+        subsystem.config['preop.database.reindexData'] = deployer.mdict['pki_clone_reindex_data']
 
         ocsp_uri = deployer.mdict.get('pki_default_ocsp_uri')
         if ocsp_uri:
@@ -601,6 +616,17 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                 logger.debug('Setting ephemeral requests to true')
                 subsystem.config['kra.ephemeralRequests'] = 'true'
 
+        if subsystem.name == 'tps':
+            baseDN = subsystem.config['internaldb.basedn']
+            dsHost = subsystem.config['internaldb.ldapconn.host']
+            dsPort = subsystem.config['internaldb.ldapconn.port']
+
+            subsystem.config['tokendb.activityBaseDN'] = 'ou=Activities,' + baseDN
+            subsystem.config['tokendb.baseDN'] = 'ou=Tokens,' + baseDN
+            subsystem.config['tokendb.certBaseDN'] = 'ou=Certificates,' + baseDN
+            subsystem.config['tokendb.userBaseDN'] = baseDN
+            subsystem.config['tokendb.hostport'] = dsHost + ':' + dsPort
+
         subsystem.save()
 
         token = pki.nssdb.normalize_token(deployer.mdict['pki_token_name'])
@@ -647,10 +673,12 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             len(deployer.instance.tomcat_instance_subsystems())
 
         if tomcat_instance_subsystems == 1:
-            deployer.systemd.start()
+            logger.info('Starting server')
+            instance.start()
 
         elif tomcat_instance_subsystems > 1:
-            deployer.systemd.restart()
+            logger.info('Restarting server')
+            instance.restart()
 
         # Configure status request timeout.  This is used for each
         # status request in wait_for_startup
@@ -662,27 +690,16 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             if status_request_timeout <= 0:
                 raise ValueError("timeout must be greater than zero")
 
-        # wait for startup
-        status = deployer.instance.wait_for_startup(
+        deployer.instance.wait_for_startup(
+            subsystem,
             PKISPAWN_STARTUP_TIMEOUT_SECONDS,
             request_timeout=status_request_timeout,
         )
-        if status is None:
-            logger.error('Server failed to restart')
-            raise Exception("server failed to restart")
 
         # Optionally wait for debugger to attach (e. g. - 'eclipse'):
         if config.str2bool(deployer.mdict['pki_enable_java_debugger']):
             config.wait_to_attach_an_external_java_debugger()
 
-        # Construct PKI Subsystem Configuration Data
-        nssdb = instance.open_nssdb(token)
-        try:
-            request = deployer.config_client.create_config_request(nssdb)
-
-        finally:
-            nssdb.close()
-
         connection = pki.client.PKIConnection(
             protocol='https',
             hostname=deployer.mdict['pki_hostname'],
@@ -693,36 +710,71 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         client = pki.system.SystemConfigClient(connection)
 
         logger.info('Configuring %s subsystem', subsystem.type)
+        request = deployer.config_client.create_config_request()
         client.configure(request)
 
         logger.info('Setting up database')
-        client.setupDatabase(request)
 
-        logger.info('Configuring certificates')
-        response = client.configureCerts(request)
+        database_setup_request = deployer.config_client.create_database_setup_request()
+        client.setupDatabase(database_setup_request)
+
+        sslserver = subsystem.get_subsystem_cert('sslserver')
+        cert_setup_request = deployer.config_client.create_certificate_setup_request()
+
+        for tag in subsystem.config['preop.cert.list'].split(','):
+
+            logger.info('Setting up %s certificate', tag)
+
+            cert_setup_request.tag = tag
+            cert = client.setupCert(cert_setup_request)
+
+            if not cert:
+                continue
+
+            logger.debug('- cert: %s', cert['cert'])
+            logger.debug('- request: %s', cert['request'])
+
+            if tag == 'sslserver':
+                sslserver['data'] = cert['cert']
+                sslserver['request'] = cert['request']
 
         if not clone:
-            logger.info('Setting up admin')
+
+            logger.info('Setting up admin user')
+
             admin_setup_request = deployer.config_client.create_admin_setup_request()
             admin_setup_response = client.setupAdmin(admin_setup_request)
 
+            if external or standalone \
+                    or not config.str2bool(deployer.mdict['pki_import_admin_cert']):
+                admin_cert = admin_setup_response['adminCert']['cert']
+                deployer.config_client.process_admin_cert(admin_cert)
+
         if config.str2bool(deployer.mdict['pki_backup_keys']):
 
-            logger.info(
-                'Backing up keys into %s',
-                deployer.mdict['pki_backup_keys_p12'])
+            # by default store the backup file in the NSS databases directory
+            if not deployer.mdict['pki_backup_file']:
+                deployer.mdict['pki_backup_file'] = \
+                    deployer.mdict['pki_server_database_path'] + '/' + \
+                    deployer.mdict['pki_subsystem'].lower() + '_backup_keys.p12'
+
+            logger.info('Backing up keys into %s', deployer.mdict['pki_backup_file'])
 
             key_backup_request = deployer.config_client.create_key_backup_request()
             client.backupKeys(key_backup_request)
 
         logger.info('Setting up security domain')
-        client.setupSecurityDomain(request)
+        sd_setup_request = deployer.config_client.create_security_domain_setup_request()
+        client.setupSecurityDomain(sd_setup_request)
 
-        logger.info('Setting up database user')
-        client.setupDatabaseUser(request)
+        if not config.str2bool(deployer.mdict['pki_share_db']):
+            logger.info('Setting up database user')
+            db_user_setup_request = deployer.config_client.create_database_user_setup_request()
+            client.setupDatabaseUser(db_user_setup_request)
 
         logger.info('Finalizing %s configuration', subsystem.type)
-        client.finalizeConfiguration(request)
+        finalize_config_request = deployer.config_client.create_finalize_config_request()
+        client.finalizeConfiguration(finalize_config_request)
 
         logger.info('%s configuration complete', subsystem.type)
 
@@ -737,39 +789,11 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         os.chown(restart_server, instance.uid, instance.gid)
         os.chmod(restart_server, 0o660)
 
-        try:
-            certs = response['systemCerts']
-        except KeyError:
-            # no system certs created
-            logger.debug('No new system certificates generated')
-            certs = []
-
-        if not isinstance(certs, list):
-            certs = [certs]
-
-        sslserver = subsystem.get_subsystem_cert('sslserver')
-
-        for cdata in certs:
-
-            if cdata['tag'] == 'sslserver':
-                sslserver['data'] = cdata['cert']
-                sslserver['request'] = cdata['request']
-
-            logger.debug('%s cert: %s', cdata['tag'], cdata['cert'])
-            logger.debug('%s request: %s', cdata['tag'], cdata['request'])
-
-        # Cloned PKI subsystems do not return an Admin Certificate
-        if not clone:
-
-            if external or standalone \
-                    or not config.str2bool(deployer.mdict['pki_import_admin_cert']):
-                admin_cert = admin_setup_response['adminCert']['cert']
-                deployer.config_client.process_admin_cert(admin_cert)
-
         # If temp SSL server cert was created and there's a new perm cert,
         # replace it with the perm cert.
         if create_temp_sslserver_cert and sslserver and sslserver['data']:
-            deployer.systemd.stop()
+            logger.info('Stopping server')
+            instance.stop()
 
             # Remove temp SSL server cert.
             self.remove_temp_sslserver_cert(instance, sslserver)
@@ -785,33 +809,18 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
                 self.import_perm_sslserver_cert(deployer, instance, sslserver)
 
-            deployer.systemd.start()
+            logger.info('Starting server')
+            instance.start()
 
         elif config.str2bool(deployer.mdict['pki_restart_configured_instance']):
-            # Optionally, programmatically 'restart' the configured PKI instance
-            deployer.systemd.restart()
+            logger.info('Restarting server')
+            instance.restart()
 
-        # wait for startup
-        status = None
-
-        if deployer.fips.is_fips_enabled():
-            # must use 'http' protocol when FIPS mode is enabled
-            status = deployer.instance.wait_for_startup(
-                PKISPAWN_STARTUP_TIMEOUT_SECONDS,
-                request_timeout=status_request_timeout,
-                secure_connection=False,
-            )
-
-        else:
-            status = deployer.instance.wait_for_startup(
-                PKISPAWN_STARTUP_TIMEOUT_SECONDS,
-                request_timeout=status_request_timeout,
-                secure_connection=True,
-            )
-
-        if not status:
-            logger.error('Server failed to restart')
-            raise RuntimeError("server failed to restart")
+        deployer.instance.wait_for_startup(
+            subsystem,
+            PKISPAWN_STARTUP_TIMEOUT_SECONDS,
+            request_timeout=status_request_timeout,
+        )
 
     def destroy(self, deployer):
         pass
