@@ -32,9 +32,7 @@ import pki.util
 from .. import pkiconfig as config
 from .. import pkiscriptlet
 
-logger = logging.LoggerAdapter(
-    logging.getLogger('nssdb'),
-    extra={'indent': ''})
+logger = logging.getLogger('nssdb')
 
 
 # PKI Deployment Security Databases Scriptlet
@@ -51,19 +49,26 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         instance = pki.server.PKIInstance(deployer.mdict['pki_instance_name'])
         instance.load()
 
-        subsystem = instance.get_subsystem(
-            deployer.mdict['pki_subsystem'].lower())
+        subsystem = instance.get_subsystem(deployer.mdict['pki_subsystem'].lower())
 
         logger.info('Creating password config: %s', deployer.mdict['pki_shared_password_conf'])
+
+        # store internal token password
+        self_signed_token = deployer.mdict['pki_self_signed_token']
+        if not pki.nssdb.normalize_token(self_signed_token):
+            self_signed_token = pki.nssdb.INTERNAL_TOKEN_NAME
+
+        instance.passwords[self_signed_token] = deployer.mdict['pki_server_database_password']
+
         if config.str2bool(deployer.mdict['pki_hsm_enable']):
-            deployer.password.create_hsm_password_conf(
-                deployer.mdict['pki_shared_password_conf'],
-                deployer.mdict['pki_server_database_password'],
-                deployer.mdict['pki_token_password'])
-        else:
-            deployer.password.create_password_conf(
-                deployer.mdict['pki_shared_password_conf'],
-                deployer.mdict['pki_server_database_password'])
+
+            hsm_token = deployer.mdict['pki_token_name']
+            subsystem.config['preop.module.token'] = hsm_token
+            instance.passwords['hardware-%s' % hsm_token] = deployer.mdict['pki_token_password']
+
+        # store internal database password
+        instance.passwords['internaldb'] = deployer.mdict['pki_ds_password']
+        instance.store_passwords()
 
         # Since 'certutil' does NOT strip the 'token=' portion of
         # the 'token=password' entries, create a temporary server 'pfile'
@@ -231,6 +236,16 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             subject_dn = deployer.mdict['pki_%s_subject_dn' % deploy_tag]
             subsystem.config['preop.cert.%s.dn' % config_tag] = subject_dn
 
+            keytype = deployer.mdict['pki_%s_key_type' % deploy_tag]
+            subsystem.config['preop.cert.%s.keytype' % config_tag] = keytype
+
+            keyalgorithm = deployer.mdict['pki_%s_key_algorithm' % deploy_tag]
+            subsystem.config['preop.cert.%s.keyalgorithm' % config_tag] = keyalgorithm
+
+            signingalgorithm = deployer.mdict.get(
+                'pki_%s_signing_algorithm' % deploy_tag, keyalgorithm)
+            subsystem.config['preop.cert.%s.signingalgorithm' % config_tag] = signingalgorithm
+
             # TODO: move more system cert params here
 
         # If specified in the deployment parameter, add generic CA signing cert
@@ -248,6 +263,36 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                 subsystem.config['preop.cert.signing.ext.critical'] = \
                     deployer.configuration_file.req_ext_critical.lower()
 
+            if deployer.configuration_file.req_ski:
+                subsystem.config['preop.cert.signing.subject_key_id'] = \
+                    deployer.configuration_file.req_ski
+
+        if subsystem.type == 'KRA':
+            if deployer.configuration_file.clone:
+
+                token = subsystem.config['preop.module.token']
+                if pki.nssdb.normalize_token(token):
+
+                    storage_subsystem = subsystem.config['preop.cert.storage.subsystem']
+                    storage_nickname = subsystem.config['preop.cert.storage.nickname']
+                    transport_nickname = subsystem.config['preop.cert.transport.nickname']
+
+                    subsystem.config['%s.storageUnit.hardware' % storage_subsystem] = token
+                    subsystem.config['%s.storageUnit.nickName' % storage_subsystem] = \
+                        token + ':' + storage_nickname
+                    subsystem.config['%s.transportUnit.nickName' % storage_subsystem] = \
+                        token + ':' + transport_nickname
+
+        if deployer.configuration_file.clone:
+
+            nickname = subsystem.config['%s.audit_signing.nickname' % subsystem.name]
+            token = subsystem.config['%s.audit_signing.tokenname' % subsystem.name]
+
+            if pki.nssdb.normalize_token(token):
+                nickname = token + ':' + nickname
+
+            subsystem.config['log.instance.SignedAudit.signedAuditCertNickname'] = nickname
+
         subsystem.save()
 
         # Place 'slightly' less restrictive permissions on
@@ -306,6 +351,11 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         logger.info('Removing NSS database')
 
+        # Remove NSS DB when uninstalling the last subsystem
+        #
+        # NOTE: We check for 0 subsystems to exist at this point as
+        # /var/lib/pki/<instance>/<subsystem> dir should
+        # be removed as part of subsystem_layout scriptlet
         if len(deployer.instance.tomcat_instance_subsystems()) == 0:
 
             if deployer.directory.exists(deployer.mdict['pki_client_dir']):
