@@ -39,9 +39,7 @@ if selinux.is_selinux_enabled():
         if sys.version_info.major == 2:
             raise
 
-logger = logging.LoggerAdapter(
-    logging.getLogger('selinux'),
-    extra={'indent': ''})
+logger = logging.getLogger('selinux')
 
 
 # PKI Deployment Selinux Setup Scriptlet
@@ -55,6 +53,15 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         selinux.restorecon(mdict['pki_instance_log_path'], True)
         selinux.restorecon(mdict['pki_instance_configuration_path'], True)
 
+    # Helper function to check if a given `context_value` exists in the given
+    # set of `records`. This method can process both port contexts and file contexts
+    def context_exists(self, records, context_value):
+        for keys in records.keys():
+            for key in keys:
+                if str(key) == context_value:
+                    return True
+        return False
+
     def spawn(self, deployer):
 
         if config.str2bool(deployer.mdict['pki_skip_installation']):
@@ -89,8 +96,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
                         logger.info(
                             "adding selinux fcontext \"%s\"",
-                            deployer.mdict['pki_instance_path'] + self.suffix,
-                            extra=config.PKI_INDENTATION_LEVEL_2)
+                            deployer.mdict['pki_instance_path'] + self.suffix)
                         fcon.add(
                             deployer.mdict['pki_instance_path'] + self.suffix,
                             config.PKI_INSTANCE_SELINUX_CONTEXT, "", "s0", "")
@@ -98,8 +104,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                         logger.info(
                             "adding selinux fcontext \"%s\"",
                             deployer.mdict['pki_instance_log_path'] +
-                            self.suffix,
-                            extra=config.PKI_INDENTATION_LEVEL_2)
+                            self.suffix)
                         fcon.add(
                             deployer.mdict['pki_instance_log_path'] +
                             self.suffix,
@@ -108,8 +113,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                         logger.info(
                             "adding selinux fcontext \"%s\"",
                             deployer.mdict['pki_instance_configuration_path'] +
-                            self.suffix,
-                            extra=config.PKI_INDENTATION_LEVEL_2)
+                            self.suffix)
                         fcon.add(
                             deployer.mdict['pki_instance_configuration_path'] +
                             self.suffix,
@@ -117,17 +121,14 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
                         logger.info(
                             "adding selinux fcontext \"%s\"",
-                            deployer.mdict['pki_server_database_path'] + self.suffix,
-                            extra=config.PKI_INDENTATION_LEVEL_2)
+                            deployer.mdict['pki_server_database_path'] + self.suffix)
                         fcon.add(
                             deployer.mdict['pki_server_database_path'] + self.suffix,
                             config.PKI_CERTDB_SELINUX_CONTEXT, "", "s0", "")
 
                         port_records = seobject.portRecords(trans)
                         for port in ports:
-                            logger.info(
-                                "adding selinux port %s", port,
-                                extra=config.PKI_INDENTATION_LEVEL_2)
+                            logger.info("adding selinux port %s", port)
                             port_records.add(
                                 port, "tcp", "s0",
                                 config.PKI_PORT_SELINUX_CONTEXT)
@@ -163,9 +164,8 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             return
 
         # A maximum of 10 tries to delete the SELinux contexts
-        counter = 1
         max_tries = 10
-        while True:
+        for counter in range(1, max_tries):
             try:
                 # remove SELinux contexts when removing the last subsystem
                 if len(deployer.instance.tomcat_instance_subsystems()) == 0:
@@ -176,47 +176,56 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                             config.PKI_DEPLOYMENT_DEFAULT_TOMCAT_INSTANCE_NAME:
 
                         fcon = seobject.fcontextRecords(trans)
+                        file_records = fcon.get_all()
 
-                        logger.info(
-                            "deleting selinux fcontext \"%s\"",
-                            deployer.mdict['pki_instance_path'] + self.suffix,
-                            extra=config.PKI_INDENTATION_LEVEL_2)
-                        fcon.delete(
-                            deployer.mdict['pki_instance_path'] +
-                            self.suffix, "")
+                        if self.context_exists(file_records,
+                                               deployer.mdict['pki_instance_path'] +
+                                               self.suffix):
+                            logger.info(
+                                "deleting selinux fcontext \"%s\"",
+                                deployer.mdict['pki_instance_path'] + self.suffix)
+                            fcon.delete(
+                                deployer.mdict['pki_instance_path'] +
+                                self.suffix, "")
 
-                        logger.info(
-                            "deleting selinux fcontext \"%s\"",
-                            deployer.mdict['pki_instance_log_path'] +
-                            self.suffix,
-                            extra=config.PKI_INDENTATION_LEVEL_2)
-                        fcon.delete(
-                            deployer.mdict['pki_instance_log_path'] +
-                            self.suffix, "")
+                        if self.context_exists(file_records,
+                                               deployer.mdict['pki_instance_log_path'] +
+                                               self.suffix):
+                            logger.info(
+                                "deleting selinux fcontext \"%s\"",
+                                deployer.mdict['pki_instance_log_path'] +
+                                self.suffix)
+                            fcon.delete(
+                                deployer.mdict['pki_instance_log_path'] +
+                                self.suffix, "")
 
-                        logger.info(
-                            "deleting selinux fcontext \"%s\"",
-                            deployer.mdict['pki_instance_configuration_path'] +
-                            self.suffix,
-                            extra=config.PKI_INDENTATION_LEVEL_2)
-                        fcon.delete(
-                            deployer.mdict['pki_instance_configuration_path'] +
-                            self.suffix, "")
+                        if self.context_exists(file_records,
+                                               deployer.mdict['pki_instance_configuration_path'] +
+                                               self.suffix):
+                            logger.info(
+                                "deleting selinux fcontext \"%s\"",
+                                deployer.mdict['pki_instance_configuration_path'] +
+                                self.suffix)
+                            fcon.delete(
+                                deployer.mdict['pki_instance_configuration_path'] +
+                                self.suffix, "")
 
-                        logger.info(
-                            "deleting selinux fcontext \"%s\"",
-                            deployer.mdict['pki_server_database_path'] + self.suffix,
-                            extra=config.PKI_INDENTATION_LEVEL_2)
-                        fcon.delete(
-                            deployer.mdict['pki_server_database_path'] +
-                            self.suffix, "")
+                        if self.context_exists(file_records,
+                                               deployer.mdict['pki_server_database_path'] +
+                                               self.suffix):
+                            logger.info(
+                                "deleting selinux fcontext \"%s\"",
+                                deployer.mdict['pki_server_database_path'] + self.suffix)
+                            fcon.delete(
+                                deployer.mdict['pki_server_database_path'] +
+                                self.suffix, "")
 
                         port_records = seobject.portRecords(trans)
+                        port_record_values = port_records.get_all()
                         for port in ports:
-                            logger.info(
-                                "deleting selinux port %s", port,
-                                extra=config.PKI_INDENTATION_LEVEL_2)
-                            port_records.delete(port, "tcp")
+                            if self.context_exists(port_record_values, port):
+                                logger.info("deleting selinux port %s", port)
+                                port_records.delete(port, "tcp")
 
                     trans.finish()
                 break
@@ -225,7 +234,6 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                 logger.error(error_message)
                 if error_message.strip() == \
                         "Could not start semanage transaction":
-                    counter += 1
                     if counter >= max_tries:
                         raise
                     time.sleep(5)
