@@ -21,6 +21,7 @@
 # System Imports
 from __future__ import absolute_import
 from __future__ import print_function
+import logging
 import sys
 import signal
 import subprocess
@@ -38,7 +39,6 @@ try:
     import pki
     from pki.server.deployment import pkiconfig as config
     from pki.server.deployment import pkimanifest as manifest
-    from pki.server.deployment.pkihelper import RETRYABLE_EXCEPTIONS
     from pki.server.deployment.pkiparser import PKIConfigParser
     from pki.server.deployment import pkilogging
     from pki.server.deployment import pkimessages as log
@@ -51,6 +51,7 @@ error was:
 """ % sys.exc_info()[1], file=sys.stderr)
     sys.exit(1)
 
+logger = logging.getLogger('pkispawn')
 
 deployer = pki.server.deployment.PKIDeployer()
 
@@ -370,7 +371,7 @@ def main(argv):
                                             'pki_security_domain_name',
                                             info.name)
                         break
-                    except RETRYABLE_EXCEPTIONS as e:
+                    except pki.RETRYABLE_EXCEPTIONS as e:
                         parser.print_text('ERROR: ' + str(e))
 
                 while True:
@@ -401,7 +402,7 @@ def main(argv):
                         if status == 'running':
                             break
                         parser.print_text('ERROR: CA is not running')
-                    except RETRYABLE_EXCEPTIONS as e:
+                    except pki.RETRYABLE_EXCEPTIONS as e:
                         parser.print_text('ERROR: ' + str(e))
 
                 while True:
@@ -413,7 +414,7 @@ def main(argv):
                         if status == 'running':
                             break
                         parser.print_text('ERROR: TKS is not running')
-                    except RETRYABLE_EXCEPTIONS as e:
+                    except pki.RETRYABLE_EXCEPTIONS as e:
                         parser.print_text('ERROR: ' + str(e))
 
                 while True:
@@ -436,7 +437,7 @@ def main(argv):
                             if status == 'running':
                                 break
                             parser.print_text('ERROR: KRA is not running')
-                        except RETRYABLE_EXCEPTIONS as e:
+                        except pki.RETRYABLE_EXCEPTIONS as e:
                             parser.print_text('ERROR: ' + str(e))
                     else:
                         parser.set_property(deployer.subsystem_name,
@@ -502,8 +503,7 @@ def main(argv):
     # Read the specified PKI configuration file.
     rv = parser.read_pki_configuration_file()
     if rv != 0:
-        config.pki_log.error(log.PKI_UNABLE_TO_PARSE_1, rv,
-                             extra=config.PKI_INDENTATION_LEVEL_0)
+        logger.error(log.PKI_UNABLE_TO_PARSE_1, rv)
         sys.exit(1)
 
     # --skip-configuration
@@ -581,10 +581,9 @@ def main(argv):
 
     # ALWAYS archive configuration file and manifest file
 
-    config.pki_log.info(
+    logger.info(
         log.PKI_ARCHIVE_CONFIG_MESSAGE_1,
-        deployer.mdict['pki_user_deployment_cfg_spawn_archive'],
-        extra=config.PKI_INDENTATION_LEVEL_1)
+        deployer.mdict['pki_user_deployment_cfg_spawn_archive'])
 
     # For debugging/auditing purposes, save a timestamped copy of
     # this configuration file in the subsystem archive
@@ -592,10 +591,9 @@ def main(argv):
         deployer.mdict['pki_user_deployment_cfg_replica'],
         deployer.mdict['pki_user_deployment_cfg_spawn_archive'])
 
-    config.pki_log.info(
+    logger.info(
         log.PKI_ARCHIVE_MANIFEST_MESSAGE_1,
-        deployer.mdict['pki_manifest_spawn_archive'],
-        extra=config.PKI_INDENTATION_LEVEL_1)
+        deployer.mdict['pki_manifest_spawn_archive'])
 
     # for record in manifest.database:
     #     print tuple(record)
@@ -672,7 +670,7 @@ def start_logging():
                           deployer.subsystem_name.lower() + \
                           "-" + "spawn" + "." + \
                           deployer.log_timestamp + "." + "log"
-    print('Log file: %s/%s' % (config.pki_log_dir, config.pki_log_name))
+    print('Installation log: %s/%s' % (config.pki_log_dir, config.pki_log_name))
 
     pkilogging.enable_pki_logger(config.pki_log_dir,
                                  config.pki_log_name,
@@ -692,10 +690,8 @@ def create_master_dictionary(parser):
     parser.mdict['pki_spawn_log'] = \
         config.pki_log_dir + "/" + config.pki_log_name
 
-    config.pki_log.debug(log.PKI_DICTIONARY_MASTER,
-                         extra=config.PKI_INDENTATION_LEVEL_0)
-    config.pki_log.debug(pkilogging.log_format(parser.mdict),
-                         extra=config.PKI_INDENTATION_LEVEL_0)
+    logger.debug(log.PKI_DICTIONARY_MASTER)
+    logger.debug(pkilogging.log_format(parser.mdict))
 
 
 def check_security_domain(parser):
@@ -704,11 +700,10 @@ def check_security_domain(parser):
             # Verify existence of Security Domain Password
             if 'pki_security_domain_password' not in parser.mdict or \
                     not len(parser.mdict['pki_security_domain_password']):
-                config.pki_log.error(
+                logger.error(
                     log.PKIHELPER_UNDEFINED_CONFIGURATION_FILE_ENTRY_2,
                     "pki_security_domain_password",
-                    parser.mdict['pki_user_deployment_cfg'],
-                    extra=config.PKI_INDENTATION_LEVEL_0)
+                    parser.mdict['pki_user_deployment_cfg'])
                 sys.exit(1)
 
             if not config.str2bool(parser.mdict['pki_skip_sd_verify']):
@@ -729,11 +724,10 @@ def check_ds(parser):
         # Verify existence of Directory Server Password
         if 'pki_ds_password' not in parser.mdict or \
                 not len(parser.mdict['pki_ds_password']):
-            config.pki_log.error(
+            logger.error(
                 log.PKIHELPER_UNDEFINED_CONFIGURATION_FILE_ENTRY_2,
                 "pki_ds_password",
-                parser.mdict['pki_user_deployment_cfg'],
-                extra=config.PKI_INDENTATION_LEVEL_0)
+                parser.mdict['pki_user_deployment_cfg'])
             sys.exit(1)
 
         if not config.str2bool(parser.mdict['pki_skip_ds_verify']):
@@ -896,7 +890,7 @@ def print_final_install_information(mdict):
               "      is a clone." %
               (deployer.subsystem_name, mdict['pki_instance_name']))
 
-    if mdict['pki_fips_mode_enabled']:
+    if pki.FIPS.is_enabled():
         print()
         print("      This %s subsystem of the '%s' instance\n"
               "      has FIPS mode enabled on this operating system." %
@@ -922,15 +916,11 @@ def print_final_install_information(mdict):
 
 def log_error_details():
     e_type, e_value, e_stacktrace = sys.exc_info()
-    config.pki_log.debug(
-        "Error Type: %s", e_type.__name__, extra=config.PKI_INDENTATION_LEVEL_2)
-    config.pki_log.debug(
-        "Error Message: %s", e_value, extra=config.PKI_INDENTATION_LEVEL_2)
     stacktrace_list = traceback.format_list(traceback.extract_tb(e_stacktrace))
-    e_stacktrace = ""
+    e_stacktrace = "%s: %s\n" % (e_type.__name__, e_value)
     for l in stacktrace_list:
         e_stacktrace += l
-    config.pki_log.debug(e_stacktrace, extra=config.PKI_INDENTATION_LEVEL_2)
+    logger.error(e_stacktrace)
     del e_type, e_value, e_stacktrace
 
 
