@@ -19,16 +19,20 @@
 package org.dogtagpki.server.tps;
 
 import com.netscape.certsrv.base.EBaseException;
+import com.netscape.cms.servlet.csadmin.Configurator;
 import com.netscape.cmscore.apps.CMSEngine;
-import com.netscape.cmscore.apps.SubsystemInfo;
 import com.netscape.cmscore.selftests.SelfTestSubsystem;
 
 public class TPSEngine extends CMSEngine {
 
-    public TPSEngine() {
+    public TPSEngine() throws Exception {
         super("TPS");
     }
 
+    public Configurator createConfigurator() throws Exception {
+        return new TPSConfigurator(this);
+    }
+
     protected void loadSubsystems() throws EBaseException {
 
         super.loadSubsystems();
@@ -37,8 +41,7 @@ public class TPSEngine extends CMSEngine {
             // Disable some subsystems before database initialization
             // in pre-op mode to prevent misleading exceptions.
 
-            SubsystemInfo si = dynSubsystems.get(SelfTestSubsystem.ID);
-            si.enabled = false;
+            setSubsystemEnabled(SelfTestSubsystem.ID, false);
         }
     }
 }
