@@ -9,7 +9,8 @@ function compose {
 
 function upload {
     if test -f $BUILDLOG; then
-        curl -k -w "\n" --upload-file $BUILDLOG https://transfer.sh/pki-build.txt >> /tmp/workdir/pki/logs.txt
+        curl -k -w "\n" --upload-file $BUILDLOG https://transfer.sh/pki-build.txt >> ${BUILDDIR}/pki/logs.txt || true
+        cat ${BUILDDIR}/pki/logs.txt
     fi
 }
 
@@ -23,6 +24,10 @@ if test "${TRAVIS}" != "true"; then
     compose
 
 else
+    # Always invoke upload() while exiting the script
     trap "upload" EXIT
-    compose "$@" >> $BUILDLOG 2>&1
+
+    # If IPA task is run, we just need to build base, server, ca and kra packages
+    [[ $TASK == 'IPA' ]] && args="$@ --with-pkgs=base,server,ca,kra" || args="$@"
+    compose $args >> $BUILDLOG 2>&1
 fi
